//
//  Lark.js stand-alone parser
//===============================

"use strict";

/**
	This is the main entrypoint into the generated Lark parser.

  @param {object} options An object with the following optional properties:

	  - transformer: an object of {rule: callback}, or an instance of Transformer
	  - propagate_positions (bool): should all tree nodes calculate line/column info?
	  - tree_class (Tree): a class that extends Tree, to be used for creating the parse tree.
	  - debug (bool): in case of error, should the parser output debug info to the console?

  @returns {Lark} an object which provides the following methods:

    - parse
    - parse_interactive
    - lex

*/
function get_parser(options = {}) {
  if (
    options.transformer &&
    options.transformer.constructor.name === "object"
  ) {
    options.transformer = Transformer.fromObj(options.transformer);
  }

  return Lark._load_from_dict({ data: DATA, memo: MEMO, ...options });
}

const NO_VALUE = {};
class _Decoratable {}
const Discard = {};

//
//   Implementation of Scanner + module emulation for Python's stdlib re
// -------------------------------------------------------------------------

const re = {
  escape(string) {
    // See: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Regular_Expressions#escaping
    return string.replace(/[.*+?^${}()|[\]\\]/g, "\\$&"); // $& means the whole matched string
  },
  compile(regex, flags) {
    // May throw re.error
    return new RegExp(regex, flags);
  },
  error: SyntaxError,
};

function _get_match(re_, regexp, s, flags) {
  const m = re_.compile(regexp, flags).exec(s);
  if (m != null) return m[0];
}

class Scanner {
  constructor(terminals, g_regex_flags, re_, use_bytes, match_whole = false) {
    this.terminals = terminals;
    this.g_regex_flags = g_regex_flags;
    this.re_ = re_;
    this.use_bytes = use_bytes;
    this.match_whole = match_whole;
    this.allowed_types = new Set(this.terminals.map((t) => t.name));

    this._regexps = this._build_mres(terminals);
  }

  _build_mres(terminals) {
    // TODO deal with priorities!
    let postfix = this.match_whole ? "$" : "";
    let patterns_by_flags = segment_by_key(terminals, (t) =>
      t.pattern.flags.join("")
    );

    let regexps = [];
    for (let [flags, patterns] of patterns_by_flags) {
      const pattern = patterns
        .map((t) => `(?<${t.name}>${t.pattern.to_regexp() + postfix})`)
        .join("|");
      regexps.push(new RegExp(pattern, this.g_regex_flags + flags + "y"));
    }

    return regexps;
  }

  match(text, pos) {
    for (const re of this._regexps) {
      re.lastIndex = pos;
      let m = re.exec(text);
      if (m) {
        // Find group. Ugly hack, but javascript is forcing my hand.
        let group = null;
        for (let [k, v] of Object.entries(m.groups)) {
          if (v) {
            group = k;
            break;
          }
        }
        return [m[0], group];
      }
    }
  }
}
//
//  Start of library code
// --------------------------

const util = typeof require !== "undefined" && require("util");

class ABC {}

const NotImplemented = {};

function dict_items(d) {
  return Object.entries(d);
}
function dict_keys(d) {
  return Object.keys(d);
}
function dict_values(d) {
  return Object.values(d);
}

function dict_pop(d, key) {
  if (key === undefined) {
    key = Object.keys(d)[0];
  }
  let value = d[key];
  delete d[key];
  return value;
}

function dict_get(d, key, otherwise = null) {
  return d[key] || otherwise;
}

function dict_update(self, other) {
  if (self.constructor.name === "Map") {
    for (const [k, v] of dict_items(other)) {
      self.set(k, v);
    }
  } else {
    for (const [k, v] of dict_items(other)) {
      self[k] = v;
    }
  }
}

function make_constructor(cls) {
  return function () {
    return new cls(...arguments);
  };
}

function range(start, end) {
  if (end === undefined) {
    end = start;
    start = 0;
  }
  const res = [];
  for (let i = start; i < end; i++) res.push(i);
  return res;
}

function format(s) {
  let counter = 0;
  let args = [...arguments].slice(1);

  return s.replace(/%([sr])/g, function () {
    const t = arguments[1];
    const item = args[counter++];
    if (t === "r") {
      return util
        ? util.inspect(item, false, null, true)
        : JSON.stringify(item, null, 0);
    } else {
      return item;
    }
  });
}

function union(setA, setB) {
  let _union = new Set(setA);
  for (const elem of setB) {
    _union.add(elem);
  }
  return _union;
}

function intersection(setA, setB) {
  let _intersection = new Set();
  for (const elem of setB) {
    if (setA.has(elem)) {
      _intersection.add(elem);
    }
  }
  return _intersection;
}

function set_subtract(a, b) {
  return [...a].filter((e) => !b.has(e));
}

function dict(d) {
  return { ...d };
}

function bool(x) {
  return !!x;
}

function new_object(cls) {
  return Object.create(cls.prototype);
}

function copy(obj) {
  if (typeof obj == "object") {
    let empty_clone = Object.create(Object.getPrototypeOf(obj));
    return Object.assign(empty_clone, obj);
  }
  return obj;
}

function map_pop(key) {
  let value = this.get(key);
  this.delete(key);
  return value;
}

function hash(x) {
  return x;
}
function tuple(x) {
  return x;
}
function frozenset(x) {
  return new Set(x);
}

function is_dict(x) {
  return x && x.constructor.name === "Object";
}
function is_array(x) {
  return x && x.constructor.name === "Array";
}
function callable(x) {
  return typeof x === "function";
}

function* enumerate(it, start = 0) {
  // Taken from: https://stackoverflow.com/questions/34336960/what-is-the-es6-equivalent-of-python-enumerate-for-a-sequence
  let i = start;
  for (const x of it) {
    yield [i++, x];
  }
}

function any(lst) {
  for (const item of lst) {
    if (item) {
      return true;
    }
  }
  return false;
}

function all(lst) {
  for (const item of lst) {
    if (!item) {
      return false;
    }
  }
  return true;
}

function filter(pred, lst) {
  return lst.filter(pred || bool);
}

function partial(f) {
  let args = [...arguments].slice(1);
  return function () {
    return f(...args, ...arguments);
  };
}

class EOFError extends Error {}

function last_item(a) {
  return a[a.length - 1];
}

function callable_class(cls) {
  return function () {
    let inst = new cls(...arguments);
    return inst.__call__.bind(inst);
  };
}

function list_repeat(list, count) {
  return Array.from({ length: count }, () => list).flat();
}

function isupper(a) {
  return /^[A-Z_$]*$/.test(a);
}

function rsplit(s, delimiter, limit) {
  const arr = s.split(delimiter);
  return limit ? arr.splice(-limit - 1) : arr;
}

function str_count(s, substr) {
  let re = new RegExp(substr, "g");
  return (s.match(re) || []).length;
}

function list_count(list, elem) {
  let count = 0;
  for (const e of list) {
    if (e === elem) {
      count++;
    }
  }
  return count;
}

function isSubset(subset, set) {
  for (let elem of subset) {
    if (!set.has(elem)) {
      return false;
    }
  }
  return true;
}

function* segment_by_key(a, key) {
  let buffer = [];
  let last_k = null;
  for (const item of a) {
    const k = key(item);
    if (last_k && k != last_k) {
      yield [last_k, buffer];
      buffer = [];
    }
    buffer.push(item);
    last_k = k;
  }
  yield [last_k, buffer];
}

// --------------------------
//  End of library code
//

//
// Exceptions
//

class LarkError extends Error {
  // pass
}

class ConfigurationError extends LarkError {
  // pass
}

function assert_config(value, options, msg = "Got %r, expected one of %s") {
  if (!(options.includes(value))) {
    throw new ConfigurationError(format(msg, value, options));
  }
}

class GrammarError extends LarkError {
  // pass
}

class ParseError extends LarkError {
  // pass
}

class LexError extends LarkError {
  // pass
}

/**
  UnexpectedInput Error.

    Used as a base class for the following exceptions:

    - ``UnexpectedCharacters``: The lexer encountered an unexpected string
    - ``UnexpectedToken``: The parser received an unexpected token
    - ``UnexpectedEOF``: The parser expected a token, but the input ended

    After catching one of these exceptions, you may call the following helper methods to create a nicer error message.

*/

class UnexpectedInput extends LarkError {
  pos_in_stream = null;
  _terminals_by_name = null;
  /**
    Returns a pretty string pinpointing the error in the text,
        with span amount of context characters around it.

        Note:
            The parser doesn't hold a copy of the text it has to parse,
            so you have to provide it again

  */
  get_context(text, span = 40) {
    let after, before;
    let pos = this.pos_in_stream;
    let start = max(pos - span, 0);
    let end = pos + span;
    if (!(text instanceof bytes)) {
      before = last_item(rsplit(text.slice(start, pos), "\n", 1));
      after = text.slice(pos, end).split("\n", 1)[0];
      return before + after + "\n" + " " * before.expandtabs().length + "^\n";
    } else {
      before = last_item(rsplit(text.slice(start, pos), "\n", 1));
      after = text.slice(pos, end).split("\n", 1)[0];
      return (
        before +
        after +
        "\n" +
        " " * before.expandtabs().length +
        "^\n"
      ).decode("ascii", "backslashreplace");
    }
  }

  /**
    Allows you to detect what's wrong in the input text by matching
        against example errors.

        Given a parser instance and a dictionary mapping some label with
        some malformed syntax examples, it'll return the label for the
        example that bests matches the current error. The function will
        iterate the dictionary until it finds a matching error, and
        return the corresponding value.

        For an example usage, see `examples/error_reporting_lalr.py`

        Parameters:
            parse_fn: parse function (usually ``lark_instance.parse``)
            examples: dictionary of ``{'example_string': value}``.
            use_accepts: Recommended to keep this as ``use_accepts=True``.

  */
  match_examples(
    parse_fn,
    examples,
    token_type_match_fallback = false,
  ) {
    if (is_dict(examples)) {
      examples = dict_items(examples);
    }

    let candidate = [null, false];
    for (const [i, [label, example]] of enumerate(examples)) {
      for (const [j, malformed] of enumerate(example)) {
        try {
          parse_fn(malformed);
        } catch (ut) {
          if (ut instanceof UnexpectedInput) {
            if (ut.state.eq(this.state)) {
                if (ut.token === this.token) {
                  return label;
                }

                if (token_type_match_fallback) {
                  // Fallback to token types match
                  if (
                    ut.token.type === this.token.type &&
                    !last_item(candidate)
                  ) {
                    candidate = [label, true];
                  }
                }
              if (candidate[0] === null) {
                candidate = [label, false];
              }
            }
          } else {
            throw ut;
          }
        }
      }
    }

    return candidate[0];
  }

  _format_expected(expected) {
    let d;
    if (this._terminals_by_name) {
      d = this._terminals_by_name;
      expected = expected.map((t_name) =>
        t_name in d ? d[t_name].user_repr() : t_name
      );
    }

    return format("Expected one of: \n\t* %s\n", expected.join("\n\t* "));
  }
}

/**
  An exception that is raised by the parser, when the input ends while it still expects a token.

*/

class UnexpectedEOF extends UnexpectedInput {
  constructor(expected, state = null, terminals_by_name = null) {
    super();
    this.expected = expected;
    this.state = state;
    this.token = new Token("<EOF>", "");
    // , line=-1, column=-1, pos_in_stream=-1)
    this.pos_in_stream = -1;
    this.line = -1;
    this.column = -1;
    this._terminals_by_name = terminals_by_name;
  }
}

/**
  An exception that is raised by the lexer, when it cannot match the next
    string of characters to any of its terminals.

*/

class UnexpectedCharacters extends UnexpectedInput {
  constructor({
    seq,
    lex_pos,
    line,
    column,
    allowed = null,
    considered_tokens = null,
    state = null,
    token_history = null,
    terminals_by_name = null,
    considered_rules = null,
  } = {}) {
    super();
    // TODO considered_tokens and allowed can be figured out using state
    this.line = line;
    this.column = column;
    this.pos_in_stream = lex_pos;
    this.state = state;
    this._terminals_by_name = terminals_by_name;
    this.allowed = allowed;
    this.considered_tokens = considered_tokens;
    this.considered_rules = considered_rules;
    this.token_history = token_history;
      this.char = seq[lex_pos];
    // this._context = this.get_context(seq);
  }
}

/**
  An exception that is raised by the parser, when the token it received
    doesn't match any valid step forward.

    Parameters:
        token: The mismatched token
        expected: The set of expected tokens
        considered_rules: Which rules were considered, to deduce the expected tokens
        state: A value representing the parser state. Do not rely on its value or type.
        interactive_parser: An instance of ``InteractiveParser``, that is initialized to the point of failture,
                            and can be used for debugging and error handling.

    Note: These parameters are available as attributes of the instance.

*/

class UnexpectedToken extends UnexpectedInput {
  constructor({
    token,
    expected,
    considered_rules = null,
    state = null,
    interactive_parser = null,
    terminals_by_name = null,
    token_history = null,
  } = {}) {
    super();
    // TODO considered_rules and expected can be figured out using state
    this.line = (token && token["line"]) || "?";
    this.column = (token && token["column"]) || "?";
    this.pos_in_stream = (token && token["start_pos"]) || null;
    this.state = state;
    this.token = token;
    this.expected = expected;
    // XXX deprecate? `accepts` is better
    this._accepts = NO_VALUE;
    this.considered_rules = considered_rules;
    this.interactive_parser = interactive_parser;
    this._terminals_by_name = terminals_by_name;
    this.token_history = token_history;
  }

  get accepts() {
    if (this._accepts === NO_VALUE) {
      this._accepts =
        this.interactive_parser && this.interactive_parser.accepts();
    }

    return this._accepts;
  }
}

/**
  VisitError is raised when visitors are interrupted by an exception

    It provides the following attributes for inspection:

    Parameters:
        rule: the name of the visit rule that failed
        obj: the tree-node or token that was being processed
        orig_exc: the exception that cause it to fail

    Note: These parameters are available as attributes

*/

class VisitError extends LarkError {
  constructor(rule, obj, orig_exc) {
    let message = format(
      'Error trying to process rule "%s":\n\n%s',
      rule,
      orig_exc
    );
    super(message);
    this.rule = rule;
    this.obj = obj;
    this.orig_exc = orig_exc;
  }
}

//
// Utils
//

function classify(seq, key = null, value = null) {
  let k, v;
  let d = new Map();
  for (const item of seq) {
    k = key !== null ? key(item) : item;
    v = value !== null ? value(item) : item;
    if (d.has(k)) {
      d.get(k).push(v);
    } else {
      d.set(k, [v]);
    }
  }

  return d;
}

function _deserialize(data, namespace, memo) {
  let class_;
  if (is_dict(data)) {
    if ("__type__" in data) {
      // Object
      class_ = namespace[data["__type__"]];
      return class_.deserialize(data, memo);
    } else if ("@" in data) {
      return memo[data["@"]];
    }

    return Object.fromEntries(
      dict_items(data).map(([key, value]) => [
        key,
        _deserialize(value, namespace, memo),
      ])
    );
  } else if (is_array(data)) {
    return data.map((value) => _deserialize(value, namespace, memo));
  }

  return data;
}

/**
  Safe-ish serialization interface that doesn't rely on Pickle

    Attributes:
        __serialize_fields__ (List[str]): Fields (aka attributes) to serialize.
        __serialize_namespace__ (list): List of classes that deserialization is allowed to instantiate.
                                        Should include all field types that aren't builtin types.

*/

class Serialize {
  static deserialize(data, memo) {
    const cls = this;
    let fields = cls && cls["__serialize_fields__"];
    if ("@" in data) {
      return memo[data["@"]];
    }

    let inst = new_object(cls);
    for (const f of fields) {
      if (data && f in data) {
        inst[f] = _deserialize(data[f], NAMESPACE, memo);
      } else {
        throw new KeyError("Cannot find key for class", cls, e);
      }
    }

    if ("_deserialize" in inst) {
      inst._deserialize();
    }

    return inst;
  }
}

/**
  A version of serialize that memoizes objects to reduce space
*/

class SerializeMemoizer extends Serialize {
  static get __serialize_fields__() {
    return ["memoized"];
  }
  constructor(types_to_memoize) {
    super();
    this.types_to_memoize = tuple(types_to_memoize);
    this.memoized = new Enumerator();
  }

  in_types(value) {
    return value instanceof this.types_to_memoize;
  }

  serialize() {
    return _serialize(this.memoized.reversed(), null);
  }

  static deserialize(data, namespace, memo) {
    const cls = this;
    return _deserialize(data, namespace, memo);
  }
}

//
// Tree
//

class Meta {
  constructor() {
    this.empty = true;
  }
}

/**
  The main tree class.

    Creates a new tree, and stores "data" and "children" in attributes of the same name.
    Trees can be hashed and compared.

    Parameters:
        data: The name of the rule or alias
        children: List of matched sub-rules and terminals
        meta: Line & Column numbers (if ``propagate_positions`` is enabled).
            meta attributes: line, column, start_pos, end_line, end_column, end_pos

*/

class Tree {
  constructor(data, children, meta = null) {
    this.data = data;
    this.children = children;
    this._meta = meta;
  }

  get meta() {
    if (this._meta === null) {
      this._meta = new Meta();
    }

    return this._meta;
  }

  repr() {
    return format("Tree(%r, %r)", this.data, this.children);
  }

  _pretty_label() {
    return this.data;
  }

  _pretty(level, indent_str) {
    if (this.children.length === 1 && !(this.children[0] instanceof Tree)) {
      return [
        list_repeat(indent_str, level).join(''),
        this._pretty_label(),
        "\t",
        format("%s", this.children[0].value),
        "\n",
      ];
    }

    let l = [list_repeat(indent_str, level).join(''), this._pretty_label(), "\n"];
    for (const n of this.children) {
      if (n instanceof Tree) {
        l.push(...n._pretty(level + 1, indent_str));
      } else {
        l.push(...[list_repeat(indent_str, level+1).join(''), format("%s", n.value), "\n"]);
      }
    }

    return l;
  }

  /**
    Returns an indented string representation of the tree.

        Great for debugging.

  */
  pretty(indent_str = "  ") {
    return this._pretty(0, indent_str).join("");
  }

  eq(other) {
    if (
      other &&
      this &&
      other &&
      this &&
      other.children &&
      this.children &&
      other.data &&
      this.data
    ) {
      return this.data === other.data && this.children === other.children;
    } else {
      return false;
    }
  }

  /**
    Depth-first iteration.

        Iterates over all the subtrees, never returning to the same node twice (Lark's parse-tree is actually a DAG).

  */
  iter_subtrees() {
    let queue = [this];
    let subtrees = new Map();
    for (const subtree of queue) {
      subtrees.set(subtree, subtree);
      queue.push(
        ...[...subtree.children]
          .reverse()
          .filter((c) => c instanceof Tree && !subtrees.has(c))
          .map((c) => c)
      );
    }

    queue = undefined;
    return [...subtrees.values()].reverse();
  }

  /**
    Returns all nodes of the tree that evaluate pred(node) as true.
  */
  find_pred(pred) {
    return filter(pred, this.iter_subtrees());
  }

  /**
    Returns all nodes of the tree whose data equals the given data.
  */
  find_data(data) {
    return this.find_pred((t) => t.data === data);
  }


  /**
    Return all values in the tree that evaluate pred(value) as true.

        This can be used to find all the tokens in the tree.

        Example:
            >>> all_tokens = tree.scan_values(lambda v: isinstance(v, Token))

  */
  *scan_values(pred) {
    for (const c of this.children) {
      if (c instanceof Tree) {
        for (const t of c.scan_values(pred)) {
          yield t;
        }
      } else {
        if (pred(c)) {
          yield c;
        }
      }
    }
  }

  /**
    Breadth-first iteration.

        Iterates over all the subtrees, return nodes in order like pretty() does.

  */
  *iter_subtrees_topdown() {
    let node;
    let stack = [this];
    while (stack.length) {
      node = stack.pop();
      if (!(node instanceof Tree)) {
        continue;
      }

      yield node;
      for (const child of [...node.children].reverse()) {
        stack.push(child);
      }
    }
  }

  copy() {
    return type(this)(this.data, this.children);
  }

  set(data, children) {
    this.data = data;
    this.children = children;
  }
}

//
// Visitors
//

/**
  Transformers work bottom-up (or depth-first), starting with visiting the leaves and working
    their way up until ending at the root of the tree.

    For each node visited, the transformer will call the appropriate method (callbacks), according to the
    node's ``data``, and use the returned value to replace the node, thereby creating a new tree structure.

    Transformers can be used to implement map & reduce patterns. Because nodes are reduced from leaf to root,
    at any point the callbacks may assume the children have already been transformed (if applicable).

    If the transformer cannot find a method with the right name, it will instead call ``__default__``, which by
    default creates a copy of the node.

    To discard a node, return Discard (``lark.visitors.Discard``).

    ``Transformer`` can do anything ``Visitor`` can do, but because it reconstructs the tree,
    it is slightly less efficient.

    A transformer without methods essentially performs a non-memoized partial deepcopy.

    All these classes implement the transformer interface:

    - ``Transformer`` - Recursively transforms the tree. This is the one you probably want.
    - ``Transformer_InPlace`` - Non-recursive. Changes the tree in-place instead of returning new instances
    - ``Transformer_InPlaceRecursive`` - Recursive. Changes the tree in-place instead of returning new instances

    Parameters:
        visit_tokens (bool, optional): Should the transformer visit tokens in addition to rules.
                                       Setting this to ``False`` is slightly faster. Defaults to ``True``.
                                       (For processing ignored tokens, use the ``lexer_callbacks`` options)


*/

class Transformer extends _Decoratable {
  static get __visit_tokens__() {
    return true;
  }
  // For backwards compatibility

  constructor(visit_tokens = true) {
    super();
    this.__visit_tokens__ = visit_tokens;
  }

  static fromObj(obj, ...args) {
    class _T extends this {}
    for (let [k, v] of Object.entries(obj)) {
      _T.prototype[k] = v
    }
    return new _T(...args)
  }

  _call_userfunc(tree, new_children = null) {
    let f, wrapper;
    // Assumes tree is already transformed
    let children = new_children !== null ? new_children : tree.children;
    if (tree && tree.data && this && this[tree.data]) {
      f = this && this[tree.data];
      try {
        wrapper = (f && f["visit_wrapper"]) || null;
        if (wrapper !== null) {
          return f.visit_wrapper(f, tree.data, children, tree.meta);
        } else {
          return f(children);
        }
      } catch (e) {
        if (e instanceof GrammarError) {
          throw e;
        } else if (e instanceof Error) {
          throw new VisitError(tree.data, tree, e);
        } else {
          throw e;
        }
      }
    } else {
      return this.__default__(tree.data, children, tree.meta);
    }
  }

  _call_userfunc_token(token) {
    let f;
    if (token && token.type && this && this[token.type]) {
      f = this && this[token.type];
      try {
        return f(token);
      } catch (e) {
        if (e instanceof GrammarError) {
          throw e;
        } else if (e instanceof Error) {
          throw new VisitError(token.type, token, e);
        } else {
          throw e;
        }
      }
    } else {
      return this.__default_token__(token);
    }
  }

  *_transform_children(children) {
    let res;
    for (const c of children) {
      if (c instanceof Tree) {
        res = this._transform_tree(c);
      } else if (this.__visit_tokens__ && c instanceof Token) {
        res = this._call_userfunc_token(c);
      } else {
        res = c;
      }
      if (res !== Discard) {
        yield res;
      }
    }
  }

  _transform_tree(tree) {
    let children = [...this._transform_children(tree.children)];
    return this._call_userfunc(tree, children);
  }

  /**
    Transform the given tree, and return the final result
  */
  transform(tree) {
    return this._transform_tree(tree);
  }

  /**
    Default function that is called if there is no attribute matching ``data``

        Can be overridden. Defaults to creating a new copy of the tree node (i.e. ``return Tree(data, children, meta)``)

  */
  __default__(data, children, meta) {
    return new Tree(data, children, meta);
  }

  /**
    Default function that is called if there is no attribute matching ``token.type``

        Can be overridden. Defaults to returning the token as-is.

  */
  __default_token__(token) {
    return token;
  }
}

/**
  Same as Transformer, but non-recursive, and changes the tree in-place instead of returning new instances

    Useful for huge trees. Conservative in memory.

*/

class Transformer_InPlace extends Transformer {
  _transform_tree(tree) {
    // Cancel recursion
    return this._call_userfunc(tree);
  }

  transform(tree) {
    for (const subtree of tree.iter_subtrees()) {
      subtree.children = [...this._transform_children(subtree.children)];
    }

    return this._transform_tree(tree);
  }
}

/**
  Same as Transformer but non-recursive.

    Like Transformer, it doesn't change the original tree.

    Useful for huge trees.

*/

class Transformer_NonRecursive extends Transformer {
  transform(tree) {
    let args, res, size;
    // Tree to postfix
    let rev_postfix = [];
    let q = [tree];
    while (q.length) {
      const t = q.pop();
      rev_postfix.push(t);
      if (t instanceof Tree) {
        q.push(...t.children);
      }
    }

    // Postfix to tree
    let stack = [];
    for (const x of [...rev_postfix].reverse()) {
      if (x instanceof Tree) {
        size = x.children.length;
        if (size) {
          args = stack.slice(-size);
          stack.splice(-size);
        } else {
          args = [];
        }
        res = this._call_userfunc(x, args);
        if (res !== Discard) {
          stack.push(res);
        }
      } else if (this.__visit_tokens__ && x instanceof Token) {
        res = this._call_userfunc_token(x);
        if (res !== Discard) {
          stack.push(res);
        }
      } else {
        stack.push(x);
      }
    }

    let [t] = stack;
    // We should have only one tree remaining
    return t;
  }
}

/**
  Same as Transformer, recursive, but changes the tree in-place instead of returning new instances
*/

class Transformer_InPlaceRecursive extends Transformer {
  _transform_tree(tree) {
    tree.children = [...this._transform_children(tree.children)];
    return this._call_userfunc(tree);
  }
}

// Visitors

class VisitorBase {
  _call_userfunc(tree) {
    const callback = this[tree.data]
    if (callback) {
      return callback(tree)
    } else {
      return this.__default__(tree);
    }
  }

  /**
    Default function that is called if there is no attribute matching ``tree.data``

        Can be overridden. Defaults to doing nothing.

  */
  __default__(tree) {
    return tree;
  }

  __class_getitem__(_) {
    return cls;
  }
}

/**
  Tree visitor, non-recursive (can handle huge trees).

    Visiting a node calls its methods (provided by the user via inheritance) according to ``tree.data``

*/

class Visitor extends VisitorBase {
  /**
    Visits the tree, starting with the leaves and finally the root (bottom-up)
  */
  visit(tree) {
    for (const subtree of tree.iter_subtrees()) {
      this._call_userfunc(subtree);
    }

    return tree;
  }

  /**
    Visit the tree, starting at the root, and ending at the leaves (top-down)
  */
  visit_topdown(tree) {
    for (const subtree of tree.iter_subtrees_topdown()) {
      this._call_userfunc(subtree);
    }

    return tree;
  }
}

/**
  Bottom-up visitor, recursive.

    Visiting a node calls its methods (provided by the user via inheritance) according to ``tree.data``

    Slightly faster than the non-recursive version.

*/

class Visitor_Recursive extends VisitorBase {
  /**
    Visits the tree, starting with the leaves and finally the root (bottom-up)
  */
  visit(tree) {
    for (const child of tree.children) {
      if (child instanceof Tree) {
        this.visit(child);
      }
    }

    this._call_userfunc(tree);
    return tree;
  }

  /**
    Visit the tree, starting at the root, and ending at the leaves (top-down)
  */
  visit_topdown(tree) {
    this._call_userfunc(tree);
    for (const child of tree.children) {
      if (child instanceof Tree) {
        this.visit_topdown(child);
      }
    }

    return tree;
  }
}

/**
  Interpreter walks the tree starting at the root.

    Visits the tree, starting with the root and finally the leaves (top-down)

    For each tree node, it calls its methods (provided by user via inheritance) according to ``tree.data``.

    Unlike ``Transformer`` and ``Visitor``, the Interpreter doesn't automatically visit its sub-branches.
    The user has to explicitly call ``visit``, ``visit_children``, or use the ``@visit_children_decor``.
    This allows the user to implement branching and loops.

*/

class Interpreter extends _Decoratable {
  visit(tree) {
    if (tree.data in this) {
      return this[tree.data](tree);
    } else {
      return this.__default__(tree)
    }
  }

  visit_children(tree) {
    return tree.children.map((child) =>
      child instanceof Tree ? this.visit(child) : child
    );
  }

  __default__(tree) {
    return this.visit_children(tree);
  }
}

//
// Grammar
//

var TOKEN_DEFAULT_PRIORITY = 0;
class Symbol extends Serialize {
  is_term = NotImplemented;
  constructor(name) {
    super();
    this.name = name;
  }

  eq(other) {
    return this.is_term === other.is_term && this.name === other.name;
  }

  repr() {
    return format("%s(%r)", type(this).name, this.name);
  }

  static get fullrepr() {
    return property(__repr__);
  }
  get fullrepr() {
    return this.constructor.fullrepr;
  }
  renamed(f) {
    return type(this)(f(this.name));
  }
}

class Terminal extends Symbol {
  static get __serialize_fields__() {
    return ["name", "filter_out"];
  }
  get is_term() {
    return true
  }

  constructor(name, filter_out = false) {
    super();
    this.name = name;
    this.filter_out = filter_out;
  }

  get fullrepr() {
    return format("%s(%r, %r)", type(this).name, this.name, this.filter_out);
  }

  renamed(f) {
    return type(this)(f(this.name), this.filter_out);
  }
}

class NonTerminal extends Symbol {
  static get __serialize_fields__() {
    return ["name"];
  }
  get is_term() {
    return false
  }

}

class RuleOptions extends Serialize {
  static get __serialize_fields__() {
    return [
      "keep_all_tokens",
      "expand1",
      "priority",
      "template_source",
      "empty_indices",
    ];
  }
  constructor(
    keep_all_tokens = false,
    expand1 = false,
    priority = null,
    template_source = null,
    empty_indices = []
  ) {
    super();
    this.keep_all_tokens = keep_all_tokens;
    this.expand1 = expand1;
    this.priority = priority;
    this.template_source = template_source;
    this.empty_indices = empty_indices;
  }

  repr() {
    return format(
      "RuleOptions(%r, %r, %r, %r)",
      this.keep_all_tokens,
      this.expand1,
      this.priority,
      this.template_source
    );
  }
}

/**

        origin : a symbol
        expansion : a list of symbols
        order : index of this expansion amongst all rules of the same name

*/

class Rule extends Serialize {
  static get __serialize_fields__() {
    return ["origin", "expansion", "order", "alias", "options"];
  }
  static get __serialize_namespace__() {
    return [Terminal, NonTerminal, RuleOptions];
  }
  constructor(origin, expansion, order = 0, alias = null, options = null) {
    super();
    this.origin = origin;
    this.expansion = expansion;
    this.alias = alias;
    this.order = order;
    this.options = options || new RuleOptions();
    this._hash = hash([this.origin, tuple(this.expansion)]);
  }

  _deserialize() {
    this._hash = hash([this.origin, tuple(this.expansion)]);
  }

  repr() {
    return format(
      "Rule(%r, %r, %r, %r)",
      this.origin,
      this.expansion,
      this.alias,
      this.options
    );
  }

  eq(other) {
    if (!(other instanceof Rule)) {
      return false;
    }

    return this.origin === other.origin && this.expansion === other.expansion;
  }
}

//
// Lexer
//

// Lexer Implementation

class Pattern extends Serialize {
  constructor(value, flags = [], raw = null) {
    super();
    this.value = value;
    this.flags = frozenset(flags);
    this.raw = raw;
  }

  repr() {
    return repr(this.to_regexp());
  }

  eq(other) {
    return (
      type(this) === type(other) &&
      this.value === other.value &&
      this.flags === other.flags
    );
  }

  to_regexp() {
    throw new NotImplementedError();
  }

  get min_width() {
    throw new NotImplementedError();
  }

  get max_width() {
    throw new NotImplementedError();
  }

  _get_flags(value) {
    return value;
  }
}

class PatternStr extends Pattern {
  static get __serialize_fields__() {
    return ["value", "flags"];
  }
  static get type() { return "str"; }
  to_regexp() {
    return this._get_flags(re.escape(this.value));
  }

  get min_width() {
    return this.value.length;
  }

  get max_width() {
    return this.value.length;
  }
}

class PatternRE extends Pattern {
  static get __serialize_fields__() {
    return ["value", "flags", "_width"];
  }
  static get type() { return "re"; }
  to_regexp() {
    return this._get_flags(this.value);
  }

  _get_width() {
    if (this._width === null) {
      this._width = get_regexp_width(this.to_regexp());
    }

    return this._width;
  }

  get min_width() {
    return this._get_width()[0];
  }

  get max_width() {
    return this._get_width()[1];
  }
}

class TerminalDef extends Serialize {
  static get __serialize_fields__() {
    return ["name", "pattern", "priority"];
  }
  static get __serialize_namespace__() {
    return [PatternStr, PatternRE];
  }
  constructor(name, pattern, priority = TOKEN_DEFAULT_PRIORITY) {
    super();
    this.name = name;
    this.pattern = pattern;
    this.priority = priority;
  }

  repr() {
    return format("%s(%r, %r)", type(this).name, this.name, this.pattern);
  }

  user_repr() {
    if (this.name.startsWith("__")) {
      // We represent a generated terminal
      return this.pattern.raw || this.name;
    } else {
      return this.name;
    }
  }
}

/**
  A string with meta-information, that is produced by the lexer.

    When parsing text, the resulting chunks of the input that haven't been discarded,
    will end up in the tree as Token instances. The Token class inherits from Python's ``str``,
    so normal string comparisons and operations will work as expected.

    Attributes:
        type: Name of the token (as specified in grammar)
        value: Value of the token (redundant, as ``token.value == token`` will always be true)
        start_pos: The index of the token in the text
        line: The line of the token in the text (starting with 1)
        column: The column of the token in the text (starting with 1)
        end_line: The line where the token ends
        end_column: The next column after the end of the token. For example,
            if the token is a single character with a column value of 4,
            end_column will be 5.
        end_pos: the index where the token ends (basically ``start_pos + len(token)``)

*/

class Token {
  constructor(
    type_,
    value,
    start_pos = null,
    line = null,
    column = null,
    end_line = null,
    end_column = null,
    end_pos = null
  ) {
    this.type = type_;
    this.start_pos = start_pos;
    this.value = value;
    this.line = line;
    this.column = column;
    this.end_line = end_line;
    this.end_column = end_column;
    this.end_pos = end_pos;
  }

  update(type_ = null, value = null) {
    return Token.new_borrow_pos(
      type_ !== null ? type_ : this.type,
      value !== null ? value : this.value,
      this
    );
  }

  static new_borrow_pos(type_, value, borrow_t) {
    const cls = this;
    return new cls(
      type_,
      value,
      borrow_t.start_pos,
      borrow_t.line,
      borrow_t.column,
      borrow_t.end_line,
      borrow_t.end_column,
      borrow_t.end_pos
    );
  }

  repr() {
    return format("Token(%r, %r)", this.type, this.value);
  }

  eq(other) {
    if (other instanceof Token && this.type !== other.type) {
      return false;
    }

    return str.__eq__(this, other);
  }

  static get __hash__() {
    return str.__hash__;
  }
}

class LineCounter {
  constructor(newline_char) {
    this.newline_char = newline_char;
    this.char_pos = 0;
    this.line = 1;
    this.column = 1;
    this.line_start_pos = 0;
  }

  eq(other) {
    if (!(other instanceof LineCounter)) {
      return NotImplemented;
    }

    return (
      this.char_pos === other.char_pos &&
      this.newline_char === other.newline_char
    );
  }

  /**
    Consume a token and calculate the new line & column.

        As an optional optimization, set test_newline=False if token doesn't contain a newline.

  */
  feed(token, test_newline = true) {
    let newlines;
    if (test_newline) {
      newlines = str_count(token, this.newline_char);
      if (newlines) {
        this.line += newlines;
        this.line_start_pos =
          this.char_pos + token.lastIndexOf(this.newline_char) + 1;
      }
    }

    this.char_pos += token.length;
    this.column = this.char_pos - this.line_start_pos + 1;
  }
}

class _UnlessCallback {
  constructor(scanner) {
    this.scanner = scanner;
  }

  __call__(t) {
    let _value;
    let res = this.scanner.match(t.value, 0);
    if (res) {
      [_value, t.type] = res;
    }

    return t;
  }
}

const UnlessCallback = callable_class(_UnlessCallback);
class _CallChain {
  constructor(callback1, callback2, cond) {
    this.callback1 = callback1;
    this.callback2 = callback2;
    this.cond = cond;
  }

  __call__(t) {
    let t2 = this.callback1(t);
    return this.cond(t2) ? this.callback2(t) : t2;
  }
}

const CallChain = callable_class(_CallChain);
function _create_unless(terminals, g_regex_flags, re_, use_bytes) {
  let s, unless;
  let tokens_by_type = classify(terminals, (t) => t.pattern.constructor.type);
  let embedded_strs = new Set();
  let callback = {};
  for (const retok of tokens_by_type.get('re') || []) {
    unless = [];
    for (const strtok of tokens_by_type.get('str') || []) {
      if (strtok.priority !== retok.priority) {
        continue;
      }

      s = strtok.pattern.value;
      if (s === _get_match(re_, retok.pattern.to_regexp(), s, g_regex_flags)) {
        unless.push(strtok);
        if (isSubset(new Set(strtok.pattern.flags), new Set(retok.pattern.flags))) {
          embedded_strs.add(strtok);
        }
      }
    }

    if (unless.length) {
      callback[retok.name] = new UnlessCallback(
        new Scanner(
          unless,
          g_regex_flags,
          re_,
          use_bytes,
          true,
        ),
      );
    }
  }

  let new_terminals = terminals
    .filter((t) => !embedded_strs.has(t))
    .map((t) => t);
  return [new_terminals, callback];
}

/**
    Expressions that may indicate newlines in a regexp:
        - newlines (\n)
        - escaped newline (\\n)
        - anything but ([^...])
        - any-char (.) when the flag (?s) exists
        - spaces (\s)

  */
function _regexp_has_newline(r) {
  return (
    r.includes("\n") ||
    r.includes("\\n") ||
    r.includes("\\s") ||
    r.includes("[^") ||
    (r.includes("(?s") && r.includes("."))
  );
}

/**
  Represents the current state of the lexer as it scans the text
    (Lexer objects are only instanciated per grammar, not per text)

*/

class LexerState {
  constructor(text, line_ctr = null, last_token = null) {
    this.text = text;
    this.line_ctr = line_ctr || new LineCounter("\n");
    this.last_token = last_token;
  }

  eq(other) {
    if (!(other instanceof LexerState)) {
      return NotImplemented;
    }

    return (
      this.text === other.text &&
      this.line_ctr === other.line_ctr &&
      this.last_token === other.last_token
    );
  }
}

/**
  A thread that ties a lexer instance and a lexer state, to be used by the parser

*/

class LexerThread {
  constructor(lexer, lexer_state) {
    this.lexer = lexer;
    this.state = lexer_state;
  }

  static from_text(lexer, text) {
    return new this(lexer, new LexerState(text));
  }

  lex(parser_state) {
    return this.lexer.lex(this.state, parser_state);
  }
}

/**
  Lexer interface

    Method Signatures:
        lex(self, lexer_state, parser_state) -> Iterator[Token]

*/

class Lexer extends ABC {
  lex(lexer_state, parser_state) {
    return NotImplemented;
  }
}

function sort_by_key_tuple(arr, key) {
  arr.sort( (a, b) => {
    let ta = key(a)
    let tb = key(b)
    for (let i=0; i<ta.length; i++) {
      if (ta[i] > tb[i]) {
        return 1;
      }
      else if (ta[i] < tb[i]) {
        return -1;
      }
    }
    return 0;
  })
}


class BasicLexer extends Lexer {
  constructor(conf) {
    super();
    let terminals = [...conf.terminals];
    this.re = conf.re_module;
    if (!conf.skip_validation) {
      // Sanitization
      for (const t of terminals) {
        try {
          this.re.compile(t.pattern.to_regexp(), conf.g_regex_flags);
        } catch (e) {
          if (e instanceof this.re.error) {
            throw new LexError(
              format("Cannot compile token %s: %s", t.name, t.pattern)
            );
          } else {
            throw e;
          }
        }
        if (t.pattern.min_width === 0) {
          throw new LexError(
            format(
              "Lexer does not allow zero-width terminals. (%s: %s)",
              t.name,
              t.pattern
            )
          );
        }
      }

      if (!(new Set(conf.ignore) <= new Set(terminals.map((t) => t.name)))) {
        throw new LexError(
          format(
            "Ignore terminals are not defined: %s",
            set_subtract(
              new Set(conf.ignore),
              new Set(terminals.map((t) => t.name))
            )
          )
        );
      }
    }

    // Init
    this.newline_types = frozenset(
      terminals
        .filter((t) => _regexp_has_newline(t.pattern.to_regexp()))
        .map((t) => t.name)
    );
    this.ignore_types = frozenset(conf.ignore);
    sort_by_key_tuple(terminals, (x) => [
        -x.priority,
        -x.pattern.max_width,
        -x.pattern.value.length,
        x.name,
    ]);
    this.terminals = terminals;
    this.user_callbacks = conf.callbacks;
    this.g_regex_flags = conf.g_regex_flags;
    this.use_bytes = conf.use_bytes;
    this.terminals_by_name = conf.terminals_by_name;
    this._scanner = null;
  }

  _build_scanner() {
    let terminals;
    [terminals, this.callback] = _create_unless(
      this.terminals,
      this.g_regex_flags,
      this.re,
      this.use_bytes
    );
    for (const [type_, f] of dict_items(this.user_callbacks)) {
      if (type_ in this.callback) {
        // Already a callback there, probably UnlessCallback
        this.callback[type_] = new CallChain(
          this.callback[type_],
          f,
          (t) => t.type === type_
        );
      } else {
        this.callback[type_] = f;
      }
    }

    this._scanner = new Scanner(
      terminals,
      this.g_regex_flags,
      this.re,
      this.use_bytes
    );
  }

  get scanner() {
    if (this._scanner === null) {
      this._build_scanner();
    }

    return this._scanner;
  }

  match(text, pos) {
    return this.scanner.match(text, pos);
  }

  *lex(state, parser_state) {
    try {
      while (true) {
        yield this.next_token(state, parser_state);
      }
    } catch (e) {
      if (e instanceof EOFError) {
        // pass
      } else {
        throw e;
      }
    }
  }

  next_token(lex_state, parser_state = null) {
    let allowed, res, t, t2, type_, value;
    let line_ctr = lex_state.line_ctr;
    while (line_ctr.char_pos < lex_state.text.length) {
      res = this.match(lex_state.text, line_ctr.char_pos);
      if (!res) {
        allowed = set_subtract(this.scanner.allowed_types, this.ignore_types);
        if (!allowed) {
          allowed = new Set(["<END-OF-FILE>"]);
        }

        throw new UnexpectedCharacters({
          seq: lex_state.text,
          lex_pos: line_ctr.char_pos,
          line: line_ctr.line,
          column: line_ctr.column,
          allowed: allowed,
          token_history: lex_state.last_token && [lex_state.last_token],
          state: parser_state,
          terminals_by_name: this.terminals_by_name,
        });
      }

      let [value, type_] = res;
      if (!this.ignore_types.has(type_)) {
        t = new Token(
          type_,
          value,
          line_ctr.char_pos,
          line_ctr.line,
          line_ctr.column
        );
        line_ctr.feed(value, this.newline_types.has(type_));
        t.end_line = line_ctr.line;
        t.end_column = line_ctr.column;
        t.end_pos = line_ctr.char_pos;
        if (t.type in this.callback) {
          t = this.callback[t.type](t);
          if (!(t instanceof Token)) {
            throw new LexError(
              format("Callbacks must return a token (returned %r)", t)
            );
          }
        }

        lex_state.last_token = t;
        return t;
      } else {
        if (type_ in this.callback) {
          t2 = new Token(
            type_,
            value,
            line_ctr.char_pos,
            line_ctr.line,
            line_ctr.column
          );
          this.callback[type_](t2);
        }

        line_ctr.feed(value, this.newline_types.has(type_));
      }
    }

    // EOF
    throw new EOFError(this);
  }
}

class ContextualLexer extends Lexer {
  constructor({ conf, states, always_accept = [] } = {}) {
    super();
    let accepts, key, lexer, lexer_conf;
    let terminals = [...conf.terminals];
    let terminals_by_name = conf.terminals_by_name;
    let trad_conf = copy(conf);
    trad_conf.terminals = terminals;
    let lexer_by_tokens = new Map();
    this.lexers = {};
    for (let [state, accepts] of dict_items(states)) {
      key = frozenset(accepts);
      if (lexer_by_tokens.has(key)) {
        lexer = lexer_by_tokens.get(key);
      } else {
        accepts = union(new Set(accepts), [
          ...new Set(conf.ignore),
          ...new Set(always_accept),
        ]);
        lexer_conf = copy(trad_conf);
        lexer_conf.terminals = [...accepts]
          .filter((n) => n in terminals_by_name)
          .map((n) => terminals_by_name[n]);
        lexer = new BasicLexer(lexer_conf);
        lexer_by_tokens.set(key, lexer);
      }
      this.lexers[state] = lexer;
    }

    this.root_lexer = new BasicLexer(trad_conf);
  }

  *lex(lexer_state, parser_state) {
    let last_token, lexer, token;
    try {
      while (true) {
        lexer = this.lexers[parser_state.position];
        yield lexer.next_token(lexer_state, parser_state);
      }
    } catch (e) {
      if (e instanceof EOFError) {
        // pass
      } else if (e instanceof UnexpectedCharacters) {
        // In the contextual lexer, UnexpectedCharacters can mean that the terminal is defined, but not in the current context.
        // This tests the input against the global context, to provide a nicer error.
        try {
          last_token = lexer_state.last_token;
          // Save last_token. Calling root_lexer.next_token will change this to the wrong token
          token = this.root_lexer.next_token(lexer_state, parser_state);
          throw new UnexpectedToken({
            token: token,
            expected: e.allowed,
            state: parser_state,
            token_history: [last_token],
            terminals_by_name: this.root_lexer.terminals_by_name,
          });
        } catch (e) {
          if (e instanceof UnexpectedCharacters) {
            throw e;
          } else {
            throw e;
          }
        }
      } else {
        throw e;
      }
    }
  }
}

//
// Common
//

class LexerConf extends Serialize {
  static get __serialize_fields__() {
    return ["terminals", "ignore", "g_regex_flags", "use_bytes", "lexer_type"];
  }
  static get __serialize_namespace__() {
    return [TerminalDef];
  }
  constructor({
    terminals,
    re_module,
    ignore = [],
    postlex = null,
    callbacks = null,
    g_regex_flags = '',
    skip_validation = false,
    use_bytes = false,
  } = {}) {
    super();
    this.terminals = terminals;
    this.terminals_by_name = Object.fromEntries(
      this.terminals.map((t) => [t.name, t])
    );
    this.ignore = ignore;
    this.postlex = postlex;
    this.callbacks = Object.keys(callbacks).length || {};
    this.g_regex_flags = g_regex_flags;
    this.re_module = re_module;
    this.skip_validation = skip_validation;
    this.use_bytes = use_bytes;
    this.lexer_type = null;
  }

  _deserialize() {
    this.terminals_by_name = Object.fromEntries(
      this.terminals.map((t) => [t.name, t])
    );
  }
}

class ParserConf extends Serialize {
  static get __serialize_fields__() {
    return ["rules", "start", "parser_type"];
  }
  constructor(rules, callbacks, start) {
    super();
    this.rules = rules;
    this.callbacks = callbacks;
    this.start = start;
    this.parser_type = null;
  }
}

//
// Parse Tree Builder
//

class _ExpandSingleChild {
  constructor(node_builder) {
    this.node_builder = node_builder;
  }

  __call__(children) {
    if (children.length === 1) {
      return children[0];
    } else {
      return this.node_builder(children);
    }
  }
}

const ExpandSingleChild = callable_class(_ExpandSingleChild);
class _PropagatePositions {
  constructor(node_builder, node_filter = null) {
    this.node_builder = node_builder;
    this.node_filter = node_filter;
  }

  __call__(children) {
    let first_meta, last_meta, res_meta;
    let res = this.node_builder(children);
    if (res instanceof Tree) {
      // Calculate positions while the tree is streaming, according to the rule:
      // - nodes start at the start of their first child's container,
      //   and end at the end of their last child's container.
      // Containers are nodes that take up space in text, but have been inlined in the tree.

      res_meta = res.meta;
      first_meta = this._pp_get_meta(children);
      if (first_meta !== null) {
        if (!("line" in res_meta)) {
          // meta was already set, probably because the rule has been inlined (e.g. `?rule`)
          res_meta.line =
            (first_meta && first_meta["container_line"]) || first_meta.line;
          res_meta.column =
            (first_meta && first_meta["container_column"]) || first_meta.column;
          res_meta.start_pos =
            (first_meta && first_meta["container_start_pos"]) ||
            first_meta.start_pos;
          res_meta.empty = false;
        }

        res_meta.container_line =
          (first_meta && first_meta["container_line"]) || first_meta.line;
        res_meta.container_column =
          (first_meta && first_meta["container_column"]) || first_meta.column;
      }

      last_meta = this._pp_get_meta([...children].reverse());
      if (last_meta !== null) {
        if (!("end_line" in res_meta)) {
          res_meta.end_line =
            (last_meta && last_meta["container_end_line"]) ||
            last_meta.end_line;
          res_meta.end_column =
            (last_meta && last_meta["container_end_column"]) ||
            last_meta.end_column;
          res_meta.end_pos =
            (last_meta && last_meta["container_end_pos"]) || last_meta.end_pos;
          res_meta.empty = false;
        }

        res_meta.container_end_line =
          (last_meta && last_meta["container_end_line"]) || last_meta.end_line;
        res_meta.container_end_column =
          (last_meta && last_meta["container_end_column"]) ||
          last_meta.end_column;
      }
    }

    return res;
  }

  _pp_get_meta(children) {
    for (const c of children) {
      if (this.node_filter !== null && !this.node_filter(c)) {
        continue;
      }

      if (c instanceof Tree) {
        if (!c.meta.empty) {
          return c.meta;
        }
      } else if (c instanceof Token) {
        return c;
      }
    }
  }
}

const PropagatePositions = callable_class(_PropagatePositions);
function make_propagate_positions(option) {
  if (callable(option)) {
    return partial({
      unknown_param_0: PropagatePositions,
      node_filter: option,
    });
  } else if (option === true) {
    return PropagatePositions;
  } else if (option === false) {
    return null;
  }

  throw new ConfigurationError(
    format("Invalid option for propagate_positions: %r", option)
  );
}

class _ChildFilter {
  constructor(to_include, append_none, node_builder) {
    this.node_builder = node_builder;
    this.to_include = to_include;
    this.append_none = append_none;
  }

  __call__(children) {
    let filtered = [];
    for (const [i, to_expand, add_none] of this.to_include) {
      if (add_none) {
        filtered.push(...list_repeat([null], add_none));
      }

      if (to_expand) {
        filtered.push(...children[i].children);
      } else {
        filtered.push(children[i]);
      }
    }

    if (this.append_none) {
      filtered.push(...list_repeat([null], this.append_none));
    }

    return this.node_builder(filtered);
  }
}

const ChildFilter = callable_class(_ChildFilter);
/**
  Optimized childfilter for LALR (assumes no duplication in parse tree, so it's safe to change it)
*/

class _ChildFilterLALR extends _ChildFilter {
  __call__(children) {
    let filtered = [];
    for (const [i, to_expand, add_none] of this.to_include) {
      if (add_none) {
        filtered.push(...list_repeat([null], add_none));
      }

      if (to_expand) {
        if (filtered.length) {
          filtered.push(...children[i].children);
        } else {
          // Optimize for left-recursion
          filtered = children[i].children;
        }
      } else {
        filtered.push(children[i]);
      }
    }

    if (this.append_none) {
      filtered.push(...list_repeat([null], this.append_none));
    }

    return this.node_builder(filtered);
  }
}

const ChildFilterLALR = callable_class(_ChildFilterLALR);
/**
  Optimized childfilter for LALR (assumes no duplication in parse tree, so it's safe to change it)
*/

class _ChildFilterLALR_NoPlaceholders extends _ChildFilter {
  constructor(to_include, node_builder) {
    super();
    this.node_builder = node_builder;
    this.to_include = to_include;
  }

  __call__(children) {
    let filtered = [];
    for (const [i, to_expand] of this.to_include) {
      if (to_expand) {
        if (filtered.length) {
          filtered.push(...children[i].children);
        } else {
          // Optimize for left-recursion
          filtered = children[i].children;
        }
      } else {
        filtered.push(children[i]);
      }
    }

    return this.node_builder(filtered);
  }
}

const ChildFilterLALR_NoPlaceholders = callable_class(
  _ChildFilterLALR_NoPlaceholders
);
function _should_expand(sym) {
  return !sym.is_term && sym.name.startsWith("_");
}

function maybe_create_child_filter(
  expansion,
  keep_all_tokens,
  ambiguous,
  _empty_indices
) {
  let empty_indices, s;
  // Prepare empty_indices as: How many Nones to insert at each index?
  if (_empty_indices.length) {
    s = _empty_indices.map((b) => (0 + b).toString()).join("");
    empty_indices = s.split("0").map((ones) => ones.length);
  } else {
    empty_indices = list_repeat([0], expansion.length + 1);
  }
  let to_include = [];
  let nones_to_add = 0;
  for (const [i, sym] of enumerate(expansion)) {
    nones_to_add += empty_indices[i];
    if (keep_all_tokens || !(sym.is_term && sym.filter_out)) {
      to_include.push([i, _should_expand(sym), nones_to_add]);
      nones_to_add = 0;
    }
  }

  nones_to_add += empty_indices[expansion.length];
  if (
    _empty_indices.length ||
    to_include.length < expansion.length ||
    any(to_include.map(([i, to_expand, _]) => to_expand))
  ) {
    if ((_empty_indices.length || ambiguous).length) {
      return partial(
        ambiguous ? ChildFilter : ChildFilterLALR,
        to_include,
        nones_to_add
      );
    } else {
      // LALR without placeholders
      return partial(
        ChildFilterLALR_NoPlaceholders,
        to_include.map(([i, x, _]) => [i, x])
      );
    }
  }
}


/**

    Propagate ambiguous intermediate nodes and their derivations up to the
    current rule.

    In general, converts

    rule
      _iambig
        _inter
          someChildren1
          ...
        _inter
          someChildren2
          ...
      someChildren3
      ...

    to

    _ambig
      rule
        someChildren1
        ...
        someChildren3
        ...
      rule
        someChildren2
        ...
        someChildren3
        ...
      rule
        childrenFromNestedIambigs
        ...
        someChildren3
        ...
      ...

    propagating up any nested '_iambig' nodes along the way.

*/

function inplace_transformer(func) {
  function f(children) {
    // function name in a Transformer is a rule name.
    let tree = new Tree(func.name, children);
    return func(tree);
  }

  f = wraps(func)(f);
  return f;
}

function apply_visit_wrapper(func, name, wrapper) {
  if (wrapper === _vargs_meta || wrapper === _vargs_meta_inline) {
    throw new NotImplementedError(
      "Meta args not supported for internal transformer"
    );
  }

  function f(children) {
    return wrapper(func, name, children, null);
  }

  f = wraps(func)(f);
  return f;
}

class ParseTreeBuilder {
  constructor(
    rules,
    tree_class,
    propagate_positions = false,
    ambiguous = false,
    maybe_placeholders = false
  ) {
    this.tree_class = tree_class;
    this.propagate_positions = propagate_positions;
    this.ambiguous = ambiguous;
    this.maybe_placeholders = maybe_placeholders;
    this.rule_builders = [...this._init_builders(rules)];
  }

  *_init_builders(rules) {
    let expand_single_child, keep_all_tokens, options, wrapper_chain;
    let propagate_positions = make_propagate_positions(
      this.propagate_positions
    );
    for (const rule of rules) {
      options = rule.options;
      keep_all_tokens = options.keep_all_tokens;
      expand_single_child = options.expand1;
      wrapper_chain = [
        ...filter(null, [
          expand_single_child && !rule.alias && ExpandSingleChild,
          maybe_create_child_filter(
            rule.expansion,
            keep_all_tokens,
            this.ambiguous,
            this.maybe_placeholders ? options.empty_indices : []
          ),
          propagate_positions,
        ]),
      ];
      yield [rule, wrapper_chain];
    }
  }

  create_callback(transformer = null) {
    let f, user_callback_name, wrapper;
    let callbacks = new Map();
    for (const [rule, wrapper_chain] of this.rule_builders) {
      user_callback_name =
        rule.alias || rule.options.template_source || rule.origin.name;
      if (transformer && transformer[user_callback_name]) {
        f = transformer && transformer[user_callback_name];
        wrapper = (f && f["visit_wrapper"]) || null;
        if (wrapper !== null) {
          f = apply_visit_wrapper(f, user_callback_name, wrapper);
        } else if (transformer instanceof Transformer_InPlace) {
          f = inplace_transformer(f);
        }
      } else {
        f = partial(this.tree_class, user_callback_name);
      }
      for (const w of wrapper_chain) {
        f = w(f);
      }

      if (callbacks.has(rule)) {
        throw new GrammarError(format("Rule '%s' already exists", rule));
      }

      callbacks.set(rule, f);
    }

    return callbacks;
  }
}

//
// Lalr Parser
//

class LALR_Parser extends Serialize {
  constructor({ parser_conf, debug = false } = {}) {
    super();
    let analysis = new LALR_Analyzer({
      unknown_param_0: parser_conf,
      debug: debug,
    });
    analysis.compute_lalr();
    let callbacks = parser_conf.callbacks;
    this._parse_table = analysis.parse_table;
    this.parser_conf = parser_conf;
    this.parser = new _Parser(analysis.parse_table, callbacks, debug);
  }

  static deserialize(data, memo, callbacks, debug = false) {
    const cls = this;
    let inst = new_object(cls);
    inst._parse_table = IntParseTable.deserialize(data, memo);
    inst.parser = new _Parser(inst._parse_table, callbacks, debug);
    return inst;
  }

  serialize(memo) {
    return this._parse_table.serialize(memo);
  }

  parse_interactive(lexer, start) {
    return this.parser.parse({
      lexer: lexer,
      start: start,
      start_interactive: true,
    });
  }

  parse({lexer, start, on_error = null} = {}) {
    let e, p, s;
    try {
      return this.parser.parse({ lexer: lexer, start: start });
    } catch (e) {
      if (e instanceof UnexpectedInput) {
        if (on_error === null) {
          throw e;
        }

        while (true) {
          if (e instanceof UnexpectedCharacters) {
            s = e.interactive_parser.lexer_thread.state;
            p = s.line_ctr.char_pos;
          }

          if (!on_error(e)) {
            throw e;
          }

          if (e instanceof UnexpectedCharacters) {
            // If user didn't change the character position, then we should
            if (p === s.line_ctr.char_pos) {
              s.line_ctr.feed(s.text.slice(p, p + 1));
            }
          }

          try {
            return e.interactive_parser.resume_parse();
          } catch (e2) {
            if (e2 instanceof UnexpectedToken) {
              if (
                e instanceof UnexpectedToken &&
                e.token.type === e2.token.type &&
                e2.token.type === "$END" &&
                e.interactive_parser.eq(e2.interactive_parser)
              ) {
                // Prevent infinite loop
                throw e2;
              }

              e = e2;
            } else if (e2 instanceof UnexpectedCharacters) {
              e = e2;
            } else {
              throw e2;
            }
          }
        }
      } else {
        throw e;
      }
    }
  }
}

class ParseConf {
  constructor(parse_table, callbacks, start) {
    this.parse_table = parse_table;
    this.start_state = this.parse_table.start_states[start];
    this.end_state = this.parse_table.end_states[start];
    this.states = this.parse_table.states;
    this.callbacks = callbacks;
    this.start = start;
  }
}

class ParserState {
  constructor(parse_conf, lexer, state_stack = null, value_stack = null) {
    this.parse_conf = parse_conf;
    this.lexer = lexer;
    this.state_stack = state_stack || [this.parse_conf.start_state];
    this.value_stack = value_stack || [];
  }

  get position() {
    return last_item(this.state_stack);
  }

  // Necessary for match_examples() to work

  eq(other) {
    if (!(other instanceof ParserState)) {
      return NotImplemented;
    }

    return (
      this.state_stack.length === other.state_stack.length &&
      this.position === other.position
    );
  }

  copy() {
    return copy(this);
  }

  feed_token(token, is_end = false) {
    let _action, action, arg, expected, new_state, rule, s, size, state, value;
    let state_stack = this.state_stack;
    let value_stack = this.value_stack;
    let states = this.parse_conf.states;
    let end_state = this.parse_conf.end_state;
    let callbacks = this.parse_conf.callbacks;
    while (true) {
      state = last_item(state_stack);
      if ( token.type in states[state] ) {
        [action, arg] = states[state][token.type];
      } else {
        expected = new Set(
          dict_keys(states[state])
            .filter((s) => isupper(s))
            .map((s) => s)
        );
        throw new UnexpectedToken({
          token: token,
          expected: expected,
          state: this,
          interactive_parser: null,
        });
      }
      if (action === Shift) {
        // shift once and return

        state_stack.push(arg);
        value_stack.push(
          !(token.type in callbacks) ? token : callbacks[token.type](token)
        );
        return;
      } else {
        // reduce+shift as many times as necessary
        rule = arg;
        size = rule.expansion.length;
        if (size) {
          s = value_stack.slice(-size);
          state_stack.splice(-size);
          value_stack.splice(-size);
        } else {
          s = [];
        }
        value = callbacks.get(rule)(s);
        [_action, new_state] = states[last_item(state_stack)][rule.origin.name];
        state_stack.push(new_state);
        value_stack.push(value);
        if (is_end && last_item(state_stack) === end_state) {
          return last_item(value_stack);
        }
      }
    }
  }
}

class _Parser {
  constructor(parse_table, callbacks, debug = false) {
    this.parse_table = parse_table;
    this.callbacks = callbacks;
    this.debug = debug;
  }

  parse({
    lexer,
    start,
    value_stack = null,
    state_stack = null,
    start_interactive = false,
  } = {}) {
    let parse_conf = new ParseConf(this.parse_table, this.callbacks, start);
    let parser_state = new ParserState(
      parse_conf,
      lexer,
      state_stack,
      value_stack
    );
    if (start_interactive) {
      return new InteractiveParser(this, parser_state, parser_state.lexer);
    }

    return this.parse_from_state(parser_state);
  }

  parse_from_state(state) {
    let end_token, token;
    // Main LALR-parser loop
    try {
      token = null;
      for (token of state.lexer.lex(state)) {
        state.feed_token(token);
      }

      end_token = token
        ? Token.new_borrow_pos("$END", "", token)
        : new Token("$END", "", 0, 1, 1);
      return state.feed_token(end_token, true);
    } catch (e) {
      if (e instanceof UnexpectedInput) {
        try {
          e.interactive_parser = new InteractiveParser(
            this,
            state,
            state.lexer
          );
        } catch (e) {
          if (e instanceof ReferenceError) {
            // pass
          } else {
            throw e;
          }
        }
        throw e;
      } else if (e instanceof Error) {
        if (this.debug) {
          console.log("");
          console.log("STATE STACK DUMP");
          console.log("----------------");
          for (const [i, s] of enumerate(state.state_stack)) {
            console.log(format("%d)", i), s);
          }

          console.log("");
        }

        throw e;
      } else {
        throw e;
      }
    }
  }
}

//
// Lalr Interactive Parser
//

// This module provides a LALR interactive parser, which is used for debugging and error handling

/**
  InteractiveParser gives you advanced control over parsing and error handling when parsing with LALR.

    For a simpler interface, see the ``on_error`` argument to ``Lark.parse()``.

*/

class InteractiveParser {
  constructor(parser, parser_state, lexer_thread) {
    this.parser = parser;
    this.parser_state = parser_state;
    this.lexer_thread = lexer_thread;
    this.result = null;
  }

  /**
    Feed the parser with a token, and advance it to the next state, as if it received it from the lexer.

        Note that ``token`` has to be an instance of ``Token``.

  */
  feed_token(token) {
    return this.parser_state.feed_token(token, token.type === "$END");
  }

  /**
    Step through the different stages of the parse, by reading tokens from the lexer
        and feeding them to the parser, one per iteration.

        Returns an iterator of the tokens it encounters.

        When the parse is over, the resulting tree can be found in ``InteractiveParser.result``.

  */
  *iter_parse() {
    for (const token of this.lexer_thread.lex(this.parser_state)) {
      yield token;
      this.result = this.feed_token(token);
    }
  }

  /**
    Try to feed the rest of the lexer state into the interactive parser.

        Note that this modifies the instance in place and does not feed an '$END' Token

  */
  exhaust_lexer() {
    return [...this.iter_parse()];
  }

  /**
    Feed a '$END' Token. Borrows from 'last_token' if given.
  */
  feed_eof(last_token = null) {
    let eof =
      last_token !== null
        ? Token.new_borrow_pos("$END", "", last_token)
        : new Token("$END", "", 0, 1, 1);
    return this.feed_token(eof);
  }

  copy() {
    return copy(this);
  }

  eq(other) {
    if (!(other instanceof InteractiveParser)) {
      return false;
    }

    return (
      this.parser_state === other.parser_state &&
      this.lexer_thread === other.lexer_thread
    );
  }

  /**
    Convert to an ``ImmutableInteractiveParser``.
  */
  as_immutable() {
    let p = copy(this);
    return new ImmutableInteractiveParser(
      p.parser,
      p.parser_state,
      p.lexer_thread
    );
  }

  /**
    Print the output of ``choices()`` in a way that's easier to read.
  */
  pretty() {
    let out = ["Parser choices:"];
    for (const [k, v] of dict_items(this.choices())) {
      out.push(format("\t- %s -> %r", k, v));
    }

    out.push(format("stack size: %s", this.parser_state.state_stack.length));
    return out.join("\n");
  }

  /**
    Returns a dictionary of token types, matched to their action in the parser.

        Only returns token types that are accepted by the current state.

        Updated by ``feed_token()``.

  */
  choices() {
    return this.parser_state.parse_conf.parse_table.states[
      this.parser_state.position
    ];
  }

  /**
    Returns the set of possible tokens that will advance the parser into a new valid state.
  */
  accepts() {
    let new_cursor;
    let accepts = new Set();
    for (const t of this.choices()) {
      if (isupper(t)) {
        // is terminal?
        new_cursor = copy(this);
        let exc = null;
        try {
          new_cursor.feed_token(new Token(t, ""));
        } catch (e) {
          exc = e;
          if (e instanceof UnexpectedToken) {
            // pass
          } else {
            throw e;
          }
        }
        if (!exc) {
          accepts.add(t);
        }
      }
    }

    return accepts;
  }

  /**
    Resume automated parsing from the current state.
  */
  resume_parse() {
    return this.parser.parse_from_state(this.parser_state);
  }
}

/**
  Same as ``InteractiveParser``, but operations create a new instance instead
    of changing it in-place.

*/

class ImmutableInteractiveParser extends InteractiveParser {
  result = null;
  feed_token(token) {
    let c = copy(this);
    c.result = InteractiveParser.feed_token(c, token);
    return c;
  }

  /**
    Try to feed the rest of the lexer state into the parser.

        Note that this returns a new ImmutableInteractiveParser and does not feed an '$END' Token
  */
  exhaust_lexer() {
    let cursor = this.as_mutable();
    cursor.exhaust_lexer();
    return cursor.as_immutable();
  }

  /**
    Convert to an ``InteractiveParser``.
  */
  as_mutable() {
    let p = copy(this);
    return new InteractiveParser(p.parser, p.parser_state, p.lexer_thread);
  }
}

//
// Lalr Analysis
//

class Action {
  constructor(name) {
    this.name = name;
  }

  repr() {
    return this.toString();
  }
}

var Shift = new Action("Shift");
var Reduce = new Action("Reduce");
class ParseTable {
  constructor(states, start_states, end_states) {
    this.states = states;
    this.start_states = start_states;
    this.end_states = end_states;
  }

  serialize(memo) {
    let tokens = new Enumerator();
    let states = Object.fromEntries(
      dict_items(this.states).map(([state, actions]) => [
        state,
        Object.fromEntries(
          dict_items(actions).map(([token, [action, arg]]) => [
            dict_get(tokens, token),
            action === Reduce ? [1, arg.serialize(memo)] : [0, arg],
          ])
        ),
      ])
    );
    return {
      tokens: tokens.reversed(),
      states: states,
      start_states: this.start_states,
      end_states: this.end_states,
    };
  }

  static deserialize(data, memo) {
    const cls = this;
    let tokens = data["tokens"];
    let states = Object.fromEntries(
      dict_items(data["states"]).map(([state, actions]) => [
        state,
        Object.fromEntries(
          dict_items(actions).map(([token, [action, arg]]) => [
            tokens[token],
            action === 1 ? [Reduce, Rule.deserialize(arg, memo)] : [Shift, arg],
          ])
        ),
      ])
    );
    return new cls(states, data["start_states"], data["end_states"]);
  }
}

class IntParseTable extends ParseTable {
  static from_ParseTable(parse_table) {
    const cls = this;
    let enum_ = [...parse_table.states];
    let state_to_idx = Object.fromEntries(
      enumerate(enum_).map(([i, s]) => [s, i])
    );
    let int_states = {};
    for (let [s, la] of dict_items(parse_table.states)) {
      la = Object.fromEntries(
        dict_items(la).map(([k, v]) => [
          k,
          v[0] === Shift ? [v[0], state_to_idx[v[1]]] : v,
        ])
      );
      int_states[state_to_idx[s]] = la;
    }

    let start_states = Object.fromEntries(
      dict_items(parse_table.start_states).map(([start, s]) => [
        start,
        state_to_idx[s],
      ])
    );
    let end_states = Object.fromEntries(
      dict_items(parse_table.end_states).map(([start, s]) => [
        start,
        state_to_idx[s],
      ])
    );
    return new cls(int_states, start_states, end_states);
  }
}

//
// Parser Frontends
//

function _wrap_lexer(lexer_class) {
  let future_interface =
    (lexer_class && lexer_class["__future_interface__"]) || false;
  if (future_interface) {
    return lexer_class;
  } else {
    class CustomLexerWrapper extends Lexer {
      constructor(lexer_conf) {
        super();
        this.lexer = lexer_class(lexer_conf);
      }

      lex(lexer_state, parser_state) {
        return this.lexer.lex(lexer_state.text);
      }
    }

    return CustomLexerWrapper;
  }
}

class MakeParsingFrontend {
  constructor(parser_type, lexer_type) {
    this.parser_type = parser_type;
    this.lexer_type = lexer_type;
  }

  deserialize(data, memo, lexer_conf, callbacks, options) {
    let parser_conf = ParserConf.deserialize(data["parser_conf"], memo);
    let parser = LALR_Parser.deserialize(
      data["parser"],
      memo,
      callbacks,
      options.debug
    );
    parser_conf.callbacks = callbacks;
    return new ParsingFrontend({
      lexer_conf: lexer_conf,
      parser_conf: parser_conf,
      options: options,
      parser: parser,
    });
  }
}

// ... Continued later in the module

function _deserialize_parsing_frontend(
  data,
  memo,
  lexer_conf,
  callbacks,
  options
) {
  let parser_conf = ParserConf.deserialize(data["parser_conf"], memo);
  let parser = LALR_Parser.deserialize(data["parser"], memo, callbacks, options.debug);
  parser_conf.callbacks = callbacks;
  return new ParsingFrontend({
    lexer_conf: lexer_conf,
    parser_conf: parser_conf,
    options: options,
    parser: parser,
  });
}

var _parser_creators = {}

class ParsingFrontend extends Serialize {
  static get __serialize_fields__() {
    return ["lexer_conf", "parser_conf", "parser"];
  }
  constructor({ lexer_conf, parser_conf, options, parser = null } = {}) {
    super();
    let create_lexer, create_parser;
    this.parser_conf = parser_conf;
    this.lexer_conf = lexer_conf;
    this.options = options;
    // Set-up parser
    if (parser) {
      // From cache
      this.parser = parser;
    } else {
      create_parser = dict_get(_parser_creators, parser_conf.parser_type);
      this.parser = create_parser(lexer_conf, parser_conf, options);
    }
    // Set-up lexer
    let lexer_type = lexer_conf.lexer_type;
    this.skip_lexer = false;
    if (["dynamic", "dynamic_complete"].includes(lexer_type)) {
      this.skip_lexer = true;
      return;
    }

    const lexers = {
        basic: create_basic_lexer,
        contextual: create_contextual_lexer
    }
    if (lexer_type in lexers) {
      create_lexer = lexers[lexer_type];
      this.lexer = create_lexer(
        lexer_conf,
        this.parser,
        lexer_conf.postlex,
        options
      );
    } else {
      this.lexer = _wrap_lexer(lexer_type)(lexer_conf);
    }
    if (lexer_conf.postlex) {
      this.lexer = new PostLexConnector(this.lexer, lexer_conf.postlex);
    }
  }

  _verify_start(start = null) {
    let start_decls;
    if (start === null) {
      start_decls = this.parser_conf.start;
      if (start_decls.length > 1) {
        throw new ConfigurationError(
          "Lark initialized with more than 1 possible start rule. Must specify which start rule to parse",
          start_decls
        );
      }

      [start] = start_decls;
    } else if (!(this.parser_conf.start.includes(start))) {
      throw new ConfigurationError(
        format(
          "Unknown start rule %s. Must be one of %r",
          start,
          this.parser_conf.start
        )
      );
    }

    return start;
  }

  _make_lexer_thread(text) {
    return this.skip_lexer ? text : LexerThread.from_text(this.lexer, text);
  }

  parse(text, start = null, on_error = null) {
    let chosen_start = this._verify_start(start);
    let kw = on_error === null ? {} : { on_error: on_error };
    let stream = this._make_lexer_thread(text);
    return this.parser.parse({
      lexer: stream,
      start: chosen_start,
      ...kw,
    });
  }

  parse_interactive(text = null, start = null) {
    let chosen_start = this._verify_start(start);
    if (this.parser_conf.parser_type !== "lalr") {
      throw new ConfigurationError(
        "parse_interactive() currently only works with parser='lalr' "
      );
    }

    let stream = this._make_lexer_thread(text);
    return this.parser.parse_interactive(stream, chosen_start);
  }
}

function _validate_frontend_args(parser, lexer) {
  let expected;
  assert_config(parser, ["lalr", "earley", "cyk"]);
  if (!(typeof lexer === "object")) {
    // not custom lexer?
    expected = {
      lalr: ["basic", "contextual"],
      earley: ["basic", "dynamic", "dynamic_complete"],
      cyk: ["basic"],
    }[parser];
    assert_config(
      lexer,
      expected,
      format(
        "Parser %r does not support lexer %%r, expected one of %%s",
        parser
      )
    );
  }
}

function _get_lexer_callbacks(transformer, terminals) {
  let callback;
  let result = {};
  for (const terminal of terminals) {
    callback = (transformer && transformer[terminal.name]) || null;
    if (callback !== null) {
      result[terminal.name] = callback;
    }
  }

  return result;
}

class PostLexConnector {
  constructor(lexer, postlexer) {
    this.lexer = lexer;
    this.postlexer = postlexer;
  }

  lex(lexer_state, parser_state) {
    let i = this.lexer.lex(lexer_state, parser_state);
    return this.postlexer.process(i);
  }
}

function create_basic_lexer(lexer_conf, parser, postlex, options) {
  return new BasicLexer(lexer_conf);
}

function create_contextual_lexer(lexer_conf, parser, postlex, options) {
  let states = Object.fromEntries(
    dict_items(parser._parse_table.states).map(([idx, t]) => [
      idx,
      [...dict_keys(t)],
    ])
  );
  let always_accept = postlex ? postlex.always_accept : [];
  return new ContextualLexer({
    conf: lexer_conf,
    states: states,
    always_accept: always_accept,
  });
}

function create_lalr_parser(lexer_conf, parser_conf, options = null) {
  let debug = options ? options.debug : false;
  return new LALR_Parser({ parser_conf: parser_conf, debug: debug });
}

_parser_creators["lalr"] = create_lalr_parser;

//
// Lark
//

class PostLex extends ABC {
  process(stream) {
    return stream;
  }

  always_accept = [];
}

/**
  Specifies the options for Lark


*/

class LarkOptions extends Serialize {
  OPTIONS_DOC = `
    **===  General Options  ===**

    start
            The start symbol. Either a string, or a list of strings for multiple possible starts (Default: "start")
    debug
            Display debug information and extra warnings. Use only when debugging (Default: \`\`False\`\`)
            When used with Earley, it generates a forest graph as "sppf.png", if 'dot' is installed.
    transformer
            Applies the transformer to every parse tree (equivalent to applying it after the parse, but faster)
    propagate_positions
            Propagates (line, column, end_line, end_column) attributes into all tree branches.
            Accepts \`\`False\`\`, \`\`True\`\`, or a callable, which will filter which nodes to ignore when propagating.
    maybe_placeholders
            When \`\`True\`\`, the \`\`[]\`\` operator returns \`\`None\`\` when not matched.
            When \`\`False\`\`,  \`\`[]\`\` behaves like the \`\`?\`\` operator, and returns no value at all.
            (default= \`\`True\`\`)
    cache
            Cache the results of the Lark grammar analysis, for x2 to x3 faster loading. LALR only for now.

            - When \`\`False\`\`, does nothing (default)
            - When \`\`True\`\`, caches to a temporary file in the local directory
            - When given a string, caches to the path pointed by the string
    regex
            When True, uses the \`\`regex\`\` module instead of the stdlib \`\`re\`\`.
    g_regex_flags
            Flags that are applied to all terminals (both regex and strings)
    keep_all_tokens
            Prevent the tree builder from automagically removing "punctuation" tokens (Default: \`\`False\`\`)
    tree_class
            Lark will produce trees comprised of instances of this class instead of the default \`\`lark.Tree\`\`.

    **=== Algorithm Options ===**

    parser
            Decides which parser engine to use. Accepts "earley" or "lalr". (Default: "earley").
            (there is also a "cyk" option for legacy)
    lexer
            Decides whether or not to use a lexer stage

            - "auto" (default): Choose for me based on the parser
            - "basic": Use a basic lexer
            - "contextual": Stronger lexer (only works with parser="lalr")
            - "dynamic": Flexible and powerful (only with parser="earley")
            - "dynamic_complete": Same as dynamic, but tries *every* variation of tokenizing possible.
    ambiguity
            Decides how to handle ambiguity in the parse. Only relevant if parser="earley"

            - "resolve": The parser will automatically choose the simplest derivation
              (it chooses consistently: greedy for tokens, non-greedy for rules)
            - "explicit": The parser will return all derivations wrapped in "_ambig" tree nodes (i.e. a forest).
            - "forest": The parser will return the root of the shared packed parse forest.

    **=== Misc. / Domain Specific Options ===**

    postlex
            Lexer post-processing (Default: \`\`None\`\`) Only works with the basic and contextual lexers.
    priority
            How priorities should be evaluated - "auto", \`\`None\`\`, "normal", "invert" (Default: "auto")
    lexer_callbacks
            Dictionary of callbacks for the lexer. May alter tokens during lexing. Use with caution.
    use_bytes
            Accept an input of type \`\`bytes\`\` instead of \`\`str\`\`.
    edit_terminals
            A callback for editing the terminals before parse.
    import_paths
            A List of either paths or loader functions to specify from where grammars are imported
    source_path
            Override the source of from where the grammar was loaded. Useful for relative imports and unconventional grammar loading
    **=== End of Options ===**
    `;
  // Adding a new option needs to be done in multiple places:
  // - In the dictionary below. This is the primary truth of which options `Lark.__init__` accepts
  // - In the docstring above. It is used both for the docstring of `LarkOptions` and `Lark`, and in readthedocs
  // - As an attribute of `LarkOptions` above
  // - Potentially in `_LOAD_ALLOWED_OPTIONS` below this class, when the option doesn't change how the grammar is loaded
  // - Potentially in `lark.tools.__init__`, if it makes sense, and it can easily be passed as a cmd argument
  _defaults = {
    debug: false,
    keep_all_tokens: false,
    tree_class: null,
    cache: false,
    postlex: null,
    parser: "earley",
    lexer: "auto",
    transformer: null,
    start: "start",
    priority: "auto",
    ambiguity: "auto",
    regex: false,
    propagate_positions: false,
    lexer_callbacks: {},
    maybe_placeholders: true,
    edit_terminals: null,
    g_regex_flags: '',
    use_bytes: false,
    import_paths: [],
    source_path: null,
    _plugins: null,
  };
  constructor(options_dict) {
    super();
    let value;
    let o = dict(options_dict);
    let options = this;
    for (const [name, default_] of dict_items(this._defaults)) {
      if (name in o) {
        value = dict_pop(o, name);
        if (
          typeof default_ === "boolean" &&
          !["cache", "use_bytes", "propagate_positions"].includes(name)
        ) {
          value = bool(value);
        }
      } else {
        value = default_;
      }
      options[name] = value;
    }

    if (typeof options["start"] === "string") {
      options["start"] = [options["start"]];
    }

    this["options"] = options;
    assert_config(this.parser, ["earley", "lalr", "cyk", null]);
    if (this.parser === "earley" && this.transformer) {
      throw new ConfigurationError(
        "Cannot specify an embedded transformer when using the Earley algorithm. " +
          "Please use your transformer on the resulting parse tree, or use a different algorithm (i.e. LALR)"
      );
    }

    if (Object.keys(o).length) {
      throw new ConfigurationError(format("Unknown options: %s", dict_keys(o)));
    }
  }

  serialize(memo) {
    return this.options;
  }

  static deserialize(data, memo) {
    const cls = this;
    return new cls(data);
  }
}

// Options that can be passed to the Lark parser, even when it was loaded from cache/standalone.
// These options are only used outside of `load_grammar`.
var _LOAD_ALLOWED_OPTIONS = new Set([
  "postlex",
  "transformer",
  "lexer_callbacks",
  "use_bytes",
  "debug",
  "g_regex_flags",
  "regex",
  "propagate_positions",
  "tree_class",
]);
var _VALID_PRIORITY_OPTIONS = ["auto", "normal", "invert", null];
var _VALID_AMBIGUITY_OPTIONS = ["auto", "resolve", "explicit", "forest"];
/**
  Main interface for the library.

    It's mostly a thin wrapper for the many different parsers, and for the tree constructor.

    Parameters:
        grammar: a string or file-object containing the grammar spec (using Lark's ebnf syntax)
        options: a dictionary controlling various aspects of Lark.

    Example:
        >>> Lark(r'''start: "foo" ''')
        Lark(...)

*/

class Lark extends Serialize {
  static get __serialize_fields__() {
    return ["parser", "rules", "options"];
  }
  _build_lexer(dont_ignore = false) {
    let lexer_conf = this.lexer_conf;
    if (dont_ignore) {
      lexer_conf = copy(lexer_conf);
      lexer_conf.ignore = [];
    }

    return new BasicLexer(lexer_conf);
  }

  _prepare_callbacks() {
    this._callbacks = new Map();
    // we don't need these callbacks if we aren't building a tree
    if (this.options.ambiguity !== "forest") {
      this._parse_tree_builder = new ParseTreeBuilder(
        this.rules,
        this.options.tree_class || make_constructor(Tree),
        this.options.propagate_positions,
        this.options.parser !== "lalr" && this.options.ambiguity === "explicit",
        this.options.maybe_placeholders
      );
      this._callbacks = this._parse_tree_builder.create_callback(
        this.options.transformer
      );
    }

    dict_update(
      this._callbacks,
      _get_lexer_callbacks(this.options.transformer, this.terminals)
    );
  }

  /**
    Saves the instance into the given file object

        Useful for caching and multiprocessing.

  */
  /**
    Loads an instance from the given file object

        Useful for caching and multiprocessing.

  */
  _deserialize_lexer_conf(data, memo, options) {
    let lexer_conf = LexerConf.deserialize(data["lexer_conf"], memo);
    lexer_conf.callbacks = options.lexer_callbacks || {};
    lexer_conf.re_module = options.regex ? regex : re;
    lexer_conf.use_bytes = options.use_bytes;
    lexer_conf.g_regex_flags = options.g_regex_flags || '';
    lexer_conf.skip_validation = true;
    lexer_conf.postlex = options.postlex;
    return lexer_conf;
  }

  _load({ f, ...kwargs } = {}) {
    let d;
    if (is_dict(f)) {
      d = f;
    } else {
      d = pickle.load(f);
    }
    let memo_json = d["memo"];
    let data = d["data"];
    let memo = SerializeMemoizer.deserialize(
      memo_json,
      { Rule: Rule, TerminalDef: TerminalDef },
      {}
    );
    let options = dict(data["options"]);
    // if (
    //   (new Set(kwargs) - _LOAD_ALLOWED_OPTIONS) &
    //   new Set(LarkOptions._defaults)
    // ) {
    //   throw new ConfigurationError(
    //     "Some options are not allowed when loading a Parser: {}".format(
    //       new Set(kwargs) - _LOAD_ALLOWED_OPTIONS
    //     )
    //   );
    // }

    dict_update(options, kwargs);
    this.options = LarkOptions.deserialize(options, memo);
    this.rules = data["rules"].map((r) => Rule.deserialize(r, memo));
    this.source_path = "<deserialized>";
    _validate_frontend_args(this.options.parser, this.options.lexer);
    this.lexer_conf = this._deserialize_lexer_conf(
      data["parser"],
      memo,
      this.options
    );
    this.terminals = this.lexer_conf.terminals;
    this._prepare_callbacks();
    this._terminals_dict = Object.fromEntries(
      this.terminals.map((t) => [t.name, t])
    );
    this.parser = _deserialize_parsing_frontend(
      data["parser"],
      memo,
      this.lexer_conf,
      this._callbacks,
      this.options
    );
    return this;
  }

  static _load_from_dict({ data, memo, ...kwargs } = {}) {
    const cls = this;
    let inst = new_object(cls);
    return inst._load({
      f: { data: data, memo: memo },
      ...kwargs,
    });
  }

  /**
    Create an instance of Lark with the grammar given by its filename

        If ``rel_to`` is provided, the function will find the grammar filename in relation to it.

        Example:

            >>> Lark.open("grammar_file.lark", rel_to=__file__, parser="lalr")
            Lark(...)


  */
  /**
    Create an instance of Lark with the grammar loaded from within the package `package`.
        This allows grammar loading from zipapps.

        Imports in the grammar will use the `package` and `search_paths` provided, through `FromPackageLoader`

        Example:

            Lark.open_from_package(__name__, "example.lark", ("grammars",), parser=...)

  */
  repr() {
    return format(
      "Lark(open(%r), parser=%r, lexer=%r, ...)",
      this.source_path,
      this.options.parser,
      this.options.lexer
    );
  }

  /**
    Only lex (and postlex) the text, without parsing it. Only relevant when lexer='basic'

        When dont_ignore=True, the lexer will return all tokens, even those marked for %ignore.

        :raises UnexpectedCharacters: In case the lexer cannot find a suitable match.

  */
  lex(text, dont_ignore = false) {
    let lexer;
    if (!("lexer" in this) || dont_ignore) {
      lexer = this._build_lexer(dont_ignore);
    } else {
      lexer = this.lexer;
    }
    let lexer_thread = LexerThread.from_text(lexer, text);
    let stream = lexer_thread.lex(null);
    if (this.options.postlex) {
      return this.options.postlex.process(stream);
    }

    return stream;
  }

  /**
    Get information about a terminal
  */
  get_terminal(name) {
    return this._terminals_dict[name];
  }

  /**
    Start an interactive parsing session.

        Parameters:
            text (str, optional): Text to be parsed. Required for ``resume_parse()``.
            start (str, optional): Start symbol

        Returns:
            A new InteractiveParser instance.

        See Also: ``Lark.parse()``

  */
  parse_interactive(text = null, start = null) {
    return this.parser.parse_interactive({
      unknown_param_0: text,
      start: start,
    });
  }

  /**
    Parse the given text, according to the options provided.

        Parameters:
            text (str): Text to be parsed.
            start (str, optional): Required if Lark was given multiple possible start symbols (using the start option).
            on_error (function, optional): if provided, will be called on UnexpectedToken error. Return true to resume parsing.
                LALR only. See examples/advanced/error_handling.py for an example of how to use on_error.

        Returns:
            If a transformer is supplied to ``__init__``, returns whatever is the
            result of the transformation. Otherwise, returns a Tree instance.

        :raises UnexpectedInput: On a parse error, one of these sub-exceptions will rise:
                ``UnexpectedCharacters``, ``UnexpectedToken``, or ``UnexpectedEOF``.
                For convenience, these sub-exceptions also inherit from ``ParserError`` and ``LexerError``.


  */
  parse(text, start = null, on_error = null) {
    return this.parser.parse(text, start, on_error);
  }
}

//
// Indenter
//

class DedentError extends LarkError {
  // pass
}

class Indenter extends PostLex {
  constructor() {
    super();
    this.paren_level = 0;
    this.indent_level = [0];
  }

  *handle_NL(token) {
    if (this.paren_level > 0) {
      return;
    }

    yield token;
    let indent_str = rsplit(token.value, "\n", 1)[1];
    // Tabs and spaces
    let indent =
      str_count(indent_str, " ") + str_count(indent_str, "\t") * this.tab_len;
    if (indent > last_item(this.indent_level)) {
      this.indent_level.push(indent);
      yield Token.new_borrow_pos(this.INDENT_type, indent_str, token);
    } else {
      while (indent < last_item(this.indent_level)) {
        this.indent_level.pop();
        yield Token.new_borrow_pos(this.DEDENT_type, indent_str, token);
      }

      if (indent !== last_item(this.indent_level)) {
        throw new DedentError(
          format(
            "Unexpected dedent to column %s. Expected dedent to %s",
            indent,
            last_item(this.indent_level)
          )
        );
      }
    }
  }

  *_process(stream) {
    for (const token of stream) {
      if (token.type === this.NL_type) {
        yield* this.handle_NL(token);
      } else {
        yield token;
      }
      if (this.OPEN_PAREN_types.includes(token.type)) {
        this.paren_level += 1;
      } else if (this.CLOSE_PAREN_types.includes(token.type)) {
        this.paren_level -= 1;
      }
    }

    while (this.indent_level.length > 1) {
      this.indent_level.pop();
      yield new Token(this.DEDENT_type, "");
    }
  }

  process(stream) {
    this.paren_level = 0;
    this.indent_level = [0];
    return this._process(stream);
  }

  // XXX Hack for ContextualLexer. Maybe there's a more elegant solution?

  get always_accept() {
    return [this.NL_type];
  }

  get NL_type() {
    throw new NotImplementedError();
  }

  get OPEN_PAREN_types() {
    throw new NotImplementedError();
  }

  get CLOSE_PAREN_types() {
    throw new NotImplementedError();
  }

  get INDENT_type() {
    throw new NotImplementedError();
  }

  get DEDENT_type() {
    throw new NotImplementedError();
  }

  get tab_len() {
    throw new NotImplementedError();
  }
}

class PythonIndenter extends Indenter {
  static get NL_type() {
    return "_NEWLINE";
  }
  get NL_type() {
    return this.constructor.NL_type;
  }
  static get OPEN_PAREN_types() {
    return ["LPAR", "LSQB", "LBRACE"];
  }
  get OPEN_PAREN_types() {
    return this.constructor.OPEN_PAREN_types;
  }
  static get CLOSE_PAREN_types() {
    return ["RPAR", "RSQB", "RBRACE"];
  }
  get CLOSE_PAREN_types() {
    return this.constructor.CLOSE_PAREN_types;
  }
  static get INDENT_type() {
    return "_INDENT";
  }
  get INDENT_type() {
    return this.constructor.INDENT_type;
  }
  static get DEDENT_type() {
    return "_DEDENT";
  }
  get DEDENT_type() {
    return this.constructor.DEDENT_type;
  }
  static get tab_len() {
    return 8;
  }
  get tab_len() {
    return this.constructor.tab_len;
  }
}

const NAMESPACE = {
    Terminal: Terminal,
    NonTerminal: NonTerminal,
    RuleOptions: RuleOptions,
    PatternStr: PatternStr,
    PatternRE: PatternRE,
    TerminalDef: TerminalDef
}

module.exports = {
  LarkError,
  ConfigurationError,
  GrammarError,
  ParseError,
  LexError,
  UnexpectedInput,
  UnexpectedEOF,
  UnexpectedCharacters,
  UnexpectedToken,
  VisitError,
  Meta,
  Tree,
  Discard,
  Transformer,
  Transformer_InPlace,
  Transformer_NonRecursive,
  Transformer_InPlaceRecursive,
  VisitorBase,
  Visitor,
  Visitor_Recursive,
  Interpreter,
  Symbol,
  Terminal,
  NonTerminal,
  RuleOptions,
  Rule,
  Pattern,
  PatternStr,
  PatternRE,
  TerminalDef,
  Token,
  Lexer,
  LexerConf,
  ParserConf,
  InteractiveParser,
  ImmutableInteractiveParser,
  PostLex,
  Lark,
  DedentError,
  Indenter,
  PythonIndenter,
  get_parser,
};

var DATA={
  "parser": {
    "lexer_conf": {
      "terminals": [
        {
          "@": 0
        },
        {
          "@": 1
        },
        {
          "@": 2
        },
        {
          "@": 3
        },
        {
          "@": 4
        },
        {
          "@": 5
        },
        {
          "@": 6
        },
        {
          "@": 7
        },
        {
          "@": 8
        },
        {
          "@": 9
        },
        {
          "@": 10
        },
        {
          "@": 11
        },
        {
          "@": 12
        },
        {
          "@": 13
        },
        {
          "@": 14
        },
        {
          "@": 15
        },
        {
          "@": 16
        },
        {
          "@": 17
        },
        {
          "@": 18
        },
        {
          "@": 19
        },
        {
          "@": 20
        },
        {
          "@": 21
        },
        {
          "@": 22
        },
        {
          "@": 23
        },
        {
          "@": 24
        },
        {
          "@": 25
        },
        {
          "@": 26
        },
        {
          "@": 27
        },
        {
          "@": 28
        },
        {
          "@": 29
        },
        {
          "@": 30
        },
        {
          "@": 31
        },
        {
          "@": 32
        },
        {
          "@": 33
        },
        {
          "@": 34
        },
        {
          "@": 35
        },
        {
          "@": 36
        },
        {
          "@": 37
        },
        {
          "@": 38
        },
        {
          "@": 39
        },
        {
          "@": 40
        },
        {
          "@": 41
        },
        {
          "@": 42
        },
        {
          "@": 43
        },
        {
          "@": 44
        },
        {
          "@": 45
        },
        {
          "@": 46
        },
        {
          "@": 47
        },
        {
          "@": 48
        },
        {
          "@": 49
        },
        {
          "@": 50
        },
        {
          "@": 51
        },
        {
          "@": 52
        },
        {
          "@": 53
        },
        {
          "@": 54
        },
        {
          "@": 55
        },
        {
          "@": 56
        },
        {
          "@": 57
        },
        {
          "@": 58
        },
        {
          "@": 59
        },
        {
          "@": 60
        },
        {
          "@": 61
        },
        {
          "@": 62
        },
        {
          "@": 63
        },
        {
          "@": 64
        },
        {
          "@": 65
        },
        {
          "@": 66
        },
        {
          "@": 67
        }
      ],
      "ignore": [
        "WS",
        "COMMENT"
      ],
      "g_regex_flags": 0,
      "use_bytes": false,
      "lexer_type": "contextual",
      "__type__": "LexerConf"
    },
    "parser_conf": {
      "rules": [
        {
          "@": 68
        },
        {
          "@": 69
        },
        {
          "@": 70
        },
        {
          "@": 71
        },
        {
          "@": 72
        },
        {
          "@": 73
        },
        {
          "@": 74
        },
        {
          "@": 75
        },
        {
          "@": 76
        },
        {
          "@": 77
        },
        {
          "@": 78
        },
        {
          "@": 79
        },
        {
          "@": 80
        },
        {
          "@": 81
        },
        {
          "@": 82
        },
        {
          "@": 83
        },
        {
          "@": 84
        },
        {
          "@": 85
        },
        {
          "@": 86
        },
        {
          "@": 87
        },
        {
          "@": 88
        },
        {
          "@": 89
        },
        {
          "@": 90
        },
        {
          "@": 91
        },
        {
          "@": 92
        },
        {
          "@": 93
        },
        {
          "@": 94
        },
        {
          "@": 95
        },
        {
          "@": 96
        },
        {
          "@": 97
        },
        {
          "@": 98
        },
        {
          "@": 99
        },
        {
          "@": 100
        },
        {
          "@": 101
        },
        {
          "@": 102
        },
        {
          "@": 103
        },
        {
          "@": 104
        },
        {
          "@": 105
        },
        {
          "@": 106
        },
        {
          "@": 107
        },
        {
          "@": 108
        },
        {
          "@": 109
        },
        {
          "@": 110
        },
        {
          "@": 111
        },
        {
          "@": 112
        },
        {
          "@": 113
        },
        {
          "@": 114
        },
        {
          "@": 115
        },
        {
          "@": 116
        },
        {
          "@": 117
        },
        {
          "@": 118
        },
        {
          "@": 119
        },
        {
          "@": 120
        },
        {
          "@": 121
        },
        {
          "@": 122
        },
        {
          "@": 123
        },
        {
          "@": 124
        },
        {
          "@": 125
        },
        {
          "@": 126
        },
        {
          "@": 127
        },
        {
          "@": 128
        },
        {
          "@": 129
        },
        {
          "@": 130
        },
        {
          "@": 131
        },
        {
          "@": 132
        },
        {
          "@": 133
        },
        {
          "@": 134
        },
        {
          "@": 135
        },
        {
          "@": 136
        },
        {
          "@": 137
        },
        {
          "@": 138
        },
        {
          "@": 139
        },
        {
          "@": 140
        },
        {
          "@": 141
        },
        {
          "@": 142
        },
        {
          "@": 143
        },
        {
          "@": 144
        },
        {
          "@": 145
        },
        {
          "@": 146
        },
        {
          "@": 147
        },
        {
          "@": 148
        },
        {
          "@": 149
        },
        {
          "@": 150
        },
        {
          "@": 151
        },
        {
          "@": 152
        },
        {
          "@": 153
        },
        {
          "@": 154
        },
        {
          "@": 155
        },
        {
          "@": 156
        },
        {
          "@": 157
        },
        {
          "@": 158
        },
        {
          "@": 159
        },
        {
          "@": 160
        },
        {
          "@": 161
        },
        {
          "@": 162
        },
        {
          "@": 163
        },
        {
          "@": 164
        },
        {
          "@": 165
        },
        {
          "@": 166
        },
        {
          "@": 167
        },
        {
          "@": 168
        },
        {
          "@": 169
        },
        {
          "@": 170
        },
        {
          "@": 171
        },
        {
          "@": 172
        },
        {
          "@": 173
        },
        {
          "@": 174
        },
        {
          "@": 175
        },
        {
          "@": 176
        },
        {
          "@": 177
        },
        {
          "@": 178
        },
        {
          "@": 179
        },
        {
          "@": 180
        },
        {
          "@": 181
        },
        {
          "@": 182
        },
        {
          "@": 183
        },
        {
          "@": 184
        },
        {
          "@": 185
        },
        {
          "@": 186
        },
        {
          "@": 187
        },
        {
          "@": 188
        },
        {
          "@": 189
        },
        {
          "@": 190
        },
        {
          "@": 191
        },
        {
          "@": 192
        },
        {
          "@": 193
        },
        {
          "@": 194
        },
        {
          "@": 195
        },
        {
          "@": 196
        },
        {
          "@": 197
        },
        {
          "@": 198
        },
        {
          "@": 199
        },
        {
          "@": 200
        },
        {
          "@": 201
        },
        {
          "@": 202
        },
        {
          "@": 203
        },
        {
          "@": 204
        }
      ],
      "start": [
        "start"
      ],
      "parser_type": "lalr",
      "__type__": "ParserConf"
    },
    "parser": {
      "tokens": {
        "0": "where_clause",
        "1": "SORT",
        "2": "attr_clause",
        "3": "offset_clause",
        "4": "limit_clause",
        "5": "LIMIT",
        "6": "sort_clause",
        "7": "ATTR",
        "8": "WHERE",
        "9": "OFFSET",
        "10": "$END",
        "11": "SAVE",
        "12": "TRANSFORM",
        "13": "APPLY",
        "14": "NEW",
        "15": "GET",
        "16": "FIND",
        "17": "LOAD",
        "18": "JOIN",
        "19": "VARIABLE",
        "20": "DISP",
        "21": "INFO",
        "22": "GROUP",
        "23": "OR",
        "24": "AND",
        "25": "RPAR",
        "26": "transform",
        "27": "info",
        "28": "sort",
        "29": "statement",
        "30": "__start_star_0",
        "31": "load",
        "32": "command_with_result",
        "33": "find",
        "34": "disp",
        "35": "join",
        "36": "apply",
        "37": "command_no_result",
        "38": "save",
        "39": "get",
        "40": "assign",
        "41": "assignment",
        "42": "merge",
        "43": "new",
        "44": "group",
        "45": "start",
        "46": "expression",
        "47": "STIXPATTERNBODY",
        "48": "__anaparams_star_2",
        "49": "__ANON_1",
        "50": "COMMA",
        "51": "__path_list_star_5",
        "52": "WITH",
        "53": "DUMPPATH",
        "54": "CNAME",
        "55": "localargs",
        "56": "URI",
        "57": "anaparams",
        "58": "DATASRC",
        "59": "__merge_plus_1",
        "60": "PLUS",
        "61": "EQUAL",
        "62": "START",
        "63": "starttime",
        "64": "STIXPATH",
        "65": "STOP",
        "66": "endtime",
        "67": "__variables_star_4",
        "68": "ENTITY_TYPE",
        "69": "VARDATA",
        "70": "REVERSED",
        "71": "path_list",
        "72": "variables",
        "73": "COUNT",
        "74": "funcname",
        "75": "agg",
        "76": "SUM",
        "77": "agg_list",
        "78": "AVG",
        "79": "NUNIQUE",
        "80": "MAX",
        "81": "MIN",
        "82": "__ANON_2",
        "83": "LPAR",
        "84": "column",
        "85": "conjunction",
        "86": "disjunction",
        "87": "comparison",
        "88": "OP",
        "89": "NULL_OP",
        "90": "ISOTIMESTAMP",
        "91": "ANALYTICS",
        "92": "QUOTE",
        "93": "PATH",
        "94": "valuelist",
        "95": "QSTRING",
        "96": "NUMBER",
        "97": "INT",
        "98": "ON",
        "99": "__agg_list_star_6",
        "100": "BY",
        "101": "ASC",
        "102": "DESC",
        "103": "AS",
        "104": "TO",
        "105": "RELATION",
        "106": "FROM",
        "107": "NULL",
        "108": "STIXPATHS",
        "109": "SQSTRING",
        "110": "value",
        "111": "__ANON_0",
        "112": "alias",
        "113": "__valuelist_star_3",
        "114": "condition",
        "115": "__ANON_3"
      },
      "states": {
        "0": {
          "0": [
            0,
            128
          ],
          "1": [
            0,
            212
          ],
          "2": [
            0,
            126
          ],
          "3": [
            0,
            213
          ],
          "4": [
            0,
            150
          ],
          "5": [
            0,
            191
          ],
          "6": [
            0,
            141
          ],
          "7": [
            0,
            182
          ],
          "8": [
            0,
            216
          ],
          "9": [
            0,
            122
          ],
          "10": [
            1,
            {
              "@": 146
            }
          ],
          "11": [
            1,
            {
              "@": 146
            }
          ],
          "12": [
            1,
            {
              "@": 146
            }
          ],
          "13": [
            1,
            {
              "@": 146
            }
          ],
          "14": [
            1,
            {
              "@": 146
            }
          ],
          "15": [
            1,
            {
              "@": 146
            }
          ],
          "16": [
            1,
            {
              "@": 146
            }
          ],
          "17": [
            1,
            {
              "@": 146
            }
          ],
          "18": [
            1,
            {
              "@": 146
            }
          ],
          "19": [
            1,
            {
              "@": 146
            }
          ],
          "20": [
            1,
            {
              "@": 146
            }
          ],
          "21": [
            1,
            {
              "@": 146
            }
          ],
          "22": [
            1,
            {
              "@": 146
            }
          ]
        },
        "1": {
          "10": [
            1,
            {
              "@": 71
            }
          ],
          "11": [
            1,
            {
              "@": 71
            }
          ],
          "12": [
            1,
            {
              "@": 71
            }
          ],
          "13": [
            1,
            {
              "@": 71
            }
          ],
          "14": [
            1,
            {
              "@": 71
            }
          ],
          "15": [
            1,
            {
              "@": 71
            }
          ],
          "16": [
            1,
            {
              "@": 71
            }
          ],
          "17": [
            1,
            {
              "@": 71
            }
          ],
          "18": [
            1,
            {
              "@": 71
            }
          ],
          "19": [
            1,
            {
              "@": 71
            }
          ],
          "20": [
            1,
            {
              "@": 71
            }
          ],
          "1": [
            1,
            {
              "@": 71
            }
          ],
          "21": [
            1,
            {
              "@": 71
            }
          ],
          "22": [
            1,
            {
              "@": 71
            }
          ]
        },
        "2": {
          "23": [
            1,
            {
              "@": 159
            }
          ],
          "24": [
            1,
            {
              "@": 159
            }
          ],
          "25": [
            1,
            {
              "@": 159
            }
          ],
          "10": [
            1,
            {
              "@": 159
            }
          ],
          "11": [
            1,
            {
              "@": 159
            }
          ],
          "13": [
            1,
            {
              "@": 159
            }
          ],
          "9": [
            1,
            {
              "@": 159
            }
          ],
          "15": [
            1,
            {
              "@": 159
            }
          ],
          "18": [
            1,
            {
              "@": 159
            }
          ],
          "19": [
            1,
            {
              "@": 159
            }
          ],
          "20": [
            1,
            {
              "@": 159
            }
          ],
          "1": [
            1,
            {
              "@": 159
            }
          ],
          "22": [
            1,
            {
              "@": 159
            }
          ],
          "7": [
            1,
            {
              "@": 159
            }
          ],
          "12": [
            1,
            {
              "@": 159
            }
          ],
          "14": [
            1,
            {
              "@": 159
            }
          ],
          "16": [
            1,
            {
              "@": 159
            }
          ],
          "17": [
            1,
            {
              "@": 159
            }
          ],
          "5": [
            1,
            {
              "@": 159
            }
          ],
          "21": [
            1,
            {
              "@": 159
            }
          ]
        },
        "3": {
          "10": [
            1,
            {
              "@": 79
            }
          ],
          "11": [
            1,
            {
              "@": 79
            }
          ],
          "12": [
            1,
            {
              "@": 79
            }
          ],
          "13": [
            1,
            {
              "@": 79
            }
          ],
          "14": [
            1,
            {
              "@": 79
            }
          ],
          "15": [
            1,
            {
              "@": 79
            }
          ],
          "16": [
            1,
            {
              "@": 79
            }
          ],
          "17": [
            1,
            {
              "@": 79
            }
          ],
          "18": [
            1,
            {
              "@": 79
            }
          ],
          "19": [
            1,
            {
              "@": 79
            }
          ],
          "20": [
            1,
            {
              "@": 79
            }
          ],
          "1": [
            1,
            {
              "@": 79
            }
          ],
          "21": [
            1,
            {
              "@": 79
            }
          ],
          "22": [
            1,
            {
              "@": 79
            }
          ]
        },
        "4": {
          "10": [
            1,
            {
              "@": 99
            }
          ],
          "11": [
            1,
            {
              "@": 99
            }
          ],
          "12": [
            1,
            {
              "@": 99
            }
          ],
          "13": [
            1,
            {
              "@": 99
            }
          ],
          "14": [
            1,
            {
              "@": 99
            }
          ],
          "15": [
            1,
            {
              "@": 99
            }
          ],
          "16": [
            1,
            {
              "@": 99
            }
          ],
          "17": [
            1,
            {
              "@": 99
            }
          ],
          "18": [
            1,
            {
              "@": 99
            }
          ],
          "19": [
            1,
            {
              "@": 99
            }
          ],
          "20": [
            1,
            {
              "@": 99
            }
          ],
          "1": [
            1,
            {
              "@": 99
            }
          ],
          "21": [
            1,
            {
              "@": 99
            }
          ],
          "22": [
            1,
            {
              "@": 99
            }
          ]
        },
        "5": {
          "26": [
            0,
            0
          ],
          "18": [
            0,
            63
          ],
          "1": [
            0,
            89
          ],
          "27": [
            0,
            30
          ],
          "22": [
            0,
            12
          ],
          "14": [
            0,
            48
          ],
          "28": [
            0,
            14
          ],
          "20": [
            0,
            84
          ],
          "15": [
            0,
            77
          ],
          "29": [
            0,
            40
          ],
          "30": [
            0,
            113
          ],
          "31": [
            0,
            3
          ],
          "32": [
            0,
            28
          ],
          "33": [
            0,
            34
          ],
          "11": [
            0,
            90
          ],
          "34": [
            0,
            37
          ],
          "17": [
            0,
            27
          ],
          "13": [
            0,
            97
          ],
          "16": [
            0,
            50
          ],
          "35": [
            0,
            6
          ],
          "36": [
            0,
            13
          ],
          "12": [
            0,
            73
          ],
          "37": [
            0,
            1
          ],
          "38": [
            0,
            58
          ],
          "39": [
            0,
            23
          ],
          "19": [
            0,
            25
          ],
          "40": [
            0,
            220
          ],
          "41": [
            0,
            146
          ],
          "42": [
            0,
            168
          ],
          "21": [
            0,
            138
          ],
          "43": [
            0,
            219
          ],
          "44": [
            0,
            208
          ],
          "45": [
            0,
            179
          ],
          "46": [
            0,
            196
          ],
          "10": [
            1,
            {
              "@": 69
            }
          ]
        },
        "6": {
          "10": [
            1,
            {
              "@": 76
            }
          ],
          "11": [
            1,
            {
              "@": 76
            }
          ],
          "12": [
            1,
            {
              "@": 76
            }
          ],
          "13": [
            1,
            {
              "@": 76
            }
          ],
          "14": [
            1,
            {
              "@": 76
            }
          ],
          "15": [
            1,
            {
              "@": 76
            }
          ],
          "16": [
            1,
            {
              "@": 76
            }
          ],
          "17": [
            1,
            {
              "@": 76
            }
          ],
          "18": [
            1,
            {
              "@": 76
            }
          ],
          "19": [
            1,
            {
              "@": 76
            }
          ],
          "20": [
            1,
            {
              "@": 76
            }
          ],
          "1": [
            1,
            {
              "@": 76
            }
          ],
          "21": [
            1,
            {
              "@": 76
            }
          ],
          "22": [
            1,
            {
              "@": 76
            }
          ]
        },
        "7": {
          "47": [
            0,
            32
          ]
        },
        "8": {
          "10": [
            1,
            {
              "@": 165
            }
          ],
          "11": [
            1,
            {
              "@": 165
            }
          ],
          "13": [
            1,
            {
              "@": 165
            }
          ],
          "9": [
            1,
            {
              "@": 165
            }
          ],
          "15": [
            1,
            {
              "@": 165
            }
          ],
          "18": [
            1,
            {
              "@": 165
            }
          ],
          "19": [
            1,
            {
              "@": 165
            }
          ],
          "20": [
            1,
            {
              "@": 165
            }
          ],
          "1": [
            1,
            {
              "@": 165
            }
          ],
          "22": [
            1,
            {
              "@": 165
            }
          ],
          "24": [
            1,
            {
              "@": 165
            }
          ],
          "7": [
            1,
            {
              "@": 165
            }
          ],
          "12": [
            1,
            {
              "@": 165
            }
          ],
          "23": [
            1,
            {
              "@": 165
            }
          ],
          "14": [
            1,
            {
              "@": 165
            }
          ],
          "16": [
            1,
            {
              "@": 165
            }
          ],
          "17": [
            1,
            {
              "@": 165
            }
          ],
          "5": [
            1,
            {
              "@": 165
            }
          ],
          "21": [
            1,
            {
              "@": 165
            }
          ],
          "25": [
            1,
            {
              "@": 165
            }
          ]
        },
        "9": {
          "48": [
            0,
            111
          ],
          "49": [
            0,
            45
          ],
          "10": [
            1,
            {
              "@": 167
            }
          ],
          "11": [
            1,
            {
              "@": 167
            }
          ],
          "13": [
            1,
            {
              "@": 167
            }
          ],
          "15": [
            1,
            {
              "@": 167
            }
          ],
          "18": [
            1,
            {
              "@": 167
            }
          ],
          "19": [
            1,
            {
              "@": 167
            }
          ],
          "20": [
            1,
            {
              "@": 167
            }
          ],
          "1": [
            1,
            {
              "@": 167
            }
          ],
          "22": [
            1,
            {
              "@": 167
            }
          ],
          "12": [
            1,
            {
              "@": 167
            }
          ],
          "14": [
            1,
            {
              "@": 167
            }
          ],
          "16": [
            1,
            {
              "@": 167
            }
          ],
          "17": [
            1,
            {
              "@": 167
            }
          ],
          "21": [
            1,
            {
              "@": 167
            }
          ]
        },
        "10": {
          "10": [
            1,
            {
              "@": 147
            }
          ],
          "11": [
            1,
            {
              "@": 147
            }
          ],
          "13": [
            1,
            {
              "@": 147
            }
          ],
          "9": [
            1,
            {
              "@": 147
            }
          ],
          "15": [
            1,
            {
              "@": 147
            }
          ],
          "18": [
            1,
            {
              "@": 147
            }
          ],
          "19": [
            1,
            {
              "@": 147
            }
          ],
          "20": [
            1,
            {
              "@": 147
            }
          ],
          "1": [
            1,
            {
              "@": 147
            }
          ],
          "22": [
            1,
            {
              "@": 147
            }
          ],
          "7": [
            1,
            {
              "@": 147
            }
          ],
          "12": [
            1,
            {
              "@": 147
            }
          ],
          "14": [
            1,
            {
              "@": 147
            }
          ],
          "16": [
            1,
            {
              "@": 147
            }
          ],
          "17": [
            1,
            {
              "@": 147
            }
          ],
          "5": [
            1,
            {
              "@": 147
            }
          ],
          "21": [
            1,
            {
              "@": 147
            }
          ]
        },
        "11": {
          "50": [
            0,
            62
          ],
          "51": [
            0,
            59
          ],
          "10": [
            1,
            {
              "@": 179
            }
          ],
          "11": [
            1,
            {
              "@": 179
            }
          ],
          "13": [
            1,
            {
              "@": 179
            }
          ],
          "15": [
            1,
            {
              "@": 179
            }
          ],
          "18": [
            1,
            {
              "@": 179
            }
          ],
          "19": [
            1,
            {
              "@": 179
            }
          ],
          "20": [
            1,
            {
              "@": 179
            }
          ],
          "1": [
            1,
            {
              "@": 179
            }
          ],
          "22": [
            1,
            {
              "@": 179
            }
          ],
          "12": [
            1,
            {
              "@": 179
            }
          ],
          "14": [
            1,
            {
              "@": 179
            }
          ],
          "16": [
            1,
            {
              "@": 179
            }
          ],
          "17": [
            1,
            {
              "@": 179
            }
          ],
          "52": [
            1,
            {
              "@": 179
            }
          ],
          "21": [
            1,
            {
              "@": 179
            }
          ]
        },
        "12": {
          "19": [
            0,
            217
          ]
        },
        "13": {
          "10": [
            1,
            {
              "@": 85
            }
          ],
          "11": [
            1,
            {
              "@": 85
            }
          ],
          "12": [
            1,
            {
              "@": 85
            }
          ],
          "13": [
            1,
            {
              "@": 85
            }
          ],
          "14": [
            1,
            {
              "@": 85
            }
          ],
          "15": [
            1,
            {
              "@": 85
            }
          ],
          "16": [
            1,
            {
              "@": 85
            }
          ],
          "17": [
            1,
            {
              "@": 85
            }
          ],
          "18": [
            1,
            {
              "@": 85
            }
          ],
          "19": [
            1,
            {
              "@": 85
            }
          ],
          "20": [
            1,
            {
              "@": 85
            }
          ],
          "1": [
            1,
            {
              "@": 85
            }
          ],
          "21": [
            1,
            {
              "@": 85
            }
          ],
          "22": [
            1,
            {
              "@": 85
            }
          ]
        },
        "14": {
          "10": [
            1,
            {
              "@": 77
            }
          ],
          "11": [
            1,
            {
              "@": 77
            }
          ],
          "12": [
            1,
            {
              "@": 77
            }
          ],
          "13": [
            1,
            {
              "@": 77
            }
          ],
          "14": [
            1,
            {
              "@": 77
            }
          ],
          "15": [
            1,
            {
              "@": 77
            }
          ],
          "16": [
            1,
            {
              "@": 77
            }
          ],
          "17": [
            1,
            {
              "@": 77
            }
          ],
          "18": [
            1,
            {
              "@": 77
            }
          ],
          "19": [
            1,
            {
              "@": 77
            }
          ],
          "20": [
            1,
            {
              "@": 77
            }
          ],
          "1": [
            1,
            {
              "@": 77
            }
          ],
          "21": [
            1,
            {
              "@": 77
            }
          ],
          "22": [
            1,
            {
              "@": 77
            }
          ]
        },
        "15": {
          "53": [
            0,
            64
          ]
        },
        "16": {
          "54": [
            0,
            133
          ],
          "55": [
            0,
            9
          ],
          "56": [
            0,
            36
          ],
          "57": [
            0,
            4
          ]
        },
        "17": {
          "10": [
            1,
            {
              "@": 97
            }
          ],
          "11": [
            1,
            {
              "@": 97
            }
          ],
          "12": [
            1,
            {
              "@": 97
            }
          ],
          "13": [
            1,
            {
              "@": 97
            }
          ],
          "14": [
            1,
            {
              "@": 97
            }
          ],
          "15": [
            1,
            {
              "@": 97
            }
          ],
          "16": [
            1,
            {
              "@": 97
            }
          ],
          "17": [
            1,
            {
              "@": 97
            }
          ],
          "18": [
            1,
            {
              "@": 97
            }
          ],
          "19": [
            1,
            {
              "@": 97
            }
          ],
          "20": [
            1,
            {
              "@": 97
            }
          ],
          "1": [
            1,
            {
              "@": 97
            }
          ],
          "21": [
            1,
            {
              "@": 97
            }
          ],
          "22": [
            1,
            {
              "@": 97
            }
          ]
        },
        "18": {
          "58": [
            0,
            26
          ]
        },
        "19": {
          "10": [
            1,
            {
              "@": 149
            }
          ],
          "11": [
            1,
            {
              "@": 149
            }
          ],
          "13": [
            1,
            {
              "@": 149
            }
          ],
          "9": [
            1,
            {
              "@": 149
            }
          ],
          "15": [
            1,
            {
              "@": 149
            }
          ],
          "18": [
            1,
            {
              "@": 149
            }
          ],
          "19": [
            1,
            {
              "@": 149
            }
          ],
          "20": [
            1,
            {
              "@": 149
            }
          ],
          "1": [
            1,
            {
              "@": 149
            }
          ],
          "22": [
            1,
            {
              "@": 149
            }
          ],
          "12": [
            1,
            {
              "@": 149
            }
          ],
          "14": [
            1,
            {
              "@": 149
            }
          ],
          "16": [
            1,
            {
              "@": 149
            }
          ],
          "17": [
            1,
            {
              "@": 149
            }
          ],
          "5": [
            1,
            {
              "@": 149
            }
          ],
          "21": [
            1,
            {
              "@": 149
            }
          ]
        },
        "20": {
          "50": [
            0,
            145
          ],
          "10": [
            1,
            {
              "@": 176
            }
          ],
          "11": [
            1,
            {
              "@": 176
            }
          ],
          "13": [
            1,
            {
              "@": 176
            }
          ],
          "15": [
            1,
            {
              "@": 176
            }
          ],
          "18": [
            1,
            {
              "@": 176
            }
          ],
          "19": [
            1,
            {
              "@": 176
            }
          ],
          "20": [
            1,
            {
              "@": 176
            }
          ],
          "1": [
            1,
            {
              "@": 176
            }
          ],
          "22": [
            1,
            {
              "@": 176
            }
          ],
          "12": [
            1,
            {
              "@": 176
            }
          ],
          "14": [
            1,
            {
              "@": 176
            }
          ],
          "16": [
            1,
            {
              "@": 176
            }
          ],
          "17": [
            1,
            {
              "@": 176
            }
          ],
          "52": [
            1,
            {
              "@": 176
            }
          ],
          "21": [
            1,
            {
              "@": 176
            }
          ]
        },
        "21": {
          "9": [
            0,
            122
          ],
          "3": [
            0,
            103
          ],
          "10": [
            1,
            {
              "@": 120
            }
          ],
          "11": [
            1,
            {
              "@": 120
            }
          ],
          "12": [
            1,
            {
              "@": 120
            }
          ],
          "13": [
            1,
            {
              "@": 120
            }
          ],
          "14": [
            1,
            {
              "@": 120
            }
          ],
          "15": [
            1,
            {
              "@": 120
            }
          ],
          "16": [
            1,
            {
              "@": 120
            }
          ],
          "17": [
            1,
            {
              "@": 120
            }
          ],
          "18": [
            1,
            {
              "@": 120
            }
          ],
          "19": [
            1,
            {
              "@": 120
            }
          ],
          "20": [
            1,
            {
              "@": 120
            }
          ],
          "1": [
            1,
            {
              "@": 120
            }
          ],
          "21": [
            1,
            {
              "@": 120
            }
          ],
          "22": [
            1,
            {
              "@": 120
            }
          ]
        },
        "22": {
          "23": [
            1,
            {
              "@": 160
            }
          ],
          "24": [
            1,
            {
              "@": 160
            }
          ],
          "25": [
            1,
            {
              "@": 160
            }
          ],
          "10": [
            1,
            {
              "@": 160
            }
          ],
          "11": [
            1,
            {
              "@": 160
            }
          ],
          "13": [
            1,
            {
              "@": 160
            }
          ],
          "9": [
            1,
            {
              "@": 160
            }
          ],
          "15": [
            1,
            {
              "@": 160
            }
          ],
          "18": [
            1,
            {
              "@": 160
            }
          ],
          "19": [
            1,
            {
              "@": 160
            }
          ],
          "20": [
            1,
            {
              "@": 160
            }
          ],
          "1": [
            1,
            {
              "@": 160
            }
          ],
          "22": [
            1,
            {
              "@": 160
            }
          ],
          "7": [
            1,
            {
              "@": 160
            }
          ],
          "12": [
            1,
            {
              "@": 160
            }
          ],
          "14": [
            1,
            {
              "@": 160
            }
          ],
          "16": [
            1,
            {
              "@": 160
            }
          ],
          "17": [
            1,
            {
              "@": 160
            }
          ],
          "5": [
            1,
            {
              "@": 160
            }
          ],
          "21": [
            1,
            {
              "@": 160
            }
          ]
        },
        "23": {
          "10": [
            1,
            {
              "@": 74
            }
          ],
          "11": [
            1,
            {
              "@": 74
            }
          ],
          "12": [
            1,
            {
              "@": 74
            }
          ],
          "13": [
            1,
            {
              "@": 74
            }
          ],
          "14": [
            1,
            {
              "@": 74
            }
          ],
          "15": [
            1,
            {
              "@": 74
            }
          ],
          "16": [
            1,
            {
              "@": 74
            }
          ],
          "17": [
            1,
            {
              "@": 74
            }
          ],
          "18": [
            1,
            {
              "@": 74
            }
          ],
          "19": [
            1,
            {
              "@": 74
            }
          ],
          "20": [
            1,
            {
              "@": 74
            }
          ],
          "1": [
            1,
            {
              "@": 74
            }
          ],
          "21": [
            1,
            {
              "@": 74
            }
          ],
          "22": [
            1,
            {
              "@": 74
            }
          ]
        },
        "24": {
          "10": [
            1,
            {
              "@": 141
            }
          ],
          "11": [
            1,
            {
              "@": 141
            }
          ],
          "12": [
            1,
            {
              "@": 141
            }
          ],
          "13": [
            1,
            {
              "@": 141
            }
          ],
          "14": [
            1,
            {
              "@": 141
            }
          ],
          "15": [
            1,
            {
              "@": 141
            }
          ],
          "16": [
            1,
            {
              "@": 141
            }
          ],
          "17": [
            1,
            {
              "@": 141
            }
          ],
          "18": [
            1,
            {
              "@": 141
            }
          ],
          "19": [
            1,
            {
              "@": 141
            }
          ],
          "20": [
            1,
            {
              "@": 141
            }
          ],
          "1": [
            1,
            {
              "@": 141
            }
          ],
          "21": [
            1,
            {
              "@": 141
            }
          ],
          "22": [
            1,
            {
              "@": 141
            }
          ]
        },
        "25": {
          "59": [
            0,
            203
          ],
          "60": [
            0,
            129
          ],
          "61": [
            0,
            184
          ],
          "10": [
            1,
            {
              "@": 114
            }
          ],
          "11": [
            1,
            {
              "@": 114
            }
          ],
          "12": [
            1,
            {
              "@": 114
            }
          ],
          "13": [
            1,
            {
              "@": 114
            }
          ],
          "9": [
            1,
            {
              "@": 114
            }
          ],
          "14": [
            1,
            {
              "@": 114
            }
          ],
          "15": [
            1,
            {
              "@": 114
            }
          ],
          "16": [
            1,
            {
              "@": 114
            }
          ],
          "17": [
            1,
            {
              "@": 114
            }
          ],
          "8": [
            1,
            {
              "@": 114
            }
          ],
          "18": [
            1,
            {
              "@": 114
            }
          ],
          "19": [
            1,
            {
              "@": 114
            }
          ],
          "20": [
            1,
            {
              "@": 114
            }
          ],
          "1": [
            1,
            {
              "@": 114
            }
          ],
          "5": [
            1,
            {
              "@": 114
            }
          ],
          "21": [
            1,
            {
              "@": 114
            }
          ],
          "22": [
            1,
            {
              "@": 114
            }
          ],
          "7": [
            1,
            {
              "@": 114
            }
          ]
        },
        "26": {
          "8": [
            0,
            35
          ]
        },
        "27": {
          "53": [
            0,
            151
          ]
        },
        "28": {
          "10": [
            1,
            {
              "@": 73
            }
          ],
          "11": [
            1,
            {
              "@": 73
            }
          ],
          "12": [
            1,
            {
              "@": 73
            }
          ],
          "13": [
            1,
            {
              "@": 73
            }
          ],
          "14": [
            1,
            {
              "@": 73
            }
          ],
          "15": [
            1,
            {
              "@": 73
            }
          ],
          "16": [
            1,
            {
              "@": 73
            }
          ],
          "17": [
            1,
            {
              "@": 73
            }
          ],
          "18": [
            1,
            {
              "@": 73
            }
          ],
          "19": [
            1,
            {
              "@": 73
            }
          ],
          "20": [
            1,
            {
              "@": 73
            }
          ],
          "1": [
            1,
            {
              "@": 73
            }
          ],
          "21": [
            1,
            {
              "@": 73
            }
          ],
          "22": [
            1,
            {
              "@": 73
            }
          ]
        },
        "29": {
          "62": [
            0,
            72
          ],
          "63": [
            0,
            51
          ],
          "10": [
            1,
            {
              "@": 96
            }
          ],
          "11": [
            1,
            {
              "@": 96
            }
          ],
          "12": [
            1,
            {
              "@": 96
            }
          ],
          "13": [
            1,
            {
              "@": 96
            }
          ],
          "14": [
            1,
            {
              "@": 96
            }
          ],
          "15": [
            1,
            {
              "@": 96
            }
          ],
          "16": [
            1,
            {
              "@": 96
            }
          ],
          "17": [
            1,
            {
              "@": 96
            }
          ],
          "18": [
            1,
            {
              "@": 96
            }
          ],
          "19": [
            1,
            {
              "@": 96
            }
          ],
          "20": [
            1,
            {
              "@": 96
            }
          ],
          "1": [
            1,
            {
              "@": 96
            }
          ],
          "21": [
            1,
            {
              "@": 96
            }
          ],
          "22": [
            1,
            {
              "@": 96
            }
          ]
        },
        "30": {
          "10": [
            1,
            {
              "@": 84
            }
          ],
          "11": [
            1,
            {
              "@": 84
            }
          ],
          "12": [
            1,
            {
              "@": 84
            }
          ],
          "13": [
            1,
            {
              "@": 84
            }
          ],
          "14": [
            1,
            {
              "@": 84
            }
          ],
          "15": [
            1,
            {
              "@": 84
            }
          ],
          "16": [
            1,
            {
              "@": 84
            }
          ],
          "17": [
            1,
            {
              "@": 84
            }
          ],
          "18": [
            1,
            {
              "@": 84
            }
          ],
          "19": [
            1,
            {
              "@": 84
            }
          ],
          "20": [
            1,
            {
              "@": 84
            }
          ],
          "1": [
            1,
            {
              "@": 84
            }
          ],
          "21": [
            1,
            {
              "@": 84
            }
          ],
          "22": [
            1,
            {
              "@": 84
            }
          ]
        },
        "31": {
          "64": [
            0,
            43
          ]
        },
        "32": {
          "62": [
            0,
            72
          ],
          "63": [
            0,
            75
          ],
          "10": [
            1,
            {
              "@": 94
            }
          ],
          "11": [
            1,
            {
              "@": 94
            }
          ],
          "12": [
            1,
            {
              "@": 94
            }
          ],
          "13": [
            1,
            {
              "@": 94
            }
          ],
          "14": [
            1,
            {
              "@": 94
            }
          ],
          "15": [
            1,
            {
              "@": 94
            }
          ],
          "16": [
            1,
            {
              "@": 94
            }
          ],
          "17": [
            1,
            {
              "@": 94
            }
          ],
          "18": [
            1,
            {
              "@": 94
            }
          ],
          "19": [
            1,
            {
              "@": 94
            }
          ],
          "20": [
            1,
            {
              "@": 94
            }
          ],
          "1": [
            1,
            {
              "@": 94
            }
          ],
          "21": [
            1,
            {
              "@": 94
            }
          ],
          "22": [
            1,
            {
              "@": 94
            }
          ]
        },
        "33": {
          "65": [
            0,
            156
          ],
          "66": [
            0,
            17
          ]
        },
        "34": {
          "10": [
            1,
            {
              "@": 75
            }
          ],
          "11": [
            1,
            {
              "@": 75
            }
          ],
          "12": [
            1,
            {
              "@": 75
            }
          ],
          "13": [
            1,
            {
              "@": 75
            }
          ],
          "14": [
            1,
            {
              "@": 75
            }
          ],
          "15": [
            1,
            {
              "@": 75
            }
          ],
          "16": [
            1,
            {
              "@": 75
            }
          ],
          "17": [
            1,
            {
              "@": 75
            }
          ],
          "18": [
            1,
            {
              "@": 75
            }
          ],
          "19": [
            1,
            {
              "@": 75
            }
          ],
          "20": [
            1,
            {
              "@": 75
            }
          ],
          "1": [
            1,
            {
              "@": 75
            }
          ],
          "21": [
            1,
            {
              "@": 75
            }
          ],
          "22": [
            1,
            {
              "@": 75
            }
          ]
        },
        "35": {
          "47": [
            0,
            189
          ]
        },
        "36": {
          "10": [
            1,
            {
              "@": 168
            }
          ],
          "11": [
            1,
            {
              "@": 168
            }
          ],
          "13": [
            1,
            {
              "@": 168
            }
          ],
          "15": [
            1,
            {
              "@": 168
            }
          ],
          "18": [
            1,
            {
              "@": 168
            }
          ],
          "19": [
            1,
            {
              "@": 168
            }
          ],
          "20": [
            1,
            {
              "@": 168
            }
          ],
          "1": [
            1,
            {
              "@": 168
            }
          ],
          "22": [
            1,
            {
              "@": 168
            }
          ],
          "12": [
            1,
            {
              "@": 168
            }
          ],
          "14": [
            1,
            {
              "@": 168
            }
          ],
          "16": [
            1,
            {
              "@": 168
            }
          ],
          "17": [
            1,
            {
              "@": 168
            }
          ],
          "21": [
            1,
            {
              "@": 168
            }
          ]
        },
        "37": {
          "10": [
            1,
            {
              "@": 83
            }
          ],
          "11": [
            1,
            {
              "@": 83
            }
          ],
          "12": [
            1,
            {
              "@": 83
            }
          ],
          "13": [
            1,
            {
              "@": 83
            }
          ],
          "14": [
            1,
            {
              "@": 83
            }
          ],
          "15": [
            1,
            {
              "@": 83
            }
          ],
          "16": [
            1,
            {
              "@": 83
            }
          ],
          "17": [
            1,
            {
              "@": 83
            }
          ],
          "18": [
            1,
            {
              "@": 83
            }
          ],
          "19": [
            1,
            {
              "@": 83
            }
          ],
          "20": [
            1,
            {
              "@": 83
            }
          ],
          "1": [
            1,
            {
              "@": 83
            }
          ],
          "21": [
            1,
            {
              "@": 83
            }
          ],
          "22": [
            1,
            {
              "@": 83
            }
          ]
        },
        "38": {
          "24": [
            0,
            215
          ],
          "23": [
            1,
            {
              "@": 155
            }
          ],
          "25": [
            1,
            {
              "@": 155
            }
          ],
          "10": [
            1,
            {
              "@": 155
            }
          ],
          "11": [
            1,
            {
              "@": 155
            }
          ],
          "13": [
            1,
            {
              "@": 155
            }
          ],
          "9": [
            1,
            {
              "@": 155
            }
          ],
          "15": [
            1,
            {
              "@": 155
            }
          ],
          "18": [
            1,
            {
              "@": 155
            }
          ],
          "19": [
            1,
            {
              "@": 155
            }
          ],
          "20": [
            1,
            {
              "@": 155
            }
          ],
          "1": [
            1,
            {
              "@": 155
            }
          ],
          "22": [
            1,
            {
              "@": 155
            }
          ],
          "7": [
            1,
            {
              "@": 155
            }
          ],
          "12": [
            1,
            {
              "@": 155
            }
          ],
          "14": [
            1,
            {
              "@": 155
            }
          ],
          "16": [
            1,
            {
              "@": 155
            }
          ],
          "17": [
            1,
            {
              "@": 155
            }
          ],
          "5": [
            1,
            {
              "@": 155
            }
          ],
          "21": [
            1,
            {
              "@": 155
            }
          ]
        },
        "39": {
          "23": [
            1,
            {
              "@": 158
            }
          ],
          "24": [
            1,
            {
              "@": 158
            }
          ],
          "25": [
            1,
            {
              "@": 158
            }
          ],
          "10": [
            1,
            {
              "@": 158
            }
          ],
          "11": [
            1,
            {
              "@": 158
            }
          ],
          "13": [
            1,
            {
              "@": 158
            }
          ],
          "9": [
            1,
            {
              "@": 158
            }
          ],
          "15": [
            1,
            {
              "@": 158
            }
          ],
          "18": [
            1,
            {
              "@": 158
            }
          ],
          "19": [
            1,
            {
              "@": 158
            }
          ],
          "20": [
            1,
            {
              "@": 158
            }
          ],
          "1": [
            1,
            {
              "@": 158
            }
          ],
          "22": [
            1,
            {
              "@": 158
            }
          ],
          "7": [
            1,
            {
              "@": 158
            }
          ],
          "12": [
            1,
            {
              "@": 158
            }
          ],
          "14": [
            1,
            {
              "@": 158
            }
          ],
          "16": [
            1,
            {
              "@": 158
            }
          ],
          "17": [
            1,
            {
              "@": 158
            }
          ],
          "5": [
            1,
            {
              "@": 158
            }
          ],
          "21": [
            1,
            {
              "@": 158
            }
          ]
        },
        "40": {
          "10": [
            1,
            {
              "@": 191
            }
          ],
          "11": [
            1,
            {
              "@": 191
            }
          ],
          "12": [
            1,
            {
              "@": 191
            }
          ],
          "13": [
            1,
            {
              "@": 191
            }
          ],
          "14": [
            1,
            {
              "@": 191
            }
          ],
          "15": [
            1,
            {
              "@": 191
            }
          ],
          "16": [
            1,
            {
              "@": 191
            }
          ],
          "17": [
            1,
            {
              "@": 191
            }
          ],
          "18": [
            1,
            {
              "@": 191
            }
          ],
          "19": [
            1,
            {
              "@": 191
            }
          ],
          "20": [
            1,
            {
              "@": 191
            }
          ],
          "1": [
            1,
            {
              "@": 191
            }
          ],
          "21": [
            1,
            {
              "@": 191
            }
          ],
          "22": [
            1,
            {
              "@": 191
            }
          ]
        },
        "41": {
          "19": [
            0,
            132
          ]
        },
        "42": {
          "10": [
            1,
            {
              "@": 111
            }
          ],
          "11": [
            1,
            {
              "@": 111
            }
          ],
          "12": [
            1,
            {
              "@": 111
            }
          ],
          "13": [
            1,
            {
              "@": 111
            }
          ],
          "14": [
            1,
            {
              "@": 111
            }
          ],
          "15": [
            1,
            {
              "@": 111
            }
          ],
          "16": [
            1,
            {
              "@": 111
            }
          ],
          "17": [
            1,
            {
              "@": 111
            }
          ],
          "18": [
            1,
            {
              "@": 111
            }
          ],
          "19": [
            1,
            {
              "@": 111
            }
          ],
          "20": [
            1,
            {
              "@": 111
            }
          ],
          "1": [
            1,
            {
              "@": 111
            }
          ],
          "21": [
            1,
            {
              "@": 111
            }
          ],
          "22": [
            1,
            {
              "@": 111
            }
          ]
        },
        "43": {
          "10": [
            1,
            {
              "@": 101
            }
          ],
          "11": [
            1,
            {
              "@": 101
            }
          ],
          "12": [
            1,
            {
              "@": 101
            }
          ],
          "13": [
            1,
            {
              "@": 101
            }
          ],
          "14": [
            1,
            {
              "@": 101
            }
          ],
          "15": [
            1,
            {
              "@": 101
            }
          ],
          "16": [
            1,
            {
              "@": 101
            }
          ],
          "17": [
            1,
            {
              "@": 101
            }
          ],
          "18": [
            1,
            {
              "@": 101
            }
          ],
          "19": [
            1,
            {
              "@": 101
            }
          ],
          "20": [
            1,
            {
              "@": 101
            }
          ],
          "1": [
            1,
            {
              "@": 101
            }
          ],
          "21": [
            1,
            {
              "@": 101
            }
          ],
          "22": [
            1,
            {
              "@": 101
            }
          ]
        },
        "44": {
          "10": [
            1,
            {
              "@": 152
            }
          ],
          "11": [
            1,
            {
              "@": 152
            }
          ],
          "13": [
            1,
            {
              "@": 152
            }
          ],
          "9": [
            1,
            {
              "@": 152
            }
          ],
          "15": [
            1,
            {
              "@": 152
            }
          ],
          "18": [
            1,
            {
              "@": 152
            }
          ],
          "19": [
            1,
            {
              "@": 152
            }
          ],
          "20": [
            1,
            {
              "@": 152
            }
          ],
          "1": [
            1,
            {
              "@": 152
            }
          ],
          "22": [
            1,
            {
              "@": 152
            }
          ],
          "12": [
            1,
            {
              "@": 152
            }
          ],
          "14": [
            1,
            {
              "@": 152
            }
          ],
          "16": [
            1,
            {
              "@": 152
            }
          ],
          "17": [
            1,
            {
              "@": 152
            }
          ],
          "21": [
            1,
            {
              "@": 152
            }
          ]
        },
        "45": {
          "54": [
            0,
            133
          ],
          "55": [
            0,
            149
          ]
        },
        "46": {
          "67": [
            0,
            20
          ],
          "50": [
            0,
            47
          ],
          "10": [
            1,
            {
              "@": 177
            }
          ],
          "11": [
            1,
            {
              "@": 177
            }
          ],
          "13": [
            1,
            {
              "@": 177
            }
          ],
          "15": [
            1,
            {
              "@": 177
            }
          ],
          "18": [
            1,
            {
              "@": 177
            }
          ],
          "19": [
            1,
            {
              "@": 177
            }
          ],
          "20": [
            1,
            {
              "@": 177
            }
          ],
          "1": [
            1,
            {
              "@": 177
            }
          ],
          "22": [
            1,
            {
              "@": 177
            }
          ],
          "12": [
            1,
            {
              "@": 177
            }
          ],
          "14": [
            1,
            {
              "@": 177
            }
          ],
          "16": [
            1,
            {
              "@": 177
            }
          ],
          "17": [
            1,
            {
              "@": 177
            }
          ],
          "52": [
            1,
            {
              "@": 177
            }
          ],
          "21": [
            1,
            {
              "@": 177
            }
          ]
        },
        "47": {
          "19": [
            0,
            140
          ]
        },
        "48": {
          "68": [
            0,
            148
          ],
          "69": [
            0,
            171
          ]
        },
        "49": {
          "64": [
            0,
            76
          ]
        },
        "50": {
          "68": [
            0,
            158
          ]
        },
        "51": {
          "66": [
            0,
            68
          ],
          "65": [
            0,
            156
          ]
        },
        "52": {
          "19": [
            0,
            67
          ],
          "70": [
            0,
            79
          ]
        },
        "53": {
          "10": [
            1,
            {
              "@": 108
            }
          ],
          "11": [
            1,
            {
              "@": 108
            }
          ],
          "12": [
            1,
            {
              "@": 108
            }
          ],
          "13": [
            1,
            {
              "@": 108
            }
          ],
          "14": [
            1,
            {
              "@": 108
            }
          ],
          "15": [
            1,
            {
              "@": 108
            }
          ],
          "16": [
            1,
            {
              "@": 108
            }
          ],
          "17": [
            1,
            {
              "@": 108
            }
          ],
          "18": [
            1,
            {
              "@": 108
            }
          ],
          "19": [
            1,
            {
              "@": 108
            }
          ],
          "20": [
            1,
            {
              "@": 108
            }
          ],
          "1": [
            1,
            {
              "@": 108
            }
          ],
          "21": [
            1,
            {
              "@": 108
            }
          ],
          "22": [
            1,
            {
              "@": 108
            }
          ]
        },
        "54": {
          "71": [
            0,
            198
          ],
          "64": [
            0,
            11
          ]
        },
        "55": {
          "19": [
            0,
            46
          ],
          "72": [
            0,
            71
          ]
        },
        "56": {
          "10": [
            1,
            {
              "@": 164
            }
          ],
          "11": [
            1,
            {
              "@": 164
            }
          ],
          "13": [
            1,
            {
              "@": 164
            }
          ],
          "9": [
            1,
            {
              "@": 164
            }
          ],
          "15": [
            1,
            {
              "@": 164
            }
          ],
          "18": [
            1,
            {
              "@": 164
            }
          ],
          "19": [
            1,
            {
              "@": 164
            }
          ],
          "20": [
            1,
            {
              "@": 164
            }
          ],
          "1": [
            1,
            {
              "@": 164
            }
          ],
          "22": [
            1,
            {
              "@": 164
            }
          ],
          "24": [
            1,
            {
              "@": 164
            }
          ],
          "7": [
            1,
            {
              "@": 164
            }
          ],
          "12": [
            1,
            {
              "@": 164
            }
          ],
          "23": [
            1,
            {
              "@": 164
            }
          ],
          "14": [
            1,
            {
              "@": 164
            }
          ],
          "16": [
            1,
            {
              "@": 164
            }
          ],
          "17": [
            1,
            {
              "@": 164
            }
          ],
          "5": [
            1,
            {
              "@": 164
            }
          ],
          "21": [
            1,
            {
              "@": 164
            }
          ],
          "25": [
            1,
            {
              "@": 164
            }
          ]
        },
        "57": {
          "24": [
            0,
            215
          ],
          "23": [
            1,
            {
              "@": 156
            }
          ],
          "25": [
            1,
            {
              "@": 156
            }
          ],
          "10": [
            1,
            {
              "@": 156
            }
          ],
          "11": [
            1,
            {
              "@": 156
            }
          ],
          "13": [
            1,
            {
              "@": 156
            }
          ],
          "9": [
            1,
            {
              "@": 156
            }
          ],
          "15": [
            1,
            {
              "@": 156
            }
          ],
          "18": [
            1,
            {
              "@": 156
            }
          ],
          "19": [
            1,
            {
              "@": 156
            }
          ],
          "20": [
            1,
            {
              "@": 156
            }
          ],
          "1": [
            1,
            {
              "@": 156
            }
          ],
          "22": [
            1,
            {
              "@": 156
            }
          ],
          "7": [
            1,
            {
              "@": 156
            }
          ],
          "12": [
            1,
            {
              "@": 156
            }
          ],
          "14": [
            1,
            {
              "@": 156
            }
          ],
          "16": [
            1,
            {
              "@": 156
            }
          ],
          "17": [
            1,
            {
              "@": 156
            }
          ],
          "5": [
            1,
            {
              "@": 156
            }
          ],
          "21": [
            1,
            {
              "@": 156
            }
          ]
        },
        "58": {
          "10": [
            1,
            {
              "@": 86
            }
          ],
          "11": [
            1,
            {
              "@": 86
            }
          ],
          "12": [
            1,
            {
              "@": 86
            }
          ],
          "13": [
            1,
            {
              "@": 86
            }
          ],
          "14": [
            1,
            {
              "@": 86
            }
          ],
          "15": [
            1,
            {
              "@": 86
            }
          ],
          "16": [
            1,
            {
              "@": 86
            }
          ],
          "17": [
            1,
            {
              "@": 86
            }
          ],
          "18": [
            1,
            {
              "@": 86
            }
          ],
          "19": [
            1,
            {
              "@": 86
            }
          ],
          "20": [
            1,
            {
              "@": 86
            }
          ],
          "1": [
            1,
            {
              "@": 86
            }
          ],
          "21": [
            1,
            {
              "@": 86
            }
          ],
          "22": [
            1,
            {
              "@": 86
            }
          ]
        },
        "59": {
          "50": [
            0,
            199
          ],
          "10": [
            1,
            {
              "@": 178
            }
          ],
          "11": [
            1,
            {
              "@": 178
            }
          ],
          "13": [
            1,
            {
              "@": 178
            }
          ],
          "15": [
            1,
            {
              "@": 178
            }
          ],
          "18": [
            1,
            {
              "@": 178
            }
          ],
          "19": [
            1,
            {
              "@": 178
            }
          ],
          "20": [
            1,
            {
              "@": 178
            }
          ],
          "1": [
            1,
            {
              "@": 178
            }
          ],
          "22": [
            1,
            {
              "@": 178
            }
          ],
          "12": [
            1,
            {
              "@": 178
            }
          ],
          "14": [
            1,
            {
              "@": 178
            }
          ],
          "16": [
            1,
            {
              "@": 178
            }
          ],
          "17": [
            1,
            {
              "@": 178
            }
          ],
          "52": [
            1,
            {
              "@": 178
            }
          ],
          "21": [
            1,
            {
              "@": 178
            }
          ]
        },
        "60": {
          "59": [
            0,
            203
          ],
          "60": [
            0,
            129
          ],
          "10": [
            1,
            {
              "@": 114
            }
          ],
          "11": [
            1,
            {
              "@": 114
            }
          ],
          "12": [
            1,
            {
              "@": 114
            }
          ],
          "13": [
            1,
            {
              "@": 114
            }
          ],
          "9": [
            1,
            {
              "@": 114
            }
          ],
          "15": [
            1,
            {
              "@": 114
            }
          ],
          "14": [
            1,
            {
              "@": 114
            }
          ],
          "16": [
            1,
            {
              "@": 114
            }
          ],
          "17": [
            1,
            {
              "@": 114
            }
          ],
          "8": [
            1,
            {
              "@": 114
            }
          ],
          "18": [
            1,
            {
              "@": 114
            }
          ],
          "19": [
            1,
            {
              "@": 114
            }
          ],
          "20": [
            1,
            {
              "@": 114
            }
          ],
          "1": [
            1,
            {
              "@": 114
            }
          ],
          "5": [
            1,
            {
              "@": 114
            }
          ],
          "21": [
            1,
            {
              "@": 114
            }
          ],
          "22": [
            1,
            {
              "@": 114
            }
          ],
          "7": [
            1,
            {
              "@": 114
            }
          ]
        },
        "61": {
          "10": [
            1,
            {
              "@": 131
            }
          ],
          "11": [
            1,
            {
              "@": 131
            }
          ],
          "12": [
            1,
            {
              "@": 131
            }
          ],
          "13": [
            1,
            {
              "@": 131
            }
          ],
          "14": [
            1,
            {
              "@": 131
            }
          ],
          "15": [
            1,
            {
              "@": 131
            }
          ],
          "16": [
            1,
            {
              "@": 131
            }
          ],
          "17": [
            1,
            {
              "@": 131
            }
          ],
          "18": [
            1,
            {
              "@": 131
            }
          ],
          "19": [
            1,
            {
              "@": 131
            }
          ],
          "20": [
            1,
            {
              "@": 131
            }
          ],
          "1": [
            1,
            {
              "@": 131
            }
          ],
          "21": [
            1,
            {
              "@": 131
            }
          ],
          "22": [
            1,
            {
              "@": 131
            }
          ]
        },
        "62": {
          "64": [
            0,
            186
          ]
        },
        "63": {
          "19": [
            0,
            173
          ]
        },
        "64": {
          "10": [
            1,
            {
              "@": 110
            }
          ],
          "11": [
            1,
            {
              "@": 110
            }
          ],
          "12": [
            1,
            {
              "@": 110
            }
          ],
          "13": [
            1,
            {
              "@": 110
            }
          ],
          "14": [
            1,
            {
              "@": 110
            }
          ],
          "15": [
            1,
            {
              "@": 110
            }
          ],
          "16": [
            1,
            {
              "@": 110
            }
          ],
          "17": [
            1,
            {
              "@": 110
            }
          ],
          "18": [
            1,
            {
              "@": 110
            }
          ],
          "19": [
            1,
            {
              "@": 110
            }
          ],
          "20": [
            1,
            {
              "@": 110
            }
          ],
          "1": [
            1,
            {
              "@": 110
            }
          ],
          "21": [
            1,
            {
              "@": 110
            }
          ],
          "22": [
            1,
            {
              "@": 110
            }
          ]
        },
        "65": {
          "10": [
            1,
            {
              "@": 150
            }
          ],
          "11": [
            1,
            {
              "@": 150
            }
          ],
          "13": [
            1,
            {
              "@": 150
            }
          ],
          "9": [
            1,
            {
              "@": 150
            }
          ],
          "15": [
            1,
            {
              "@": 150
            }
          ],
          "18": [
            1,
            {
              "@": 150
            }
          ],
          "19": [
            1,
            {
              "@": 150
            }
          ],
          "20": [
            1,
            {
              "@": 150
            }
          ],
          "1": [
            1,
            {
              "@": 150
            }
          ],
          "22": [
            1,
            {
              "@": 150
            }
          ],
          "12": [
            1,
            {
              "@": 150
            }
          ],
          "14": [
            1,
            {
              "@": 150
            }
          ],
          "16": [
            1,
            {
              "@": 150
            }
          ],
          "17": [
            1,
            {
              "@": 150
            }
          ],
          "5": [
            1,
            {
              "@": 150
            }
          ],
          "21": [
            1,
            {
              "@": 150
            }
          ]
        },
        "66": {
          "73": [
            0,
            115
          ],
          "74": [
            0,
            127
          ],
          "75": [
            0,
            124
          ],
          "76": [
            0,
            134
          ],
          "77": [
            0,
            152
          ],
          "78": [
            0,
            154
          ],
          "79": [
            0,
            169
          ],
          "80": [
            0,
            147
          ],
          "81": [
            0,
            180
          ]
        },
        "67": {
          "63": [
            0,
            33
          ],
          "62": [
            0,
            72
          ],
          "10": [
            1,
            {
              "@": 98
            }
          ],
          "11": [
            1,
            {
              "@": 98
            }
          ],
          "12": [
            1,
            {
              "@": 98
            }
          ],
          "13": [
            1,
            {
              "@": 98
            }
          ],
          "14": [
            1,
            {
              "@": 98
            }
          ],
          "15": [
            1,
            {
              "@": 98
            }
          ],
          "16": [
            1,
            {
              "@": 98
            }
          ],
          "17": [
            1,
            {
              "@": 98
            }
          ],
          "18": [
            1,
            {
              "@": 98
            }
          ],
          "19": [
            1,
            {
              "@": 98
            }
          ],
          "20": [
            1,
            {
              "@": 98
            }
          ],
          "1": [
            1,
            {
              "@": 98
            }
          ],
          "21": [
            1,
            {
              "@": 98
            }
          ],
          "22": [
            1,
            {
              "@": 98
            }
          ]
        },
        "68": {
          "10": [
            1,
            {
              "@": 95
            }
          ],
          "11": [
            1,
            {
              "@": 95
            }
          ],
          "12": [
            1,
            {
              "@": 95
            }
          ],
          "13": [
            1,
            {
              "@": 95
            }
          ],
          "14": [
            1,
            {
              "@": 95
            }
          ],
          "15": [
            1,
            {
              "@": 95
            }
          ],
          "16": [
            1,
            {
              "@": 95
            }
          ],
          "17": [
            1,
            {
              "@": 95
            }
          ],
          "18": [
            1,
            {
              "@": 95
            }
          ],
          "19": [
            1,
            {
              "@": 95
            }
          ],
          "20": [
            1,
            {
              "@": 95
            }
          ],
          "1": [
            1,
            {
              "@": 95
            }
          ],
          "21": [
            1,
            {
              "@": 95
            }
          ],
          "22": [
            1,
            {
              "@": 95
            }
          ]
        },
        "69": {
          "10": [
            1,
            {
              "@": 148
            }
          ],
          "11": [
            1,
            {
              "@": 148
            }
          ],
          "13": [
            1,
            {
              "@": 148
            }
          ],
          "9": [
            1,
            {
              "@": 148
            }
          ],
          "15": [
            1,
            {
              "@": 148
            }
          ],
          "18": [
            1,
            {
              "@": 148
            }
          ],
          "19": [
            1,
            {
              "@": 148
            }
          ],
          "20": [
            1,
            {
              "@": 148
            }
          ],
          "1": [
            1,
            {
              "@": 148
            }
          ],
          "22": [
            1,
            {
              "@": 148
            }
          ],
          "12": [
            1,
            {
              "@": 148
            }
          ],
          "14": [
            1,
            {
              "@": 148
            }
          ],
          "16": [
            1,
            {
              "@": 148
            }
          ],
          "17": [
            1,
            {
              "@": 148
            }
          ],
          "5": [
            1,
            {
              "@": 148
            }
          ],
          "21": [
            1,
            {
              "@": 148
            }
          ]
        },
        "70": {
          "68": [
            0,
            53
          ]
        },
        "71": {
          "52": [
            0,
            16
          ],
          "10": [
            1,
            {
              "@": 100
            }
          ],
          "11": [
            1,
            {
              "@": 100
            }
          ],
          "12": [
            1,
            {
              "@": 100
            }
          ],
          "13": [
            1,
            {
              "@": 100
            }
          ],
          "14": [
            1,
            {
              "@": 100
            }
          ],
          "15": [
            1,
            {
              "@": 100
            }
          ],
          "16": [
            1,
            {
              "@": 100
            }
          ],
          "17": [
            1,
            {
              "@": 100
            }
          ],
          "18": [
            1,
            {
              "@": 100
            }
          ],
          "19": [
            1,
            {
              "@": 100
            }
          ],
          "20": [
            1,
            {
              "@": 100
            }
          ],
          "1": [
            1,
            {
              "@": 100
            }
          ],
          "21": [
            1,
            {
              "@": 100
            }
          ],
          "22": [
            1,
            {
              "@": 100
            }
          ]
        },
        "72": {
          "82": [
            0,
            185
          ]
        },
        "73": {
          "83": [
            0,
            194
          ]
        },
        "74": {
          "64": [
            0,
            188
          ]
        },
        "75": {
          "66": [
            0,
            192
          ],
          "65": [
            0,
            156
          ]
        },
        "76": {
          "25": [
            0,
            218
          ]
        },
        "77": {
          "68": [
            0,
            164
          ]
        },
        "78": {
          "84": [
            0,
            93
          ],
          "85": [
            0,
            38
          ],
          "64": [
            0,
            107
          ],
          "86": [
            0,
            86
          ],
          "83": [
            0,
            78
          ],
          "87": [
            0,
            119
          ]
        },
        "79": {
          "19": [
            0,
            29
          ]
        },
        "80": {
          "73": [
            0,
            115
          ],
          "74": [
            0,
            127
          ],
          "76": [
            0,
            134
          ],
          "75": [
            0,
            125
          ],
          "78": [
            0,
            154
          ],
          "79": [
            0,
            169
          ],
          "80": [
            0,
            147
          ],
          "81": [
            0,
            180
          ]
        },
        "81": {
          "19": [
            0,
            91
          ]
        },
        "82": {
          "10": [
            1,
            {
              "@": 115
            }
          ],
          "11": [
            1,
            {
              "@": 115
            }
          ],
          "12": [
            1,
            {
              "@": 115
            }
          ],
          "13": [
            1,
            {
              "@": 115
            }
          ],
          "14": [
            1,
            {
              "@": 115
            }
          ],
          "15": [
            1,
            {
              "@": 115
            }
          ],
          "16": [
            1,
            {
              "@": 115
            }
          ],
          "17": [
            1,
            {
              "@": 115
            }
          ],
          "18": [
            1,
            {
              "@": 115
            }
          ],
          "19": [
            1,
            {
              "@": 115
            }
          ],
          "20": [
            1,
            {
              "@": 115
            }
          ],
          "1": [
            1,
            {
              "@": 115
            }
          ],
          "21": [
            1,
            {
              "@": 115
            }
          ],
          "22": [
            1,
            {
              "@": 115
            }
          ]
        },
        "83": {
          "10": [
            1,
            {
              "@": 104
            }
          ],
          "11": [
            1,
            {
              "@": 104
            }
          ],
          "12": [
            1,
            {
              "@": 104
            }
          ],
          "13": [
            1,
            {
              "@": 104
            }
          ],
          "14": [
            1,
            {
              "@": 104
            }
          ],
          "15": [
            1,
            {
              "@": 104
            }
          ],
          "16": [
            1,
            {
              "@": 104
            }
          ],
          "17": [
            1,
            {
              "@": 104
            }
          ],
          "18": [
            1,
            {
              "@": 104
            }
          ],
          "19": [
            1,
            {
              "@": 104
            }
          ],
          "20": [
            1,
            {
              "@": 104
            }
          ],
          "1": [
            1,
            {
              "@": 104
            }
          ],
          "21": [
            1,
            {
              "@": 104
            }
          ],
          "22": [
            1,
            {
              "@": 104
            }
          ]
        },
        "84": {
          "26": [
            0,
            0
          ],
          "12": [
            0,
            73
          ],
          "46": [
            0,
            183
          ],
          "19": [
            0,
            205
          ]
        },
        "85": {
          "10": [
            1,
            {
              "@": 123
            }
          ],
          "11": [
            1,
            {
              "@": 123
            }
          ],
          "12": [
            1,
            {
              "@": 123
            }
          ],
          "13": [
            1,
            {
              "@": 123
            }
          ],
          "14": [
            1,
            {
              "@": 123
            }
          ],
          "15": [
            1,
            {
              "@": 123
            }
          ],
          "16": [
            1,
            {
              "@": 123
            }
          ],
          "17": [
            1,
            {
              "@": 123
            }
          ],
          "18": [
            1,
            {
              "@": 123
            }
          ],
          "19": [
            1,
            {
              "@": 123
            }
          ],
          "20": [
            1,
            {
              "@": 123
            }
          ],
          "1": [
            1,
            {
              "@": 123
            }
          ],
          "21": [
            1,
            {
              "@": 123
            }
          ],
          "22": [
            1,
            {
              "@": 123
            }
          ]
        },
        "86": {
          "25": [
            0,
            95
          ],
          "23": [
            0,
            210
          ]
        },
        "87": {
          "64": [
            0,
            104
          ]
        },
        "88": {
          "50": [
            0,
            130
          ],
          "10": [
            1,
            {
              "@": 180
            }
          ],
          "11": [
            1,
            {
              "@": 180
            }
          ],
          "13": [
            1,
            {
              "@": 180
            }
          ],
          "15": [
            1,
            {
              "@": 180
            }
          ],
          "18": [
            1,
            {
              "@": 180
            }
          ],
          "19": [
            1,
            {
              "@": 180
            }
          ],
          "20": [
            1,
            {
              "@": 180
            }
          ],
          "1": [
            1,
            {
              "@": 180
            }
          ],
          "22": [
            1,
            {
              "@": 180
            }
          ],
          "12": [
            1,
            {
              "@": 180
            }
          ],
          "14": [
            1,
            {
              "@": 180
            }
          ],
          "16": [
            1,
            {
              "@": 180
            }
          ],
          "17": [
            1,
            {
              "@": 180
            }
          ],
          "21": [
            1,
            {
              "@": 180
            }
          ]
        },
        "89": {
          "19": [
            0,
            135
          ]
        },
        "90": {
          "19": [
            0,
            157
          ]
        },
        "91": {
          "10": [
            1,
            {
              "@": 194
            }
          ],
          "11": [
            1,
            {
              "@": 194
            }
          ],
          "13": [
            1,
            {
              "@": 194
            }
          ],
          "15": [
            1,
            {
              "@": 194
            }
          ],
          "18": [
            1,
            {
              "@": 194
            }
          ],
          "19": [
            1,
            {
              "@": 194
            }
          ],
          "20": [
            1,
            {
              "@": 194
            }
          ],
          "1": [
            1,
            {
              "@": 194
            }
          ],
          "60": [
            1,
            {
              "@": 194
            }
          ],
          "22": [
            1,
            {
              "@": 194
            }
          ],
          "12": [
            1,
            {
              "@": 194
            }
          ],
          "14": [
            1,
            {
              "@": 194
            }
          ],
          "16": [
            1,
            {
              "@": 194
            }
          ],
          "17": [
            1,
            {
              "@": 194
            }
          ],
          "21": [
            1,
            {
              "@": 194
            }
          ]
        },
        "92": {
          "10": [
            1,
            {
              "@": 103
            }
          ],
          "11": [
            1,
            {
              "@": 103
            }
          ],
          "12": [
            1,
            {
              "@": 103
            }
          ],
          "13": [
            1,
            {
              "@": 103
            }
          ],
          "14": [
            1,
            {
              "@": 103
            }
          ],
          "15": [
            1,
            {
              "@": 103
            }
          ],
          "16": [
            1,
            {
              "@": 103
            }
          ],
          "17": [
            1,
            {
              "@": 103
            }
          ],
          "18": [
            1,
            {
              "@": 103
            }
          ],
          "19": [
            1,
            {
              "@": 103
            }
          ],
          "20": [
            1,
            {
              "@": 103
            }
          ],
          "1": [
            1,
            {
              "@": 103
            }
          ],
          "21": [
            1,
            {
              "@": 103
            }
          ],
          "22": [
            1,
            {
              "@": 103
            }
          ]
        },
        "93": {
          "88": [
            0,
            200
          ],
          "89": [
            0,
            175
          ]
        },
        "94": {
          "90": [
            0,
            136
          ]
        },
        "95": {
          "23": [
            1,
            {
              "@": 161
            }
          ],
          "24": [
            1,
            {
              "@": 161
            }
          ],
          "25": [
            1,
            {
              "@": 161
            }
          ],
          "10": [
            1,
            {
              "@": 161
            }
          ],
          "11": [
            1,
            {
              "@": 161
            }
          ],
          "13": [
            1,
            {
              "@": 161
            }
          ],
          "9": [
            1,
            {
              "@": 161
            }
          ],
          "15": [
            1,
            {
              "@": 161
            }
          ],
          "18": [
            1,
            {
              "@": 161
            }
          ],
          "19": [
            1,
            {
              "@": 161
            }
          ],
          "20": [
            1,
            {
              "@": 161
            }
          ],
          "1": [
            1,
            {
              "@": 161
            }
          ],
          "22": [
            1,
            {
              "@": 161
            }
          ],
          "7": [
            1,
            {
              "@": 161
            }
          ],
          "12": [
            1,
            {
              "@": 161
            }
          ],
          "14": [
            1,
            {
              "@": 161
            }
          ],
          "16": [
            1,
            {
              "@": 161
            }
          ],
          "17": [
            1,
            {
              "@": 161
            }
          ],
          "5": [
            1,
            {
              "@": 161
            }
          ],
          "21": [
            1,
            {
              "@": 161
            }
          ]
        },
        "96": {
          "66": [
            0,
            187
          ],
          "65": [
            0,
            156
          ]
        },
        "97": {
          "91": [
            0,
            123
          ]
        },
        "98": {
          "10": [
            1,
            {
              "@": 193
            }
          ],
          "11": [
            1,
            {
              "@": 193
            }
          ],
          "13": [
            1,
            {
              "@": 193
            }
          ],
          "15": [
            1,
            {
              "@": 193
            }
          ],
          "18": [
            1,
            {
              "@": 193
            }
          ],
          "19": [
            1,
            {
              "@": 193
            }
          ],
          "20": [
            1,
            {
              "@": 193
            }
          ],
          "1": [
            1,
            {
              "@": 193
            }
          ],
          "60": [
            1,
            {
              "@": 193
            }
          ],
          "22": [
            1,
            {
              "@": 193
            }
          ],
          "12": [
            1,
            {
              "@": 193
            }
          ],
          "14": [
            1,
            {
              "@": 193
            }
          ],
          "16": [
            1,
            {
              "@": 193
            }
          ],
          "17": [
            1,
            {
              "@": 193
            }
          ],
          "21": [
            1,
            {
              "@": 193
            }
          ]
        },
        "99": {
          "10": [
            1,
            {
              "@": 117
            }
          ],
          "11": [
            1,
            {
              "@": 117
            }
          ],
          "12": [
            1,
            {
              "@": 117
            }
          ],
          "13": [
            1,
            {
              "@": 117
            }
          ],
          "14": [
            1,
            {
              "@": 117
            }
          ],
          "15": [
            1,
            {
              "@": 117
            }
          ],
          "16": [
            1,
            {
              "@": 117
            }
          ],
          "17": [
            1,
            {
              "@": 117
            }
          ],
          "18": [
            1,
            {
              "@": 117
            }
          ],
          "19": [
            1,
            {
              "@": 117
            }
          ],
          "20": [
            1,
            {
              "@": 117
            }
          ],
          "1": [
            1,
            {
              "@": 117
            }
          ],
          "21": [
            1,
            {
              "@": 117
            }
          ],
          "22": [
            1,
            {
              "@": 117
            }
          ]
        },
        "100": {
          "10": [
            1,
            {
              "@": 153
            }
          ],
          "11": [
            1,
            {
              "@": 153
            }
          ],
          "13": [
            1,
            {
              "@": 153
            }
          ],
          "15": [
            1,
            {
              "@": 153
            }
          ],
          "18": [
            1,
            {
              "@": 153
            }
          ],
          "19": [
            1,
            {
              "@": 153
            }
          ],
          "20": [
            1,
            {
              "@": 153
            }
          ],
          "1": [
            1,
            {
              "@": 153
            }
          ],
          "22": [
            1,
            {
              "@": 153
            }
          ],
          "12": [
            1,
            {
              "@": 153
            }
          ],
          "14": [
            1,
            {
              "@": 153
            }
          ],
          "16": [
            1,
            {
              "@": 153
            }
          ],
          "17": [
            1,
            {
              "@": 153
            }
          ],
          "21": [
            1,
            {
              "@": 153
            }
          ]
        },
        "101": {
          "92": [
            0,
            181
          ]
        },
        "102": {
          "25": [
            0,
            110
          ]
        },
        "103": {
          "10": [
            1,
            {
              "@": 119
            }
          ],
          "11": [
            1,
            {
              "@": 119
            }
          ],
          "12": [
            1,
            {
              "@": 119
            }
          ],
          "13": [
            1,
            {
              "@": 119
            }
          ],
          "14": [
            1,
            {
              "@": 119
            }
          ],
          "15": [
            1,
            {
              "@": 119
            }
          ],
          "16": [
            1,
            {
              "@": 119
            }
          ],
          "17": [
            1,
            {
              "@": 119
            }
          ],
          "18": [
            1,
            {
              "@": 119
            }
          ],
          "19": [
            1,
            {
              "@": 119
            }
          ],
          "20": [
            1,
            {
              "@": 119
            }
          ],
          "1": [
            1,
            {
              "@": 119
            }
          ],
          "21": [
            1,
            {
              "@": 119
            }
          ],
          "22": [
            1,
            {
              "@": 119
            }
          ]
        },
        "104": {
          "50": [
            0,
            31
          ]
        },
        "105": {
          "23": [
            0,
            210
          ],
          "10": [
            1,
            {
              "@": 154
            }
          ],
          "11": [
            1,
            {
              "@": 154
            }
          ],
          "13": [
            1,
            {
              "@": 154
            }
          ],
          "9": [
            1,
            {
              "@": 154
            }
          ],
          "15": [
            1,
            {
              "@": 154
            }
          ],
          "18": [
            1,
            {
              "@": 154
            }
          ],
          "19": [
            1,
            {
              "@": 154
            }
          ],
          "20": [
            1,
            {
              "@": 154
            }
          ],
          "1": [
            1,
            {
              "@": 154
            }
          ],
          "22": [
            1,
            {
              "@": 154
            }
          ],
          "7": [
            1,
            {
              "@": 154
            }
          ],
          "12": [
            1,
            {
              "@": 154
            }
          ],
          "14": [
            1,
            {
              "@": 154
            }
          ],
          "16": [
            1,
            {
              "@": 154
            }
          ],
          "17": [
            1,
            {
              "@": 154
            }
          ],
          "5": [
            1,
            {
              "@": 154
            }
          ],
          "21": [
            1,
            {
              "@": 154
            }
          ]
        },
        "106": {
          "9": [
            0,
            122
          ],
          "3": [
            0,
            85
          ],
          "10": [
            1,
            {
              "@": 124
            }
          ],
          "11": [
            1,
            {
              "@": 124
            }
          ],
          "12": [
            1,
            {
              "@": 124
            }
          ],
          "13": [
            1,
            {
              "@": 124
            }
          ],
          "14": [
            1,
            {
              "@": 124
            }
          ],
          "15": [
            1,
            {
              "@": 124
            }
          ],
          "16": [
            1,
            {
              "@": 124
            }
          ],
          "17": [
            1,
            {
              "@": 124
            }
          ],
          "18": [
            1,
            {
              "@": 124
            }
          ],
          "19": [
            1,
            {
              "@": 124
            }
          ],
          "20": [
            1,
            {
              "@": 124
            }
          ],
          "1": [
            1,
            {
              "@": 124
            }
          ],
          "21": [
            1,
            {
              "@": 124
            }
          ],
          "22": [
            1,
            {
              "@": 124
            }
          ]
        },
        "107": {
          "88": [
            1,
            {
              "@": 162
            }
          ],
          "89": [
            1,
            {
              "@": 162
            }
          ]
        },
        "108": {
          "10": [
            1,
            {
              "@": 72
            }
          ],
          "11": [
            1,
            {
              "@": 72
            }
          ],
          "12": [
            1,
            {
              "@": 72
            }
          ],
          "13": [
            1,
            {
              "@": 72
            }
          ],
          "14": [
            1,
            {
              "@": 72
            }
          ],
          "15": [
            1,
            {
              "@": 72
            }
          ],
          "16": [
            1,
            {
              "@": 72
            }
          ],
          "17": [
            1,
            {
              "@": 72
            }
          ],
          "18": [
            1,
            {
              "@": 72
            }
          ],
          "19": [
            1,
            {
              "@": 72
            }
          ],
          "20": [
            1,
            {
              "@": 72
            }
          ],
          "1": [
            1,
            {
              "@": 72
            }
          ],
          "21": [
            1,
            {
              "@": 72
            }
          ],
          "22": [
            1,
            {
              "@": 72
            }
          ]
        },
        "109": {
          "10": [
            1,
            {
              "@": 202
            }
          ],
          "11": [
            1,
            {
              "@": 202
            }
          ],
          "13": [
            1,
            {
              "@": 202
            }
          ],
          "15": [
            1,
            {
              "@": 202
            }
          ],
          "18": [
            1,
            {
              "@": 202
            }
          ],
          "19": [
            1,
            {
              "@": 202
            }
          ],
          "20": [
            1,
            {
              "@": 202
            }
          ],
          "1": [
            1,
            {
              "@": 202
            }
          ],
          "22": [
            1,
            {
              "@": 202
            }
          ],
          "12": [
            1,
            {
              "@": 202
            }
          ],
          "14": [
            1,
            {
              "@": 202
            }
          ],
          "16": [
            1,
            {
              "@": 202
            }
          ],
          "17": [
            1,
            {
              "@": 202
            }
          ],
          "52": [
            1,
            {
              "@": 202
            }
          ],
          "50": [
            1,
            {
              "@": 202
            }
          ],
          "21": [
            1,
            {
              "@": 202
            }
          ]
        },
        "110": {
          "10": [
            1,
            {
              "@": 113
            }
          ],
          "11": [
            1,
            {
              "@": 113
            }
          ],
          "12": [
            1,
            {
              "@": 113
            }
          ],
          "13": [
            1,
            {
              "@": 113
            }
          ],
          "9": [
            1,
            {
              "@": 113
            }
          ],
          "14": [
            1,
            {
              "@": 113
            }
          ],
          "15": [
            1,
            {
              "@": 113
            }
          ],
          "16": [
            1,
            {
              "@": 113
            }
          ],
          "17": [
            1,
            {
              "@": 113
            }
          ],
          "8": [
            1,
            {
              "@": 113
            }
          ],
          "18": [
            1,
            {
              "@": 113
            }
          ],
          "19": [
            1,
            {
              "@": 113
            }
          ],
          "20": [
            1,
            {
              "@": 113
            }
          ],
          "1": [
            1,
            {
              "@": 113
            }
          ],
          "5": [
            1,
            {
              "@": 113
            }
          ],
          "21": [
            1,
            {
              "@": 113
            }
          ],
          "22": [
            1,
            {
              "@": 113
            }
          ],
          "7": [
            1,
            {
              "@": 113
            }
          ]
        },
        "111": {
          "49": [
            0,
            211
          ],
          "10": [
            1,
            {
              "@": 166
            }
          ],
          "11": [
            1,
            {
              "@": 166
            }
          ],
          "13": [
            1,
            {
              "@": 166
            }
          ],
          "15": [
            1,
            {
              "@": 166
            }
          ],
          "18": [
            1,
            {
              "@": 166
            }
          ],
          "19": [
            1,
            {
              "@": 166
            }
          ],
          "20": [
            1,
            {
              "@": 166
            }
          ],
          "1": [
            1,
            {
              "@": 166
            }
          ],
          "22": [
            1,
            {
              "@": 166
            }
          ],
          "12": [
            1,
            {
              "@": 166
            }
          ],
          "14": [
            1,
            {
              "@": 166
            }
          ],
          "16": [
            1,
            {
              "@": 166
            }
          ],
          "17": [
            1,
            {
              "@": 166
            }
          ],
          "21": [
            1,
            {
              "@": 166
            }
          ]
        },
        "112": {
          "10": [
            1,
            {
              "@": 125
            }
          ],
          "11": [
            1,
            {
              "@": 125
            }
          ],
          "12": [
            1,
            {
              "@": 125
            }
          ],
          "13": [
            1,
            {
              "@": 125
            }
          ],
          "14": [
            1,
            {
              "@": 125
            }
          ],
          "15": [
            1,
            {
              "@": 125
            }
          ],
          "16": [
            1,
            {
              "@": 125
            }
          ],
          "17": [
            1,
            {
              "@": 125
            }
          ],
          "18": [
            1,
            {
              "@": 125
            }
          ],
          "19": [
            1,
            {
              "@": 125
            }
          ],
          "20": [
            1,
            {
              "@": 125
            }
          ],
          "1": [
            1,
            {
              "@": 125
            }
          ],
          "21": [
            1,
            {
              "@": 125
            }
          ],
          "22": [
            1,
            {
              "@": 125
            }
          ]
        },
        "113": {
          "26": [
            0,
            0
          ],
          "18": [
            0,
            63
          ],
          "1": [
            0,
            89
          ],
          "19": [
            0,
            25
          ],
          "27": [
            0,
            30
          ],
          "22": [
            0,
            12
          ],
          "14": [
            0,
            48
          ],
          "28": [
            0,
            14
          ],
          "20": [
            0,
            84
          ],
          "31": [
            0,
            3
          ],
          "32": [
            0,
            28
          ],
          "29": [
            0,
            166
          ],
          "33": [
            0,
            34
          ],
          "11": [
            0,
            90
          ],
          "34": [
            0,
            37
          ],
          "17": [
            0,
            27
          ],
          "13": [
            0,
            97
          ],
          "16": [
            0,
            50
          ],
          "35": [
            0,
            6
          ],
          "36": [
            0,
            13
          ],
          "12": [
            0,
            73
          ],
          "37": [
            0,
            1
          ],
          "15": [
            0,
            77
          ],
          "38": [
            0,
            58
          ],
          "39": [
            0,
            23
          ],
          "40": [
            0,
            220
          ],
          "41": [
            0,
            146
          ],
          "42": [
            0,
            168
          ],
          "21": [
            0,
            138
          ],
          "43": [
            0,
            219
          ],
          "44": [
            0,
            208
          ],
          "46": [
            0,
            196
          ],
          "10": [
            1,
            {
              "@": 68
            }
          ]
        },
        "114": {
          "9": [
            0,
            122
          ],
          "3": [
            0,
            82
          ],
          "10": [
            1,
            {
              "@": 116
            }
          ],
          "11": [
            1,
            {
              "@": 116
            }
          ],
          "12": [
            1,
            {
              "@": 116
            }
          ],
          "13": [
            1,
            {
              "@": 116
            }
          ],
          "14": [
            1,
            {
              "@": 116
            }
          ],
          "15": [
            1,
            {
              "@": 116
            }
          ],
          "16": [
            1,
            {
              "@": 116
            }
          ],
          "17": [
            1,
            {
              "@": 116
            }
          ],
          "18": [
            1,
            {
              "@": 116
            }
          ],
          "19": [
            1,
            {
              "@": 116
            }
          ],
          "20": [
            1,
            {
              "@": 116
            }
          ],
          "1": [
            1,
            {
              "@": 116
            }
          ],
          "21": [
            1,
            {
              "@": 116
            }
          ],
          "22": [
            1,
            {
              "@": 116
            }
          ]
        },
        "115": {
          "83": [
            1,
            {
              "@": 189
            }
          ]
        },
        "116": {
          "9": [
            0,
            122
          ],
          "3": [
            0,
            172
          ],
          "10": [
            1,
            {
              "@": 140
            }
          ],
          "11": [
            1,
            {
              "@": 140
            }
          ],
          "12": [
            1,
            {
              "@": 140
            }
          ],
          "13": [
            1,
            {
              "@": 140
            }
          ],
          "14": [
            1,
            {
              "@": 140
            }
          ],
          "15": [
            1,
            {
              "@": 140
            }
          ],
          "16": [
            1,
            {
              "@": 140
            }
          ],
          "17": [
            1,
            {
              "@": 140
            }
          ],
          "18": [
            1,
            {
              "@": 140
            }
          ],
          "19": [
            1,
            {
              "@": 140
            }
          ],
          "20": [
            1,
            {
              "@": 140
            }
          ],
          "1": [
            1,
            {
              "@": 140
            }
          ],
          "21": [
            1,
            {
              "@": 140
            }
          ],
          "22": [
            1,
            {
              "@": 140
            }
          ]
        },
        "117": {
          "5": [
            0,
            191
          ],
          "9": [
            0,
            122
          ],
          "4": [
            0,
            114
          ],
          "3": [
            0,
            99
          ],
          "10": [
            1,
            {
              "@": 118
            }
          ],
          "11": [
            1,
            {
              "@": 118
            }
          ],
          "12": [
            1,
            {
              "@": 118
            }
          ],
          "13": [
            1,
            {
              "@": 118
            }
          ],
          "14": [
            1,
            {
              "@": 118
            }
          ],
          "15": [
            1,
            {
              "@": 118
            }
          ],
          "16": [
            1,
            {
              "@": 118
            }
          ],
          "17": [
            1,
            {
              "@": 118
            }
          ],
          "18": [
            1,
            {
              "@": 118
            }
          ],
          "19": [
            1,
            {
              "@": 118
            }
          ],
          "20": [
            1,
            {
              "@": 118
            }
          ],
          "1": [
            1,
            {
              "@": 118
            }
          ],
          "21": [
            1,
            {
              "@": 118
            }
          ],
          "22": [
            1,
            {
              "@": 118
            }
          ]
        },
        "118": {
          "93": [
            0,
            206
          ],
          "94": [
            0,
            195
          ],
          "95": [
            0,
            163
          ],
          "96": [
            0,
            202
          ]
        },
        "119": {
          "23": [
            1,
            {
              "@": 157
            }
          ],
          "24": [
            1,
            {
              "@": 157
            }
          ],
          "25": [
            1,
            {
              "@": 157
            }
          ],
          "10": [
            1,
            {
              "@": 157
            }
          ],
          "11": [
            1,
            {
              "@": 157
            }
          ],
          "13": [
            1,
            {
              "@": 157
            }
          ],
          "9": [
            1,
            {
              "@": 157
            }
          ],
          "15": [
            1,
            {
              "@": 157
            }
          ],
          "18": [
            1,
            {
              "@": 157
            }
          ],
          "19": [
            1,
            {
              "@": 157
            }
          ],
          "20": [
            1,
            {
              "@": 157
            }
          ],
          "1": [
            1,
            {
              "@": 157
            }
          ],
          "22": [
            1,
            {
              "@": 157
            }
          ],
          "7": [
            1,
            {
              "@": 157
            }
          ],
          "12": [
            1,
            {
              "@": 157
            }
          ],
          "14": [
            1,
            {
              "@": 157
            }
          ],
          "16": [
            1,
            {
              "@": 157
            }
          ],
          "17": [
            1,
            {
              "@": 157
            }
          ],
          "5": [
            1,
            {
              "@": 157
            }
          ],
          "21": [
            1,
            {
              "@": 157
            }
          ]
        },
        "120": {
          "10": [
            1,
            {
              "@": 163
            }
          ],
          "11": [
            1,
            {
              "@": 163
            }
          ],
          "13": [
            1,
            {
              "@": 163
            }
          ],
          "9": [
            1,
            {
              "@": 163
            }
          ],
          "15": [
            1,
            {
              "@": 163
            }
          ],
          "18": [
            1,
            {
              "@": 163
            }
          ],
          "19": [
            1,
            {
              "@": 163
            }
          ],
          "20": [
            1,
            {
              "@": 163
            }
          ],
          "1": [
            1,
            {
              "@": 163
            }
          ],
          "22": [
            1,
            {
              "@": 163
            }
          ],
          "24": [
            1,
            {
              "@": 163
            }
          ],
          "7": [
            1,
            {
              "@": 163
            }
          ],
          "12": [
            1,
            {
              "@": 163
            }
          ],
          "23": [
            1,
            {
              "@": 163
            }
          ],
          "14": [
            1,
            {
              "@": 163
            }
          ],
          "16": [
            1,
            {
              "@": 163
            }
          ],
          "17": [
            1,
            {
              "@": 163
            }
          ],
          "5": [
            1,
            {
              "@": 163
            }
          ],
          "21": [
            1,
            {
              "@": 163
            }
          ],
          "25": [
            1,
            {
              "@": 163
            }
          ]
        },
        "121": {
          "10": [
            1,
            {
              "@": 200
            }
          ],
          "11": [
            1,
            {
              "@": 200
            }
          ],
          "13": [
            1,
            {
              "@": 200
            }
          ],
          "15": [
            1,
            {
              "@": 200
            }
          ],
          "18": [
            1,
            {
              "@": 200
            }
          ],
          "19": [
            1,
            {
              "@": 200
            }
          ],
          "20": [
            1,
            {
              "@": 200
            }
          ],
          "1": [
            1,
            {
              "@": 200
            }
          ],
          "22": [
            1,
            {
              "@": 200
            }
          ],
          "12": [
            1,
            {
              "@": 200
            }
          ],
          "14": [
            1,
            {
              "@": 200
            }
          ],
          "16": [
            1,
            {
              "@": 200
            }
          ],
          "17": [
            1,
            {
              "@": 200
            }
          ],
          "52": [
            1,
            {
              "@": 200
            }
          ],
          "50": [
            1,
            {
              "@": 200
            }
          ],
          "21": [
            1,
            {
              "@": 200
            }
          ]
        },
        "122": {
          "97": [
            0,
            100
          ]
        },
        "123": {
          "98": [
            0,
            55
          ]
        },
        "124": {
          "99": [
            0,
            88
          ],
          "50": [
            0,
            80
          ],
          "10": [
            1,
            {
              "@": 181
            }
          ],
          "11": [
            1,
            {
              "@": 181
            }
          ],
          "13": [
            1,
            {
              "@": 181
            }
          ],
          "15": [
            1,
            {
              "@": 181
            }
          ],
          "18": [
            1,
            {
              "@": 181
            }
          ],
          "19": [
            1,
            {
              "@": 181
            }
          ],
          "20": [
            1,
            {
              "@": 181
            }
          ],
          "1": [
            1,
            {
              "@": 181
            }
          ],
          "22": [
            1,
            {
              "@": 181
            }
          ],
          "12": [
            1,
            {
              "@": 181
            }
          ],
          "14": [
            1,
            {
              "@": 181
            }
          ],
          "16": [
            1,
            {
              "@": 181
            }
          ],
          "17": [
            1,
            {
              "@": 181
            }
          ],
          "21": [
            1,
            {
              "@": 181
            }
          ]
        },
        "125": {
          "10": [
            1,
            {
              "@": 203
            }
          ],
          "11": [
            1,
            {
              "@": 203
            }
          ],
          "12": [
            1,
            {
              "@": 203
            }
          ],
          "13": [
            1,
            {
              "@": 203
            }
          ],
          "15": [
            1,
            {
              "@": 203
            }
          ],
          "14": [
            1,
            {
              "@": 203
            }
          ],
          "16": [
            1,
            {
              "@": 203
            }
          ],
          "17": [
            1,
            {
              "@": 203
            }
          ],
          "18": [
            1,
            {
              "@": 203
            }
          ],
          "19": [
            1,
            {
              "@": 203
            }
          ],
          "20": [
            1,
            {
              "@": 203
            }
          ],
          "1": [
            1,
            {
              "@": 203
            }
          ],
          "50": [
            1,
            {
              "@": 203
            }
          ],
          "21": [
            1,
            {
              "@": 203
            }
          ],
          "22": [
            1,
            {
              "@": 203
            }
          ]
        },
        "126": {
          "5": [
            0,
            191
          ],
          "6": [
            0,
            177
          ],
          "1": [
            0,
            212
          ],
          "4": [
            0,
            214
          ],
          "3": [
            0,
            174
          ],
          "9": [
            0,
            122
          ],
          "10": [
            1,
            {
              "@": 138
            }
          ],
          "11": [
            1,
            {
              "@": 138
            }
          ],
          "12": [
            1,
            {
              "@": 138
            }
          ],
          "13": [
            1,
            {
              "@": 138
            }
          ],
          "14": [
            1,
            {
              "@": 138
            }
          ],
          "15": [
            1,
            {
              "@": 138
            }
          ],
          "16": [
            1,
            {
              "@": 138
            }
          ],
          "17": [
            1,
            {
              "@": 138
            }
          ],
          "18": [
            1,
            {
              "@": 138
            }
          ],
          "19": [
            1,
            {
              "@": 138
            }
          ],
          "20": [
            1,
            {
              "@": 138
            }
          ],
          "21": [
            1,
            {
              "@": 138
            }
          ],
          "22": [
            1,
            {
              "@": 138
            }
          ]
        },
        "127": {
          "83": [
            0,
            49
          ]
        },
        "128": {
          "7": [
            0,
            182
          ],
          "6": [
            0,
            139
          ],
          "2": [
            0,
            144
          ],
          "1": [
            0,
            212
          ],
          "4": [
            0,
            160
          ],
          "3": [
            0,
            176
          ],
          "5": [
            0,
            191
          ],
          "9": [
            0,
            122
          ],
          "10": [
            1,
            {
              "@": 130
            }
          ],
          "11": [
            1,
            {
              "@": 130
            }
          ],
          "12": [
            1,
            {
              "@": 130
            }
          ],
          "13": [
            1,
            {
              "@": 130
            }
          ],
          "14": [
            1,
            {
              "@": 130
            }
          ],
          "15": [
            1,
            {
              "@": 130
            }
          ],
          "16": [
            1,
            {
              "@": 130
            }
          ],
          "17": [
            1,
            {
              "@": 130
            }
          ],
          "18": [
            1,
            {
              "@": 130
            }
          ],
          "19": [
            1,
            {
              "@": 130
            }
          ],
          "20": [
            1,
            {
              "@": 130
            }
          ],
          "21": [
            1,
            {
              "@": 130
            }
          ],
          "22": [
            1,
            {
              "@": 130
            }
          ]
        },
        "129": {
          "19": [
            0,
            98
          ]
        },
        "130": {
          "73": [
            0,
            115
          ],
          "74": [
            0,
            127
          ],
          "76": [
            0,
            134
          ],
          "75": [
            0,
            159
          ],
          "78": [
            0,
            154
          ],
          "79": [
            0,
            169
          ],
          "80": [
            0,
            147
          ],
          "81": [
            0,
            180
          ]
        },
        "131": {
          "10": [
            1,
            {
              "@": 121
            }
          ],
          "11": [
            1,
            {
              "@": 121
            }
          ],
          "12": [
            1,
            {
              "@": 121
            }
          ],
          "13": [
            1,
            {
              "@": 121
            }
          ],
          "14": [
            1,
            {
              "@": 121
            }
          ],
          "15": [
            1,
            {
              "@": 121
            }
          ],
          "16": [
            1,
            {
              "@": 121
            }
          ],
          "17": [
            1,
            {
              "@": 121
            }
          ],
          "18": [
            1,
            {
              "@": 121
            }
          ],
          "19": [
            1,
            {
              "@": 121
            }
          ],
          "20": [
            1,
            {
              "@": 121
            }
          ],
          "1": [
            1,
            {
              "@": 121
            }
          ],
          "21": [
            1,
            {
              "@": 121
            }
          ],
          "22": [
            1,
            {
              "@": 121
            }
          ]
        },
        "132": {
          "100": [
            0,
            87
          ],
          "10": [
            1,
            {
              "@": 102
            }
          ],
          "11": [
            1,
            {
              "@": 102
            }
          ],
          "12": [
            1,
            {
              "@": 102
            }
          ],
          "13": [
            1,
            {
              "@": 102
            }
          ],
          "14": [
            1,
            {
              "@": 102
            }
          ],
          "15": [
            1,
            {
              "@": 102
            }
          ],
          "16": [
            1,
            {
              "@": 102
            }
          ],
          "17": [
            1,
            {
              "@": 102
            }
          ],
          "18": [
            1,
            {
              "@": 102
            }
          ],
          "19": [
            1,
            {
              "@": 102
            }
          ],
          "20": [
            1,
            {
              "@": 102
            }
          ],
          "1": [
            1,
            {
              "@": 102
            }
          ],
          "21": [
            1,
            {
              "@": 102
            }
          ],
          "22": [
            1,
            {
              "@": 102
            }
          ]
        },
        "133": {
          "61": [
            0,
            118
          ]
        },
        "134": {
          "83": [
            1,
            {
              "@": 187
            }
          ]
        },
        "135": {
          "100": [
            0,
            74
          ]
        },
        "136": {
          "92": [
            0,
            178
          ]
        },
        "137": {
          "10": [
            1,
            {
              "@": 133
            }
          ],
          "11": [
            1,
            {
              "@": 133
            }
          ],
          "12": [
            1,
            {
              "@": 133
            }
          ],
          "13": [
            1,
            {
              "@": 133
            }
          ],
          "14": [
            1,
            {
              "@": 133
            }
          ],
          "15": [
            1,
            {
              "@": 133
            }
          ],
          "16": [
            1,
            {
              "@": 133
            }
          ],
          "17": [
            1,
            {
              "@": 133
            }
          ],
          "18": [
            1,
            {
              "@": 133
            }
          ],
          "19": [
            1,
            {
              "@": 133
            }
          ],
          "20": [
            1,
            {
              "@": 133
            }
          ],
          "1": [
            1,
            {
              "@": 133
            }
          ],
          "21": [
            1,
            {
              "@": 133
            }
          ],
          "22": [
            1,
            {
              "@": 133
            }
          ]
        },
        "138": {
          "19": [
            0,
            197
          ]
        },
        "139": {
          "5": [
            0,
            191
          ],
          "9": [
            0,
            122
          ],
          "3": [
            0,
            112
          ],
          "4": [
            0,
            106
          ],
          "10": [
            1,
            {
              "@": 126
            }
          ],
          "11": [
            1,
            {
              "@": 126
            }
          ],
          "12": [
            1,
            {
              "@": 126
            }
          ],
          "13": [
            1,
            {
              "@": 126
            }
          ],
          "14": [
            1,
            {
              "@": 126
            }
          ],
          "15": [
            1,
            {
              "@": 126
            }
          ],
          "16": [
            1,
            {
              "@": 126
            }
          ],
          "17": [
            1,
            {
              "@": 126
            }
          ],
          "18": [
            1,
            {
              "@": 126
            }
          ],
          "19": [
            1,
            {
              "@": 126
            }
          ],
          "20": [
            1,
            {
              "@": 126
            }
          ],
          "1": [
            1,
            {
              "@": 126
            }
          ],
          "21": [
            1,
            {
              "@": 126
            }
          ],
          "22": [
            1,
            {
              "@": 126
            }
          ]
        },
        "140": {
          "10": [
            1,
            {
              "@": 199
            }
          ],
          "11": [
            1,
            {
              "@": 199
            }
          ],
          "13": [
            1,
            {
              "@": 199
            }
          ],
          "15": [
            1,
            {
              "@": 199
            }
          ],
          "18": [
            1,
            {
              "@": 199
            }
          ],
          "19": [
            1,
            {
              "@": 199
            }
          ],
          "20": [
            1,
            {
              "@": 199
            }
          ],
          "1": [
            1,
            {
              "@": 199
            }
          ],
          "22": [
            1,
            {
              "@": 199
            }
          ],
          "12": [
            1,
            {
              "@": 199
            }
          ],
          "14": [
            1,
            {
              "@": 199
            }
          ],
          "16": [
            1,
            {
              "@": 199
            }
          ],
          "17": [
            1,
            {
              "@": 199
            }
          ],
          "52": [
            1,
            {
              "@": 199
            }
          ],
          "50": [
            1,
            {
              "@": 199
            }
          ],
          "21": [
            1,
            {
              "@": 199
            }
          ]
        },
        "141": {
          "5": [
            0,
            191
          ],
          "9": [
            0,
            122
          ],
          "4": [
            0,
            116
          ],
          "3": [
            0,
            24
          ],
          "10": [
            1,
            {
              "@": 142
            }
          ],
          "11": [
            1,
            {
              "@": 142
            }
          ],
          "12": [
            1,
            {
              "@": 142
            }
          ],
          "13": [
            1,
            {
              "@": 142
            }
          ],
          "14": [
            1,
            {
              "@": 142
            }
          ],
          "15": [
            1,
            {
              "@": 142
            }
          ],
          "16": [
            1,
            {
              "@": 142
            }
          ],
          "17": [
            1,
            {
              "@": 142
            }
          ],
          "18": [
            1,
            {
              "@": 142
            }
          ],
          "19": [
            1,
            {
              "@": 142
            }
          ],
          "20": [
            1,
            {
              "@": 142
            }
          ],
          "1": [
            1,
            {
              "@": 142
            }
          ],
          "21": [
            1,
            {
              "@": 142
            }
          ],
          "22": [
            1,
            {
              "@": 142
            }
          ]
        },
        "142": {
          "64": [
            0,
            143
          ]
        },
        "143": {
          "101": [
            0,
            19
          ],
          "102": [
            0,
            65
          ],
          "10": [
            1,
            {
              "@": 151
            }
          ],
          "11": [
            1,
            {
              "@": 151
            }
          ],
          "13": [
            1,
            {
              "@": 151
            }
          ],
          "9": [
            1,
            {
              "@": 151
            }
          ],
          "15": [
            1,
            {
              "@": 151
            }
          ],
          "18": [
            1,
            {
              "@": 151
            }
          ],
          "19": [
            1,
            {
              "@": 151
            }
          ],
          "20": [
            1,
            {
              "@": 151
            }
          ],
          "1": [
            1,
            {
              "@": 151
            }
          ],
          "22": [
            1,
            {
              "@": 151
            }
          ],
          "12": [
            1,
            {
              "@": 151
            }
          ],
          "14": [
            1,
            {
              "@": 151
            }
          ],
          "16": [
            1,
            {
              "@": 151
            }
          ],
          "17": [
            1,
            {
              "@": 151
            }
          ],
          "5": [
            1,
            {
              "@": 151
            }
          ],
          "21": [
            1,
            {
              "@": 151
            }
          ]
        },
        "144": {
          "5": [
            0,
            191
          ],
          "4": [
            0,
            21
          ],
          "1": [
            0,
            212
          ],
          "6": [
            0,
            117
          ],
          "9": [
            0,
            122
          ],
          "3": [
            0,
            131
          ],
          "10": [
            1,
            {
              "@": 122
            }
          ],
          "11": [
            1,
            {
              "@": 122
            }
          ],
          "12": [
            1,
            {
              "@": 122
            }
          ],
          "13": [
            1,
            {
              "@": 122
            }
          ],
          "14": [
            1,
            {
              "@": 122
            }
          ],
          "15": [
            1,
            {
              "@": 122
            }
          ],
          "16": [
            1,
            {
              "@": 122
            }
          ],
          "17": [
            1,
            {
              "@": 122
            }
          ],
          "18": [
            1,
            {
              "@": 122
            }
          ],
          "19": [
            1,
            {
              "@": 122
            }
          ],
          "20": [
            1,
            {
              "@": 122
            }
          ],
          "21": [
            1,
            {
              "@": 122
            }
          ],
          "22": [
            1,
            {
              "@": 122
            }
          ]
        },
        "145": {
          "19": [
            0,
            121
          ]
        },
        "146": {
          "10": [
            1,
            {
              "@": 70
            }
          ],
          "11": [
            1,
            {
              "@": 70
            }
          ],
          "12": [
            1,
            {
              "@": 70
            }
          ],
          "13": [
            1,
            {
              "@": 70
            }
          ],
          "14": [
            1,
            {
              "@": 70
            }
          ],
          "15": [
            1,
            {
              "@": 70
            }
          ],
          "16": [
            1,
            {
              "@": 70
            }
          ],
          "17": [
            1,
            {
              "@": 70
            }
          ],
          "18": [
            1,
            {
              "@": 70
            }
          ],
          "19": [
            1,
            {
              "@": 70
            }
          ],
          "20": [
            1,
            {
              "@": 70
            }
          ],
          "1": [
            1,
            {
              "@": 70
            }
          ],
          "21": [
            1,
            {
              "@": 70
            }
          ],
          "22": [
            1,
            {
              "@": 70
            }
          ]
        },
        "147": {
          "83": [
            1,
            {
              "@": 186
            }
          ]
        },
        "148": {
          "69": [
            0,
            42
          ]
        },
        "149": {
          "10": [
            1,
            {
              "@": 195
            }
          ],
          "11": [
            1,
            {
              "@": 195
            }
          ],
          "12": [
            1,
            {
              "@": 195
            }
          ],
          "21": [
            1,
            {
              "@": 195
            }
          ],
          "13": [
            1,
            {
              "@": 195
            }
          ],
          "15": [
            1,
            {
              "@": 195
            }
          ],
          "14": [
            1,
            {
              "@": 195
            }
          ],
          "16": [
            1,
            {
              "@": 195
            }
          ],
          "17": [
            1,
            {
              "@": 195
            }
          ],
          "18": [
            1,
            {
              "@": 195
            }
          ],
          "19": [
            1,
            {
              "@": 195
            }
          ],
          "20": [
            1,
            {
              "@": 195
            }
          ],
          "1": [
            1,
            {
              "@": 195
            }
          ],
          "49": [
            1,
            {
              "@": 195
            }
          ],
          "22": [
            1,
            {
              "@": 195
            }
          ]
        },
        "150": {
          "9": [
            0,
            122
          ],
          "3": [
            0,
            170
          ],
          "10": [
            1,
            {
              "@": 144
            }
          ],
          "11": [
            1,
            {
              "@": 144
            }
          ],
          "12": [
            1,
            {
              "@": 144
            }
          ],
          "13": [
            1,
            {
              "@": 144
            }
          ],
          "14": [
            1,
            {
              "@": 144
            }
          ],
          "15": [
            1,
            {
              "@": 144
            }
          ],
          "16": [
            1,
            {
              "@": 144
            }
          ],
          "17": [
            1,
            {
              "@": 144
            }
          ],
          "18": [
            1,
            {
              "@": 144
            }
          ],
          "19": [
            1,
            {
              "@": 144
            }
          ],
          "20": [
            1,
            {
              "@": 144
            }
          ],
          "1": [
            1,
            {
              "@": 144
            }
          ],
          "21": [
            1,
            {
              "@": 144
            }
          ],
          "22": [
            1,
            {
              "@": 144
            }
          ]
        },
        "151": {
          "103": [
            0,
            70
          ],
          "10": [
            1,
            {
              "@": 109
            }
          ],
          "11": [
            1,
            {
              "@": 109
            }
          ],
          "12": [
            1,
            {
              "@": 109
            }
          ],
          "13": [
            1,
            {
              "@": 109
            }
          ],
          "14": [
            1,
            {
              "@": 109
            }
          ],
          "15": [
            1,
            {
              "@": 109
            }
          ],
          "16": [
            1,
            {
              "@": 109
            }
          ],
          "17": [
            1,
            {
              "@": 109
            }
          ],
          "18": [
            1,
            {
              "@": 109
            }
          ],
          "19": [
            1,
            {
              "@": 109
            }
          ],
          "20": [
            1,
            {
              "@": 109
            }
          ],
          "1": [
            1,
            {
              "@": 109
            }
          ],
          "21": [
            1,
            {
              "@": 109
            }
          ],
          "22": [
            1,
            {
              "@": 109
            }
          ]
        },
        "152": {
          "10": [
            1,
            {
              "@": 106
            }
          ],
          "11": [
            1,
            {
              "@": 106
            }
          ],
          "12": [
            1,
            {
              "@": 106
            }
          ],
          "13": [
            1,
            {
              "@": 106
            }
          ],
          "14": [
            1,
            {
              "@": 106
            }
          ],
          "15": [
            1,
            {
              "@": 106
            }
          ],
          "16": [
            1,
            {
              "@": 106
            }
          ],
          "17": [
            1,
            {
              "@": 106
            }
          ],
          "18": [
            1,
            {
              "@": 106
            }
          ],
          "19": [
            1,
            {
              "@": 106
            }
          ],
          "20": [
            1,
            {
              "@": 106
            }
          ],
          "1": [
            1,
            {
              "@": 106
            }
          ],
          "21": [
            1,
            {
              "@": 106
            }
          ],
          "22": [
            1,
            {
              "@": 106
            }
          ]
        },
        "153": {
          "93": [
            0,
            193
          ]
        },
        "154": {
          "83": [
            1,
            {
              "@": 188
            }
          ]
        },
        "155": {
          "50": [
            0,
            209
          ],
          "10": [
            1,
            {
              "@": 172
            }
          ],
          "11": [
            1,
            {
              "@": 172
            }
          ],
          "13": [
            1,
            {
              "@": 172
            }
          ],
          "15": [
            1,
            {
              "@": 172
            }
          ],
          "18": [
            1,
            {
              "@": 172
            }
          ],
          "19": [
            1,
            {
              "@": 172
            }
          ],
          "20": [
            1,
            {
              "@": 172
            }
          ],
          "1": [
            1,
            {
              "@": 172
            }
          ],
          "22": [
            1,
            {
              "@": 172
            }
          ],
          "12": [
            1,
            {
              "@": 172
            }
          ],
          "14": [
            1,
            {
              "@": 172
            }
          ],
          "16": [
            1,
            {
              "@": 172
            }
          ],
          "17": [
            1,
            {
              "@": 172
            }
          ],
          "49": [
            1,
            {
              "@": 172
            }
          ],
          "21": [
            1,
            {
              "@": 172
            }
          ]
        },
        "156": {
          "82": [
            0,
            94
          ]
        },
        "157": {
          "104": [
            0,
            15
          ]
        },
        "158": {
          "105": [
            0,
            52
          ]
        },
        "159": {
          "10": [
            1,
            {
              "@": 204
            }
          ],
          "11": [
            1,
            {
              "@": 204
            }
          ],
          "12": [
            1,
            {
              "@": 204
            }
          ],
          "13": [
            1,
            {
              "@": 204
            }
          ],
          "15": [
            1,
            {
              "@": 204
            }
          ],
          "14": [
            1,
            {
              "@": 204
            }
          ],
          "16": [
            1,
            {
              "@": 204
            }
          ],
          "17": [
            1,
            {
              "@": 204
            }
          ],
          "18": [
            1,
            {
              "@": 204
            }
          ],
          "19": [
            1,
            {
              "@": 204
            }
          ],
          "20": [
            1,
            {
              "@": 204
            }
          ],
          "1": [
            1,
            {
              "@": 204
            }
          ],
          "50": [
            1,
            {
              "@": 204
            }
          ],
          "21": [
            1,
            {
              "@": 204
            }
          ],
          "22": [
            1,
            {
              "@": 204
            }
          ]
        },
        "160": {
          "9": [
            0,
            122
          ],
          "3": [
            0,
            161
          ],
          "10": [
            1,
            {
              "@": 128
            }
          ],
          "11": [
            1,
            {
              "@": 128
            }
          ],
          "12": [
            1,
            {
              "@": 128
            }
          ],
          "13": [
            1,
            {
              "@": 128
            }
          ],
          "14": [
            1,
            {
              "@": 128
            }
          ],
          "15": [
            1,
            {
              "@": 128
            }
          ],
          "16": [
            1,
            {
              "@": 128
            }
          ],
          "17": [
            1,
            {
              "@": 128
            }
          ],
          "18": [
            1,
            {
              "@": 128
            }
          ],
          "19": [
            1,
            {
              "@": 128
            }
          ],
          "20": [
            1,
            {
              "@": 128
            }
          ],
          "1": [
            1,
            {
              "@": 128
            }
          ],
          "21": [
            1,
            {
              "@": 128
            }
          ],
          "22": [
            1,
            {
              "@": 128
            }
          ]
        },
        "161": {
          "10": [
            1,
            {
              "@": 127
            }
          ],
          "11": [
            1,
            {
              "@": 127
            }
          ],
          "12": [
            1,
            {
              "@": 127
            }
          ],
          "13": [
            1,
            {
              "@": 127
            }
          ],
          "14": [
            1,
            {
              "@": 127
            }
          ],
          "15": [
            1,
            {
              "@": 127
            }
          ],
          "16": [
            1,
            {
              "@": 127
            }
          ],
          "17": [
            1,
            {
              "@": 127
            }
          ],
          "18": [
            1,
            {
              "@": 127
            }
          ],
          "19": [
            1,
            {
              "@": 127
            }
          ],
          "20": [
            1,
            {
              "@": 127
            }
          ],
          "1": [
            1,
            {
              "@": 127
            }
          ],
          "21": [
            1,
            {
              "@": 127
            }
          ],
          "22": [
            1,
            {
              "@": 127
            }
          ]
        },
        "162": {
          "10": [
            1,
            {
              "@": 135
            }
          ],
          "11": [
            1,
            {
              "@": 135
            }
          ],
          "12": [
            1,
            {
              "@": 135
            }
          ],
          "13": [
            1,
            {
              "@": 135
            }
          ],
          "14": [
            1,
            {
              "@": 135
            }
          ],
          "15": [
            1,
            {
              "@": 135
            }
          ],
          "16": [
            1,
            {
              "@": 135
            }
          ],
          "17": [
            1,
            {
              "@": 135
            }
          ],
          "18": [
            1,
            {
              "@": 135
            }
          ],
          "19": [
            1,
            {
              "@": 135
            }
          ],
          "20": [
            1,
            {
              "@": 135
            }
          ],
          "1": [
            1,
            {
              "@": 135
            }
          ],
          "21": [
            1,
            {
              "@": 135
            }
          ],
          "22": [
            1,
            {
              "@": 135
            }
          ]
        },
        "163": {
          "10": [
            1,
            {
              "@": 170
            }
          ],
          "11": [
            1,
            {
              "@": 170
            }
          ],
          "12": [
            1,
            {
              "@": 170
            }
          ],
          "21": [
            1,
            {
              "@": 170
            }
          ],
          "13": [
            1,
            {
              "@": 170
            }
          ],
          "15": [
            1,
            {
              "@": 170
            }
          ],
          "14": [
            1,
            {
              "@": 170
            }
          ],
          "16": [
            1,
            {
              "@": 170
            }
          ],
          "17": [
            1,
            {
              "@": 170
            }
          ],
          "18": [
            1,
            {
              "@": 170
            }
          ],
          "19": [
            1,
            {
              "@": 170
            }
          ],
          "20": [
            1,
            {
              "@": 170
            }
          ],
          "1": [
            1,
            {
              "@": 170
            }
          ],
          "49": [
            1,
            {
              "@": 170
            }
          ],
          "22": [
            1,
            {
              "@": 170
            }
          ]
        },
        "164": {
          "8": [
            0,
            7
          ],
          "106": [
            0,
            18
          ]
        },
        "165": {
          "9": [
            0,
            122
          ],
          "3": [
            0,
            61
          ],
          "10": [
            1,
            {
              "@": 132
            }
          ],
          "11": [
            1,
            {
              "@": 132
            }
          ],
          "12": [
            1,
            {
              "@": 132
            }
          ],
          "13": [
            1,
            {
              "@": 132
            }
          ],
          "14": [
            1,
            {
              "@": 132
            }
          ],
          "15": [
            1,
            {
              "@": 132
            }
          ],
          "16": [
            1,
            {
              "@": 132
            }
          ],
          "17": [
            1,
            {
              "@": 132
            }
          ],
          "18": [
            1,
            {
              "@": 132
            }
          ],
          "19": [
            1,
            {
              "@": 132
            }
          ],
          "20": [
            1,
            {
              "@": 132
            }
          ],
          "1": [
            1,
            {
              "@": 132
            }
          ],
          "21": [
            1,
            {
              "@": 132
            }
          ],
          "22": [
            1,
            {
              "@": 132
            }
          ]
        },
        "166": {
          "10": [
            1,
            {
              "@": 192
            }
          ],
          "11": [
            1,
            {
              "@": 192
            }
          ],
          "12": [
            1,
            {
              "@": 192
            }
          ],
          "13": [
            1,
            {
              "@": 192
            }
          ],
          "14": [
            1,
            {
              "@": 192
            }
          ],
          "15": [
            1,
            {
              "@": 192
            }
          ],
          "16": [
            1,
            {
              "@": 192
            }
          ],
          "17": [
            1,
            {
              "@": 192
            }
          ],
          "18": [
            1,
            {
              "@": 192
            }
          ],
          "19": [
            1,
            {
              "@": 192
            }
          ],
          "20": [
            1,
            {
              "@": 192
            }
          ],
          "1": [
            1,
            {
              "@": 192
            }
          ],
          "21": [
            1,
            {
              "@": 192
            }
          ],
          "22": [
            1,
            {
              "@": 192
            }
          ]
        },
        "167": {
          "10": [
            1,
            {
              "@": 184
            }
          ],
          "11": [
            1,
            {
              "@": 184
            }
          ],
          "13": [
            1,
            {
              "@": 184
            }
          ],
          "15": [
            1,
            {
              "@": 184
            }
          ],
          "18": [
            1,
            {
              "@": 184
            }
          ],
          "19": [
            1,
            {
              "@": 184
            }
          ],
          "20": [
            1,
            {
              "@": 184
            }
          ],
          "1": [
            1,
            {
              "@": 184
            }
          ],
          "22": [
            1,
            {
              "@": 184
            }
          ],
          "12": [
            1,
            {
              "@": 184
            }
          ],
          "14": [
            1,
            {
              "@": 184
            }
          ],
          "16": [
            1,
            {
              "@": 184
            }
          ],
          "17": [
            1,
            {
              "@": 184
            }
          ],
          "50": [
            1,
            {
              "@": 184
            }
          ],
          "21": [
            1,
            {
              "@": 184
            }
          ]
        },
        "168": {
          "10": [
            1,
            {
              "@": 81
            }
          ],
          "11": [
            1,
            {
              "@": 81
            }
          ],
          "12": [
            1,
            {
              "@": 81
            }
          ],
          "13": [
            1,
            {
              "@": 81
            }
          ],
          "14": [
            1,
            {
              "@": 81
            }
          ],
          "15": [
            1,
            {
              "@": 81
            }
          ],
          "16": [
            1,
            {
              "@": 81
            }
          ],
          "17": [
            1,
            {
              "@": 81
            }
          ],
          "18": [
            1,
            {
              "@": 81
            }
          ],
          "19": [
            1,
            {
              "@": 81
            }
          ],
          "20": [
            1,
            {
              "@": 81
            }
          ],
          "1": [
            1,
            {
              "@": 81
            }
          ],
          "21": [
            1,
            {
              "@": 81
            }
          ],
          "22": [
            1,
            {
              "@": 81
            }
          ]
        },
        "169": {
          "83": [
            1,
            {
              "@": 190
            }
          ]
        },
        "170": {
          "10": [
            1,
            {
              "@": 143
            }
          ],
          "11": [
            1,
            {
              "@": 143
            }
          ],
          "12": [
            1,
            {
              "@": 143
            }
          ],
          "13": [
            1,
            {
              "@": 143
            }
          ],
          "14": [
            1,
            {
              "@": 143
            }
          ],
          "15": [
            1,
            {
              "@": 143
            }
          ],
          "16": [
            1,
            {
              "@": 143
            }
          ],
          "17": [
            1,
            {
              "@": 143
            }
          ],
          "18": [
            1,
            {
              "@": 143
            }
          ],
          "19": [
            1,
            {
              "@": 143
            }
          ],
          "20": [
            1,
            {
              "@": 143
            }
          ],
          "1": [
            1,
            {
              "@": 143
            }
          ],
          "21": [
            1,
            {
              "@": 143
            }
          ],
          "22": [
            1,
            {
              "@": 143
            }
          ]
        },
        "171": {
          "10": [
            1,
            {
              "@": 112
            }
          ],
          "11": [
            1,
            {
              "@": 112
            }
          ],
          "12": [
            1,
            {
              "@": 112
            }
          ],
          "13": [
            1,
            {
              "@": 112
            }
          ],
          "14": [
            1,
            {
              "@": 112
            }
          ],
          "15": [
            1,
            {
              "@": 112
            }
          ],
          "16": [
            1,
            {
              "@": 112
            }
          ],
          "17": [
            1,
            {
              "@": 112
            }
          ],
          "18": [
            1,
            {
              "@": 112
            }
          ],
          "19": [
            1,
            {
              "@": 112
            }
          ],
          "20": [
            1,
            {
              "@": 112
            }
          ],
          "1": [
            1,
            {
              "@": 112
            }
          ],
          "21": [
            1,
            {
              "@": 112
            }
          ],
          "22": [
            1,
            {
              "@": 112
            }
          ]
        },
        "172": {
          "10": [
            1,
            {
              "@": 139
            }
          ],
          "11": [
            1,
            {
              "@": 139
            }
          ],
          "12": [
            1,
            {
              "@": 139
            }
          ],
          "13": [
            1,
            {
              "@": 139
            }
          ],
          "14": [
            1,
            {
              "@": 139
            }
          ],
          "15": [
            1,
            {
              "@": 139
            }
          ],
          "16": [
            1,
            {
              "@": 139
            }
          ],
          "17": [
            1,
            {
              "@": 139
            }
          ],
          "18": [
            1,
            {
              "@": 139
            }
          ],
          "19": [
            1,
            {
              "@": 139
            }
          ],
          "20": [
            1,
            {
              "@": 139
            }
          ],
          "1": [
            1,
            {
              "@": 139
            }
          ],
          "21": [
            1,
            {
              "@": 139
            }
          ],
          "22": [
            1,
            {
              "@": 139
            }
          ]
        },
        "173": {
          "50": [
            0,
            41
          ]
        },
        "174": {
          "10": [
            1,
            {
              "@": 137
            }
          ],
          "11": [
            1,
            {
              "@": 137
            }
          ],
          "12": [
            1,
            {
              "@": 137
            }
          ],
          "13": [
            1,
            {
              "@": 137
            }
          ],
          "14": [
            1,
            {
              "@": 137
            }
          ],
          "15": [
            1,
            {
              "@": 137
            }
          ],
          "16": [
            1,
            {
              "@": 137
            }
          ],
          "17": [
            1,
            {
              "@": 137
            }
          ],
          "18": [
            1,
            {
              "@": 137
            }
          ],
          "19": [
            1,
            {
              "@": 137
            }
          ],
          "20": [
            1,
            {
              "@": 137
            }
          ],
          "1": [
            1,
            {
              "@": 137
            }
          ],
          "21": [
            1,
            {
              "@": 137
            }
          ],
          "22": [
            1,
            {
              "@": 137
            }
          ]
        },
        "175": {
          "107": [
            0,
            22
          ]
        },
        "176": {
          "10": [
            1,
            {
              "@": 129
            }
          ],
          "11": [
            1,
            {
              "@": 129
            }
          ],
          "12": [
            1,
            {
              "@": 129
            }
          ],
          "13": [
            1,
            {
              "@": 129
            }
          ],
          "14": [
            1,
            {
              "@": 129
            }
          ],
          "15": [
            1,
            {
              "@": 129
            }
          ],
          "16": [
            1,
            {
              "@": 129
            }
          ],
          "17": [
            1,
            {
              "@": 129
            }
          ],
          "18": [
            1,
            {
              "@": 129
            }
          ],
          "19": [
            1,
            {
              "@": 129
            }
          ],
          "20": [
            1,
            {
              "@": 129
            }
          ],
          "1": [
            1,
            {
              "@": 129
            }
          ],
          "21": [
            1,
            {
              "@": 129
            }
          ],
          "22": [
            1,
            {
              "@": 129
            }
          ]
        },
        "177": {
          "5": [
            0,
            191
          ],
          "9": [
            0,
            122
          ],
          "3": [
            0,
            137
          ],
          "4": [
            0,
            165
          ],
          "10": [
            1,
            {
              "@": 134
            }
          ],
          "11": [
            1,
            {
              "@": 134
            }
          ],
          "12": [
            1,
            {
              "@": 134
            }
          ],
          "13": [
            1,
            {
              "@": 134
            }
          ],
          "14": [
            1,
            {
              "@": 134
            }
          ],
          "15": [
            1,
            {
              "@": 134
            }
          ],
          "16": [
            1,
            {
              "@": 134
            }
          ],
          "17": [
            1,
            {
              "@": 134
            }
          ],
          "18": [
            1,
            {
              "@": 134
            }
          ],
          "19": [
            1,
            {
              "@": 134
            }
          ],
          "20": [
            1,
            {
              "@": 134
            }
          ],
          "1": [
            1,
            {
              "@": 134
            }
          ],
          "21": [
            1,
            {
              "@": 134
            }
          ],
          "22": [
            1,
            {
              "@": 134
            }
          ]
        },
        "178": {
          "10": [
            1,
            {
              "@": 175
            }
          ],
          "11": [
            1,
            {
              "@": 175
            }
          ],
          "13": [
            1,
            {
              "@": 175
            }
          ],
          "15": [
            1,
            {
              "@": 175
            }
          ],
          "18": [
            1,
            {
              "@": 175
            }
          ],
          "19": [
            1,
            {
              "@": 175
            }
          ],
          "20": [
            1,
            {
              "@": 175
            }
          ],
          "1": [
            1,
            {
              "@": 175
            }
          ],
          "22": [
            1,
            {
              "@": 175
            }
          ],
          "12": [
            1,
            {
              "@": 175
            }
          ],
          "14": [
            1,
            {
              "@": 175
            }
          ],
          "16": [
            1,
            {
              "@": 175
            }
          ],
          "17": [
            1,
            {
              "@": 175
            }
          ],
          "21": [
            1,
            {
              "@": 175
            }
          ]
        },
        "179": {},
        "180": {
          "83": [
            1,
            {
              "@": 185
            }
          ]
        },
        "181": {
          "65": [
            1,
            {
              "@": 174
            }
          ]
        },
        "182": {
          "108": [
            0,
            69
          ]
        },
        "183": {
          "10": [
            1,
            {
              "@": 89
            }
          ],
          "11": [
            1,
            {
              "@": 89
            }
          ],
          "12": [
            1,
            {
              "@": 89
            }
          ],
          "13": [
            1,
            {
              "@": 89
            }
          ],
          "14": [
            1,
            {
              "@": 89
            }
          ],
          "15": [
            1,
            {
              "@": 89
            }
          ],
          "16": [
            1,
            {
              "@": 89
            }
          ],
          "17": [
            1,
            {
              "@": 89
            }
          ],
          "18": [
            1,
            {
              "@": 89
            }
          ],
          "19": [
            1,
            {
              "@": 89
            }
          ],
          "20": [
            1,
            {
              "@": 89
            }
          ],
          "1": [
            1,
            {
              "@": 89
            }
          ],
          "21": [
            1,
            {
              "@": 89
            }
          ],
          "22": [
            1,
            {
              "@": 89
            }
          ]
        },
        "184": {
          "26": [
            0,
            0
          ],
          "18": [
            0,
            63
          ],
          "1": [
            0,
            89
          ],
          "22": [
            0,
            12
          ],
          "14": [
            0,
            48
          ],
          "28": [
            0,
            14
          ],
          "31": [
            0,
            3
          ],
          "33": [
            0,
            34
          ],
          "17": [
            0,
            27
          ],
          "35": [
            0,
            6
          ],
          "16": [
            0,
            50
          ],
          "12": [
            0,
            73
          ],
          "15": [
            0,
            77
          ],
          "39": [
            0,
            23
          ],
          "19": [
            0,
            60
          ],
          "32": [
            0,
            108
          ],
          "40": [
            0,
            220
          ],
          "42": [
            0,
            168
          ],
          "43": [
            0,
            219
          ],
          "44": [
            0,
            208
          ],
          "46": [
            0,
            196
          ]
        },
        "185": {
          "90": [
            0,
            101
          ]
        },
        "186": {
          "10": [
            1,
            {
              "@": 201
            }
          ],
          "11": [
            1,
            {
              "@": 201
            }
          ],
          "13": [
            1,
            {
              "@": 201
            }
          ],
          "15": [
            1,
            {
              "@": 201
            }
          ],
          "18": [
            1,
            {
              "@": 201
            }
          ],
          "19": [
            1,
            {
              "@": 201
            }
          ],
          "20": [
            1,
            {
              "@": 201
            }
          ],
          "1": [
            1,
            {
              "@": 201
            }
          ],
          "22": [
            1,
            {
              "@": 201
            }
          ],
          "12": [
            1,
            {
              "@": 201
            }
          ],
          "14": [
            1,
            {
              "@": 201
            }
          ],
          "16": [
            1,
            {
              "@": 201
            }
          ],
          "17": [
            1,
            {
              "@": 201
            }
          ],
          "52": [
            1,
            {
              "@": 201
            }
          ],
          "50": [
            1,
            {
              "@": 201
            }
          ],
          "21": [
            1,
            {
              "@": 201
            }
          ]
        },
        "187": {
          "10": [
            1,
            {
              "@": 91
            }
          ],
          "11": [
            1,
            {
              "@": 91
            }
          ],
          "12": [
            1,
            {
              "@": 91
            }
          ],
          "13": [
            1,
            {
              "@": 91
            }
          ],
          "14": [
            1,
            {
              "@": 91
            }
          ],
          "15": [
            1,
            {
              "@": 91
            }
          ],
          "16": [
            1,
            {
              "@": 91
            }
          ],
          "17": [
            1,
            {
              "@": 91
            }
          ],
          "18": [
            1,
            {
              "@": 91
            }
          ],
          "19": [
            1,
            {
              "@": 91
            }
          ],
          "20": [
            1,
            {
              "@": 91
            }
          ],
          "1": [
            1,
            {
              "@": 91
            }
          ],
          "21": [
            1,
            {
              "@": 91
            }
          ],
          "22": [
            1,
            {
              "@": 91
            }
          ]
        },
        "188": {
          "101": [
            0,
            92
          ],
          "102": [
            0,
            83
          ],
          "10": [
            1,
            {
              "@": 105
            }
          ],
          "11": [
            1,
            {
              "@": 105
            }
          ],
          "12": [
            1,
            {
              "@": 105
            }
          ],
          "13": [
            1,
            {
              "@": 105
            }
          ],
          "14": [
            1,
            {
              "@": 105
            }
          ],
          "15": [
            1,
            {
              "@": 105
            }
          ],
          "16": [
            1,
            {
              "@": 105
            }
          ],
          "17": [
            1,
            {
              "@": 105
            }
          ],
          "18": [
            1,
            {
              "@": 105
            }
          ],
          "19": [
            1,
            {
              "@": 105
            }
          ],
          "20": [
            1,
            {
              "@": 105
            }
          ],
          "1": [
            1,
            {
              "@": 105
            }
          ],
          "21": [
            1,
            {
              "@": 105
            }
          ],
          "22": [
            1,
            {
              "@": 105
            }
          ]
        },
        "189": {
          "62": [
            0,
            72
          ],
          "63": [
            0,
            96
          ],
          "10": [
            1,
            {
              "@": 92
            }
          ],
          "11": [
            1,
            {
              "@": 92
            }
          ],
          "12": [
            1,
            {
              "@": 92
            }
          ],
          "13": [
            1,
            {
              "@": 92
            }
          ],
          "14": [
            1,
            {
              "@": 92
            }
          ],
          "15": [
            1,
            {
              "@": 92
            }
          ],
          "16": [
            1,
            {
              "@": 92
            }
          ],
          "17": [
            1,
            {
              "@": 92
            }
          ],
          "18": [
            1,
            {
              "@": 92
            }
          ],
          "19": [
            1,
            {
              "@": 92
            }
          ],
          "20": [
            1,
            {
              "@": 92
            }
          ],
          "1": [
            1,
            {
              "@": 92
            }
          ],
          "21": [
            1,
            {
              "@": 92
            }
          ],
          "22": [
            1,
            {
              "@": 92
            }
          ]
        },
        "190": {
          "10": [
            1,
            {
              "@": 196
            }
          ],
          "11": [
            1,
            {
              "@": 196
            }
          ],
          "12": [
            1,
            {
              "@": 196
            }
          ],
          "21": [
            1,
            {
              "@": 196
            }
          ],
          "13": [
            1,
            {
              "@": 196
            }
          ],
          "15": [
            1,
            {
              "@": 196
            }
          ],
          "14": [
            1,
            {
              "@": 196
            }
          ],
          "16": [
            1,
            {
              "@": 196
            }
          ],
          "17": [
            1,
            {
              "@": 196
            }
          ],
          "18": [
            1,
            {
              "@": 196
            }
          ],
          "19": [
            1,
            {
              "@": 196
            }
          ],
          "20": [
            1,
            {
              "@": 196
            }
          ],
          "1": [
            1,
            {
              "@": 196
            }
          ],
          "49": [
            1,
            {
              "@": 196
            }
          ],
          "22": [
            1,
            {
              "@": 196
            }
          ]
        },
        "191": {
          "97": [
            0,
            44
          ]
        },
        "192": {
          "10": [
            1,
            {
              "@": 93
            }
          ],
          "11": [
            1,
            {
              "@": 93
            }
          ],
          "12": [
            1,
            {
              "@": 93
            }
          ],
          "13": [
            1,
            {
              "@": 93
            }
          ],
          "14": [
            1,
            {
              "@": 93
            }
          ],
          "15": [
            1,
            {
              "@": 93
            }
          ],
          "16": [
            1,
            {
              "@": 93
            }
          ],
          "17": [
            1,
            {
              "@": 93
            }
          ],
          "18": [
            1,
            {
              "@": 93
            }
          ],
          "19": [
            1,
            {
              "@": 93
            }
          ],
          "20": [
            1,
            {
              "@": 93
            }
          ],
          "1": [
            1,
            {
              "@": 93
            }
          ],
          "21": [
            1,
            {
              "@": 93
            }
          ],
          "22": [
            1,
            {
              "@": 93
            }
          ]
        },
        "193": {
          "10": [
            1,
            {
              "@": 197
            }
          ],
          "11": [
            1,
            {
              "@": 197
            }
          ],
          "13": [
            1,
            {
              "@": 197
            }
          ],
          "15": [
            1,
            {
              "@": 197
            }
          ],
          "18": [
            1,
            {
              "@": 197
            }
          ],
          "19": [
            1,
            {
              "@": 197
            }
          ],
          "20": [
            1,
            {
              "@": 197
            }
          ],
          "1": [
            1,
            {
              "@": 197
            }
          ],
          "22": [
            1,
            {
              "@": 197
            }
          ],
          "21": [
            1,
            {
              "@": 197
            }
          ],
          "12": [
            1,
            {
              "@": 197
            }
          ],
          "14": [
            1,
            {
              "@": 197
            }
          ],
          "16": [
            1,
            {
              "@": 197
            }
          ],
          "17": [
            1,
            {
              "@": 197
            }
          ],
          "50": [
            1,
            {
              "@": 197
            }
          ],
          "49": [
            1,
            {
              "@": 197
            }
          ]
        },
        "194": {
          "19": [
            0,
            102
          ]
        },
        "195": {
          "10": [
            1,
            {
              "@": 169
            }
          ],
          "11": [
            1,
            {
              "@": 169
            }
          ],
          "12": [
            1,
            {
              "@": 169
            }
          ],
          "21": [
            1,
            {
              "@": 169
            }
          ],
          "13": [
            1,
            {
              "@": 169
            }
          ],
          "15": [
            1,
            {
              "@": 169
            }
          ],
          "14": [
            1,
            {
              "@": 169
            }
          ],
          "16": [
            1,
            {
              "@": 169
            }
          ],
          "17": [
            1,
            {
              "@": 169
            }
          ],
          "18": [
            1,
            {
              "@": 169
            }
          ],
          "19": [
            1,
            {
              "@": 169
            }
          ],
          "20": [
            1,
            {
              "@": 169
            }
          ],
          "1": [
            1,
            {
              "@": 169
            }
          ],
          "49": [
            1,
            {
              "@": 169
            }
          ],
          "22": [
            1,
            {
              "@": 169
            }
          ]
        },
        "196": {
          "10": [
            1,
            {
              "@": 87
            }
          ],
          "11": [
            1,
            {
              "@": 87
            }
          ],
          "12": [
            1,
            {
              "@": 87
            }
          ],
          "13": [
            1,
            {
              "@": 87
            }
          ],
          "14": [
            1,
            {
              "@": 87
            }
          ],
          "15": [
            1,
            {
              "@": 87
            }
          ],
          "16": [
            1,
            {
              "@": 87
            }
          ],
          "17": [
            1,
            {
              "@": 87
            }
          ],
          "18": [
            1,
            {
              "@": 87
            }
          ],
          "19": [
            1,
            {
              "@": 87
            }
          ],
          "20": [
            1,
            {
              "@": 87
            }
          ],
          "1": [
            1,
            {
              "@": 87
            }
          ],
          "21": [
            1,
            {
              "@": 87
            }
          ],
          "22": [
            1,
            {
              "@": 87
            }
          ]
        },
        "197": {
          "10": [
            1,
            {
              "@": 90
            }
          ],
          "11": [
            1,
            {
              "@": 90
            }
          ],
          "12": [
            1,
            {
              "@": 90
            }
          ],
          "13": [
            1,
            {
              "@": 90
            }
          ],
          "14": [
            1,
            {
              "@": 90
            }
          ],
          "15": [
            1,
            {
              "@": 90
            }
          ],
          "16": [
            1,
            {
              "@": 90
            }
          ],
          "17": [
            1,
            {
              "@": 90
            }
          ],
          "18": [
            1,
            {
              "@": 90
            }
          ],
          "19": [
            1,
            {
              "@": 90
            }
          ],
          "20": [
            1,
            {
              "@": 90
            }
          ],
          "1": [
            1,
            {
              "@": 90
            }
          ],
          "21": [
            1,
            {
              "@": 90
            }
          ],
          "22": [
            1,
            {
              "@": 90
            }
          ]
        },
        "198": {
          "52": [
            0,
            66
          ],
          "10": [
            1,
            {
              "@": 107
            }
          ],
          "11": [
            1,
            {
              "@": 107
            }
          ],
          "12": [
            1,
            {
              "@": 107
            }
          ],
          "13": [
            1,
            {
              "@": 107
            }
          ],
          "14": [
            1,
            {
              "@": 107
            }
          ],
          "15": [
            1,
            {
              "@": 107
            }
          ],
          "16": [
            1,
            {
              "@": 107
            }
          ],
          "17": [
            1,
            {
              "@": 107
            }
          ],
          "18": [
            1,
            {
              "@": 107
            }
          ],
          "19": [
            1,
            {
              "@": 107
            }
          ],
          "20": [
            1,
            {
              "@": 107
            }
          ],
          "1": [
            1,
            {
              "@": 107
            }
          ],
          "21": [
            1,
            {
              "@": 107
            }
          ],
          "22": [
            1,
            {
              "@": 107
            }
          ]
        },
        "199": {
          "64": [
            0,
            109
          ]
        },
        "200": {
          "96": [
            0,
            56
          ],
          "109": [
            0,
            120
          ],
          "110": [
            0,
            2
          ],
          "111": [
            0,
            8
          ]
        },
        "201": {
          "10": [
            1,
            {
              "@": 198
            }
          ],
          "11": [
            1,
            {
              "@": 198
            }
          ],
          "13": [
            1,
            {
              "@": 198
            }
          ],
          "15": [
            1,
            {
              "@": 198
            }
          ],
          "18": [
            1,
            {
              "@": 198
            }
          ],
          "19": [
            1,
            {
              "@": 198
            }
          ],
          "20": [
            1,
            {
              "@": 198
            }
          ],
          "1": [
            1,
            {
              "@": 198
            }
          ],
          "22": [
            1,
            {
              "@": 198
            }
          ],
          "21": [
            1,
            {
              "@": 198
            }
          ],
          "12": [
            1,
            {
              "@": 198
            }
          ],
          "14": [
            1,
            {
              "@": 198
            }
          ],
          "16": [
            1,
            {
              "@": 198
            }
          ],
          "17": [
            1,
            {
              "@": 198
            }
          ],
          "50": [
            1,
            {
              "@": 198
            }
          ],
          "49": [
            1,
            {
              "@": 198
            }
          ]
        },
        "202": {
          "10": [
            1,
            {
              "@": 171
            }
          ],
          "11": [
            1,
            {
              "@": 171
            }
          ],
          "12": [
            1,
            {
              "@": 171
            }
          ],
          "21": [
            1,
            {
              "@": 171
            }
          ],
          "13": [
            1,
            {
              "@": 171
            }
          ],
          "15": [
            1,
            {
              "@": 171
            }
          ],
          "14": [
            1,
            {
              "@": 171
            }
          ],
          "16": [
            1,
            {
              "@": 171
            }
          ],
          "17": [
            1,
            {
              "@": 171
            }
          ],
          "18": [
            1,
            {
              "@": 171
            }
          ],
          "19": [
            1,
            {
              "@": 171
            }
          ],
          "20": [
            1,
            {
              "@": 171
            }
          ],
          "1": [
            1,
            {
              "@": 171
            }
          ],
          "49": [
            1,
            {
              "@": 171
            }
          ],
          "22": [
            1,
            {
              "@": 171
            }
          ]
        },
        "203": {
          "60": [
            0,
            81
          ],
          "10": [
            1,
            {
              "@": 88
            }
          ],
          "11": [
            1,
            {
              "@": 88
            }
          ],
          "12": [
            1,
            {
              "@": 88
            }
          ],
          "13": [
            1,
            {
              "@": 88
            }
          ],
          "14": [
            1,
            {
              "@": 88
            }
          ],
          "15": [
            1,
            {
              "@": 88
            }
          ],
          "16": [
            1,
            {
              "@": 88
            }
          ],
          "17": [
            1,
            {
              "@": 88
            }
          ],
          "18": [
            1,
            {
              "@": 88
            }
          ],
          "19": [
            1,
            {
              "@": 88
            }
          ],
          "20": [
            1,
            {
              "@": 88
            }
          ],
          "1": [
            1,
            {
              "@": 88
            }
          ],
          "21": [
            1,
            {
              "@": 88
            }
          ],
          "22": [
            1,
            {
              "@": 88
            }
          ]
        },
        "204": {
          "112": [
            0,
            207
          ],
          "54": [
            0,
            167
          ]
        },
        "205": {
          "10": [
            1,
            {
              "@": 114
            }
          ],
          "11": [
            1,
            {
              "@": 114
            }
          ],
          "12": [
            1,
            {
              "@": 114
            }
          ],
          "13": [
            1,
            {
              "@": 114
            }
          ],
          "9": [
            1,
            {
              "@": 114
            }
          ],
          "15": [
            1,
            {
              "@": 114
            }
          ],
          "14": [
            1,
            {
              "@": 114
            }
          ],
          "16": [
            1,
            {
              "@": 114
            }
          ],
          "17": [
            1,
            {
              "@": 114
            }
          ],
          "8": [
            1,
            {
              "@": 114
            }
          ],
          "18": [
            1,
            {
              "@": 114
            }
          ],
          "19": [
            1,
            {
              "@": 114
            }
          ],
          "20": [
            1,
            {
              "@": 114
            }
          ],
          "1": [
            1,
            {
              "@": 114
            }
          ],
          "5": [
            1,
            {
              "@": 114
            }
          ],
          "21": [
            1,
            {
              "@": 114
            }
          ],
          "22": [
            1,
            {
              "@": 114
            }
          ],
          "7": [
            1,
            {
              "@": 114
            }
          ]
        },
        "206": {
          "113": [
            0,
            155
          ],
          "50": [
            0,
            153
          ],
          "10": [
            1,
            {
              "@": 173
            }
          ],
          "11": [
            1,
            {
              "@": 173
            }
          ],
          "13": [
            1,
            {
              "@": 173
            }
          ],
          "15": [
            1,
            {
              "@": 173
            }
          ],
          "18": [
            1,
            {
              "@": 173
            }
          ],
          "19": [
            1,
            {
              "@": 173
            }
          ],
          "20": [
            1,
            {
              "@": 173
            }
          ],
          "1": [
            1,
            {
              "@": 173
            }
          ],
          "22": [
            1,
            {
              "@": 173
            }
          ],
          "12": [
            1,
            {
              "@": 173
            }
          ],
          "14": [
            1,
            {
              "@": 173
            }
          ],
          "16": [
            1,
            {
              "@": 173
            }
          ],
          "17": [
            1,
            {
              "@": 173
            }
          ],
          "49": [
            1,
            {
              "@": 173
            }
          ],
          "21": [
            1,
            {
              "@": 173
            }
          ]
        },
        "207": {
          "10": [
            1,
            {
              "@": 182
            }
          ],
          "11": [
            1,
            {
              "@": 182
            }
          ],
          "12": [
            1,
            {
              "@": 182
            }
          ],
          "13": [
            1,
            {
              "@": 182
            }
          ],
          "15": [
            1,
            {
              "@": 182
            }
          ],
          "14": [
            1,
            {
              "@": 182
            }
          ],
          "16": [
            1,
            {
              "@": 182
            }
          ],
          "17": [
            1,
            {
              "@": 182
            }
          ],
          "18": [
            1,
            {
              "@": 182
            }
          ],
          "19": [
            1,
            {
              "@": 182
            }
          ],
          "20": [
            1,
            {
              "@": 182
            }
          ],
          "1": [
            1,
            {
              "@": 182
            }
          ],
          "50": [
            1,
            {
              "@": 182
            }
          ],
          "21": [
            1,
            {
              "@": 182
            }
          ],
          "22": [
            1,
            {
              "@": 182
            }
          ]
        },
        "208": {
          "10": [
            1,
            {
              "@": 78
            }
          ],
          "11": [
            1,
            {
              "@": 78
            }
          ],
          "12": [
            1,
            {
              "@": 78
            }
          ],
          "13": [
            1,
            {
              "@": 78
            }
          ],
          "14": [
            1,
            {
              "@": 78
            }
          ],
          "15": [
            1,
            {
              "@": 78
            }
          ],
          "16": [
            1,
            {
              "@": 78
            }
          ],
          "17": [
            1,
            {
              "@": 78
            }
          ],
          "18": [
            1,
            {
              "@": 78
            }
          ],
          "19": [
            1,
            {
              "@": 78
            }
          ],
          "20": [
            1,
            {
              "@": 78
            }
          ],
          "1": [
            1,
            {
              "@": 78
            }
          ],
          "21": [
            1,
            {
              "@": 78
            }
          ],
          "22": [
            1,
            {
              "@": 78
            }
          ]
        },
        "209": {
          "93": [
            0,
            201
          ]
        },
        "210": {
          "84": [
            0,
            93
          ],
          "83": [
            0,
            78
          ],
          "85": [
            0,
            57
          ],
          "64": [
            0,
            107
          ],
          "87": [
            0,
            119
          ]
        },
        "211": {
          "54": [
            0,
            133
          ],
          "55": [
            0,
            190
          ]
        },
        "212": {
          "100": [
            0,
            142
          ]
        },
        "213": {
          "10": [
            1,
            {
              "@": 145
            }
          ],
          "11": [
            1,
            {
              "@": 145
            }
          ],
          "12": [
            1,
            {
              "@": 145
            }
          ],
          "13": [
            1,
            {
              "@": 145
            }
          ],
          "14": [
            1,
            {
              "@": 145
            }
          ],
          "15": [
            1,
            {
              "@": 145
            }
          ],
          "16": [
            1,
            {
              "@": 145
            }
          ],
          "17": [
            1,
            {
              "@": 145
            }
          ],
          "18": [
            1,
            {
              "@": 145
            }
          ],
          "19": [
            1,
            {
              "@": 145
            }
          ],
          "20": [
            1,
            {
              "@": 145
            }
          ],
          "1": [
            1,
            {
              "@": 145
            }
          ],
          "21": [
            1,
            {
              "@": 145
            }
          ],
          "22": [
            1,
            {
              "@": 145
            }
          ]
        },
        "214": {
          "9": [
            0,
            122
          ],
          "3": [
            0,
            162
          ],
          "10": [
            1,
            {
              "@": 136
            }
          ],
          "11": [
            1,
            {
              "@": 136
            }
          ],
          "12": [
            1,
            {
              "@": 136
            }
          ],
          "13": [
            1,
            {
              "@": 136
            }
          ],
          "14": [
            1,
            {
              "@": 136
            }
          ],
          "15": [
            1,
            {
              "@": 136
            }
          ],
          "16": [
            1,
            {
              "@": 136
            }
          ],
          "17": [
            1,
            {
              "@": 136
            }
          ],
          "18": [
            1,
            {
              "@": 136
            }
          ],
          "19": [
            1,
            {
              "@": 136
            }
          ],
          "20": [
            1,
            {
              "@": 136
            }
          ],
          "1": [
            1,
            {
              "@": 136
            }
          ],
          "21": [
            1,
            {
              "@": 136
            }
          ],
          "22": [
            1,
            {
              "@": 136
            }
          ]
        },
        "215": {
          "84": [
            0,
            93
          ],
          "83": [
            0,
            78
          ],
          "64": [
            0,
            107
          ],
          "87": [
            0,
            39
          ]
        },
        "216": {
          "84": [
            0,
            93
          ],
          "85": [
            0,
            38
          ],
          "114": [
            0,
            10
          ],
          "64": [
            0,
            107
          ],
          "86": [
            0,
            105
          ],
          "83": [
            0,
            78
          ],
          "87": [
            0,
            119
          ]
        },
        "217": {
          "100": [
            0,
            54
          ]
        },
        "218": {
          "115": [
            0,
            204
          ],
          "10": [
            1,
            {
              "@": 183
            }
          ],
          "11": [
            1,
            {
              "@": 183
            }
          ],
          "12": [
            1,
            {
              "@": 183
            }
          ],
          "13": [
            1,
            {
              "@": 183
            }
          ],
          "15": [
            1,
            {
              "@": 183
            }
          ],
          "14": [
            1,
            {
              "@": 183
            }
          ],
          "16": [
            1,
            {
              "@": 183
            }
          ],
          "17": [
            1,
            {
              "@": 183
            }
          ],
          "18": [
            1,
            {
              "@": 183
            }
          ],
          "19": [
            1,
            {
              "@": 183
            }
          ],
          "20": [
            1,
            {
              "@": 183
            }
          ],
          "1": [
            1,
            {
              "@": 183
            }
          ],
          "50": [
            1,
            {
              "@": 183
            }
          ],
          "21": [
            1,
            {
              "@": 183
            }
          ],
          "22": [
            1,
            {
              "@": 183
            }
          ]
        },
        "219": {
          "10": [
            1,
            {
              "@": 80
            }
          ],
          "11": [
            1,
            {
              "@": 80
            }
          ],
          "12": [
            1,
            {
              "@": 80
            }
          ],
          "13": [
            1,
            {
              "@": 80
            }
          ],
          "14": [
            1,
            {
              "@": 80
            }
          ],
          "15": [
            1,
            {
              "@": 80
            }
          ],
          "16": [
            1,
            {
              "@": 80
            }
          ],
          "17": [
            1,
            {
              "@": 80
            }
          ],
          "18": [
            1,
            {
              "@": 80
            }
          ],
          "19": [
            1,
            {
              "@": 80
            }
          ],
          "20": [
            1,
            {
              "@": 80
            }
          ],
          "1": [
            1,
            {
              "@": 80
            }
          ],
          "21": [
            1,
            {
              "@": 80
            }
          ],
          "22": [
            1,
            {
              "@": 80
            }
          ]
        },
        "220": {
          "10": [
            1,
            {
              "@": 82
            }
          ],
          "11": [
            1,
            {
              "@": 82
            }
          ],
          "12": [
            1,
            {
              "@": 82
            }
          ],
          "13": [
            1,
            {
              "@": 82
            }
          ],
          "14": [
            1,
            {
              "@": 82
            }
          ],
          "15": [
            1,
            {
              "@": 82
            }
          ],
          "16": [
            1,
            {
              "@": 82
            }
          ],
          "17": [
            1,
            {
              "@": 82
            }
          ],
          "18": [
            1,
            {
              "@": 82
            }
          ],
          "19": [
            1,
            {
              "@": 82
            }
          ],
          "20": [
            1,
            {
              "@": 82
            }
          ],
          "1": [
            1,
            {
              "@": 82
            }
          ],
          "21": [
            1,
            {
              "@": 82
            }
          ],
          "22": [
            1,
            {
              "@": 82
            }
          ]
        }
      },
      "start_states": {
        "start": 5
      },
      "end_states": {
        "start": 179
      }
    },
    "__type__": "ParsingFrontend"
  },
  "rules": [
    {
      "@": 68
    },
    {
      "@": 69
    },
    {
      "@": 70
    },
    {
      "@": 71
    },
    {
      "@": 72
    },
    {
      "@": 73
    },
    {
      "@": 74
    },
    {
      "@": 75
    },
    {
      "@": 76
    },
    {
      "@": 77
    },
    {
      "@": 78
    },
    {
      "@": 79
    },
    {
      "@": 80
    },
    {
      "@": 81
    },
    {
      "@": 82
    },
    {
      "@": 83
    },
    {
      "@": 84
    },
    {
      "@": 85
    },
    {
      "@": 86
    },
    {
      "@": 87
    },
    {
      "@": 88
    },
    {
      "@": 89
    },
    {
      "@": 90
    },
    {
      "@": 91
    },
    {
      "@": 92
    },
    {
      "@": 93
    },
    {
      "@": 94
    },
    {
      "@": 95
    },
    {
      "@": 96
    },
    {
      "@": 97
    },
    {
      "@": 98
    },
    {
      "@": 99
    },
    {
      "@": 100
    },
    {
      "@": 101
    },
    {
      "@": 102
    },
    {
      "@": 103
    },
    {
      "@": 104
    },
    {
      "@": 105
    },
    {
      "@": 106
    },
    {
      "@": 107
    },
    {
      "@": 108
    },
    {
      "@": 109
    },
    {
      "@": 110
    },
    {
      "@": 111
    },
    {
      "@": 112
    },
    {
      "@": 113
    },
    {
      "@": 114
    },
    {
      "@": 115
    },
    {
      "@": 116
    },
    {
      "@": 117
    },
    {
      "@": 118
    },
    {
      "@": 119
    },
    {
      "@": 120
    },
    {
      "@": 121
    },
    {
      "@": 122
    },
    {
      "@": 123
    },
    {
      "@": 124
    },
    {
      "@": 125
    },
    {
      "@": 126
    },
    {
      "@": 127
    },
    {
      "@": 128
    },
    {
      "@": 129
    },
    {
      "@": 130
    },
    {
      "@": 131
    },
    {
      "@": 132
    },
    {
      "@": 133
    },
    {
      "@": 134
    },
    {
      "@": 135
    },
    {
      "@": 136
    },
    {
      "@": 137
    },
    {
      "@": 138
    },
    {
      "@": 139
    },
    {
      "@": 140
    },
    {
      "@": 141
    },
    {
      "@": 142
    },
    {
      "@": 143
    },
    {
      "@": 144
    },
    {
      "@": 145
    },
    {
      "@": 146
    },
    {
      "@": 147
    },
    {
      "@": 148
    },
    {
      "@": 149
    },
    {
      "@": 150
    },
    {
      "@": 151
    },
    {
      "@": 152
    },
    {
      "@": 153
    },
    {
      "@": 154
    },
    {
      "@": 155
    },
    {
      "@": 156
    },
    {
      "@": 157
    },
    {
      "@": 158
    },
    {
      "@": 159
    },
    {
      "@": 160
    },
    {
      "@": 161
    },
    {
      "@": 162
    },
    {
      "@": 163
    },
    {
      "@": 164
    },
    {
      "@": 165
    },
    {
      "@": 166
    },
    {
      "@": 167
    },
    {
      "@": 168
    },
    {
      "@": 169
    },
    {
      "@": 170
    },
    {
      "@": 171
    },
    {
      "@": 172
    },
    {
      "@": 173
    },
    {
      "@": 174
    },
    {
      "@": 175
    },
    {
      "@": 176
    },
    {
      "@": 177
    },
    {
      "@": 178
    },
    {
      "@": 179
    },
    {
      "@": 180
    },
    {
      "@": 181
    },
    {
      "@": 182
    },
    {
      "@": 183
    },
    {
      "@": 184
    },
    {
      "@": 185
    },
    {
      "@": 186
    },
    {
      "@": 187
    },
    {
      "@": 188
    },
    {
      "@": 189
    },
    {
      "@": 190
    },
    {
      "@": 191
    },
    {
      "@": 192
    },
    {
      "@": 193
    },
    {
      "@": 194
    },
    {
      "@": 195
    },
    {
      "@": 196
    },
    {
      "@": 197
    },
    {
      "@": 198
    },
    {
      "@": 199
    },
    {
      "@": 200
    },
    {
      "@": 201
    },
    {
      "@": 202
    },
    {
      "@": 203
    },
    {
      "@": 204
    }
  ],
  "options": {
    "debug": false,
    "keep_all_tokens": true,
    "tree_class": null,
    "cache": false,
    "postlex": null,
    "parser": "lalr",
    "lexer": "contextual",
    "transformer": null,
    "start": [
      "start"
    ],
    "priority": "normal",
    "ambiguity": "auto",
    "regex": false,
    "propagate_positions": false,
    "lexer_callbacks": {},
    "maybe_placeholders": false,
    "edit_terminals": null,
    "g_regex_flags": 0,
    "use_bytes": false,
    "import_paths": [],
    "source_path": null,
    "_plugins": {}
  },
  "__type__": "Lark"
};

var MEMO={
  "0": {
    "name": "INT",
    "pattern": {
      "value": "(?:[0-9])+",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "1": {
    "name": "NUMBER",
    "pattern": {
      "value": "(?:(?:(?:[0-9])+(?:e|E)(?:(?:\\+|\\-))?(?:[0-9])+|(?:(?:[0-9])+\\.(?:(?:[0-9])+)?|\\.(?:[0-9])+)(?:(?:e|E)(?:(?:\\+|\\-))?(?:[0-9])+)?)|(?:[0-9])+)",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "2": {
    "name": "CNAME",
    "pattern": {
      "value": "(?:(?:[A-Z]|[a-z])|_)(?:(?:(?:[A-Z]|[a-z])|[0-9]|_))*",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "3": {
    "name": "WS",
    "pattern": {
      "value": "(?:[ \t\f\r\n])+",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "4": {
    "name": "OP",
    "pattern": {
      "value": "([<>!=]?=|[<>]|IN|LIKE|MATCHES)",
      "flags": [],
      "_width": [
        1,
        7
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "5": {
    "name": "NULL_OP",
    "pattern": {
      "value": "IS (NOT)?",
      "flags": [
        "i"
      ],
      "_width": [
        3,
        6
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "6": {
    "name": "TRANSFORM",
    "pattern": {
      "value": "timestamped",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "7": {
    "name": "VARIABLE",
    "pattern": {
      "value": "(?:(?:[A-Z]|[a-z])|_)(?:(?:(?:[A-Z]|[a-z])|[0-9]|_))*",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "8": {
    "name": "ENTITY_TYPE",
    "pattern": {
      "value": "(?:[A-Z]|[a-z])(?:(?:(?:[A-Z]|[a-z])|[0-9]|_|\\-))*",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "9": {
    "name": "ANALYTICS",
    "pattern": {
      "value": "(?:(?:(?:[A-Z]|[a-z])|[-_.:\\/]|[0-9]))+",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "10": {
    "name": "STIXPATH",
    "pattern": {
      "value": "(?:(?:(?:[A-Z]|[a-z])|[-_.:']|[0-9]))+",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "11": {
    "name": "STIXPATHS",
    "pattern": {
      "value": "(?:(?:(?:[A-Z]|[a-z])|[-_.:']|[0-9]))+(?:\\s*,\\s*(?:(?:(?:[A-Z]|[a-z])|[-_.:']|[0-9]))+)*",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "12": {
    "name": "PATH",
    "pattern": {
      "value": "(?:(?:(?:[A-Z]|[a-z])|[-_.:\\/]|[0-9]))+",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "13": {
    "name": "DATASRC",
    "pattern": {
      "value": "(?:\\\".*?(?<!\\\\)(\\\\\\\\)*?\\\"|(?:(?:(?:[A-Z]|[a-z])|[-_.:\\/]|[0-9]))+(?:\\,(?:(?:(?:[A-Z]|[a-z])|[-_.:\\/]|[0-9]))+)*)",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "14": {
    "name": "DUMPPATH",
    "pattern": {
      "value": "(?:(?:(?:[A-Z]|[a-z])|[-_.:\\/]|[0-9]))+",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "15": {
    "name": "ASC",
    "pattern": {
      "value": "asc",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "16": {
    "name": "DESC",
    "pattern": {
      "value": "desc",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "17": {
    "name": "REVERSED",
    "pattern": {
      "value": "by",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "18": {
    "name": "BY",
    "pattern": {
      "value": "by",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "19": {
    "name": "COMMENT",
    "pattern": {
      "value": "#.*",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "20": {
    "name": "URI",
    "pattern": {
      "value": "(?:(?:(?:[A-Z]|[a-z])|[-_.:\\/]|[0-9]))+",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "21": {
    "name": "MIN",
    "pattern": {
      "value": "min",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "22": {
    "name": "MAX",
    "pattern": {
      "value": "max",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "23": {
    "name": "SUM",
    "pattern": {
      "value": "sum",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "24": {
    "name": "AVG",
    "pattern": {
      "value": "avg",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "25": {
    "name": "COUNT",
    "pattern": {
      "value": "count",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "26": {
    "name": "NUNIQUE",
    "pattern": {
      "value": "nunique",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "27": {
    "name": "STIXPATTERNBODY",
    "pattern": {
      "value": "(?:\\[.+\\]|\\(.+\\))",
      "flags": [],
      "_width": [
        3,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "28": {
    "name": "ISOTIMESTAMP",
    "pattern": {
      "value": "\\d{4}-[01]\\d-[0-3]\\dT[0-2]\\d:[0-5]\\d:[0-5]\\d(\\.\\d+)?Z",
      "flags": [],
      "_width": [
        20,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "29": {
    "name": "QSTRING",
    "pattern": {
      "value": "(?:(?:[ \t\f\r\n])+)*\\\".*?(?<!\\\\)(\\\\\\\\)*?\\\"(?:(?:[ \t\f\r\n])+)*",
      "flags": [],
      "_width": [
        2,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "30": {
    "name": "VARDATA",
    "pattern": {
      "value": "\\[(?:(?:(?:[ \t\f\r\n])+)*\\{(?:(?:[ \t\f\r\n])+)*\\\".*?(?<!\\\\)(\\\\\\\\)*?\\\"(?:(?:[ \t\f\r\n])+)*\\:(?:(?:[ \t\f\r\n])+)*(?:\\\".*?(?<!\\\\)(\\\\\\\\)*?\\\"|(?:(?:(?:[0-9])+(?:e|E)(?:(?:\\+|\\-))?(?:[0-9])+|(?:(?:[0-9])+\\.(?:(?:[0-9])+)?|\\.(?:[0-9])+)(?:(?:e|E)(?:(?:\\+|\\-))?(?:[0-9])+)?)|(?:[0-9])+))(?:(?:[ \t\f\r\n])+)*(?:\\,(?:(?:[ \t\f\r\n])+)*\\\".*?(?<!\\\\)(\\\\\\\\)*?\\\"(?:(?:[ \t\f\r\n])+)*\\:(?:(?:[ \t\f\r\n])+)*(?:\\\".*?(?<!\\\\)(\\\\\\\\)*?\\\"|(?:(?:(?:[0-9])+(?:e|E)(?:(?:\\+|\\-))?(?:[0-9])+|(?:(?:[0-9])+\\.(?:(?:[0-9])+)?|\\.(?:[0-9])+)(?:(?:e|E)(?:(?:\\+|\\-))?(?:[0-9])+)?)|(?:[0-9])+))(?:(?:[ \t\f\r\n])+)*)*\\}(?:(?:[ \t\f\r\n])+)*(?:\\,(?:(?:[ \t\f\r\n])+)*\\{(?:(?:[ \t\f\r\n])+)*\\\".*?(?<!\\\\)(\\\\\\\\)*?\\\"(?:(?:[ \t\f\r\n])+)*\\:(?:(?:[ \t\f\r\n])+)*(?:\\\".*?(?<!\\\\)(\\\\\\\\)*?\\\"|(?:(?:(?:[0-9])+(?:e|E)(?:(?:\\+|\\-))?(?:[0-9])+|(?:(?:[0-9])+\\.(?:(?:[0-9])+)?|\\.(?:[0-9])+)(?:(?:e|E)(?:(?:\\+|\\-))?(?:[0-9])+)?)|(?:[0-9])+))(?:(?:[ \t\f\r\n])+)*(?:\\,(?:(?:[ \t\f\r\n])+)*\\\".*?(?<!\\\\)(\\\\\\\\)*?\\\"(?:(?:[ \t\f\r\n])+)*\\:(?:(?:[ \t\f\r\n])+)*(?:\\\".*?(?<!\\\\)(\\\\\\\\)*?\\\"|(?:(?:(?:[0-9])+(?:e|E)(?:(?:\\+|\\-))?(?:[0-9])+|(?:(?:[0-9])+\\.(?:(?:[0-9])+)?|\\.(?:[0-9])+)(?:(?:e|E)(?:(?:\\+|\\-))?(?:[0-9])+)?)|(?:[0-9])+))(?:(?:[ \t\f\r\n])+)*)*\\}(?:(?:[ \t\f\r\n])+)*)*|(?:(?:[ \t\f\r\n])+)*\\\".*?(?<!\\\\)(\\\\\\\\)*?\\\"(?:(?:[ \t\f\r\n])+)*(?:\\,(?:(?:[ \t\f\r\n])+)*\\\".*?(?<!\\\\)(\\\\\\\\)*?\\\"(?:(?:[ \t\f\r\n])+)*)*)\\]",
      "flags": [],
      "_width": [
        4,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "31": {
    "name": "SQSTRING",
    "pattern": {
      "value": "'[^']*'",
      "flags": [],
      "_width": [
        2,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "32": {
    "name": "RELATION",
    "pattern": {
      "value": "(?:(?:[A-Z]|[a-z]))+",
      "flags": [],
      "_width": [
        1,
        4294967295
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "33": {
    "name": "EQUAL",
    "pattern": {
      "value": "=",
      "flags": [],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "34": {
    "name": "PLUS",
    "pattern": {
      "value": "+",
      "flags": [],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "35": {
    "name": "DISP",
    "pattern": {
      "value": "disp",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "36": {
    "name": "INFO",
    "pattern": {
      "value": "info",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "37": {
    "name": "FROM",
    "pattern": {
      "value": "from",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "38": {
    "name": "GET",
    "pattern": {
      "value": "get",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "39": {
    "name": "WHERE",
    "pattern": {
      "value": "where",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "40": {
    "name": "FIND",
    "pattern": {
      "value": "find",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "41": {
    "name": "WITH",
    "pattern": {
      "value": "with",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "42": {
    "name": "APPLY",
    "pattern": {
      "value": "apply",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "43": {
    "name": "ON",
    "pattern": {
      "value": "on",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "44": {
    "name": "COMMA",
    "pattern": {
      "value": ",",
      "flags": [],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "45": {
    "name": "JOIN",
    "pattern": {
      "value": "join",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "46": {
    "name": "SORT",
    "pattern": {
      "value": "sort",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "47": {
    "name": "GROUP",
    "pattern": {
      "value": "group",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "48": {
    "name": "AS",
    "pattern": {
      "value": "as",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "49": {
    "name": "LOAD",
    "pattern": {
      "value": "load",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "50": {
    "name": "SAVE",
    "pattern": {
      "value": "save",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "51": {
    "name": "TO",
    "pattern": {
      "value": "to",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "52": {
    "name": "NEW",
    "pattern": {
      "value": "new",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "53": {
    "name": "LPAR",
    "pattern": {
      "value": "(",
      "flags": [],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "54": {
    "name": "RPAR",
    "pattern": {
      "value": ")",
      "flags": [],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "55": {
    "name": "ATTR",
    "pattern": {
      "value": "attr",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "56": {
    "name": "LIMIT",
    "pattern": {
      "value": "limit",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "57": {
    "name": "OFFSET",
    "pattern": {
      "value": "offset",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "58": {
    "name": "OR",
    "pattern": {
      "value": "OR",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "59": {
    "name": "AND",
    "pattern": {
      "value": "AND",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "60": {
    "name": "NULL",
    "pattern": {
      "value": "null",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "61": {
    "name": "__ANON_0",
    "pattern": {
      "value": "NULL",
      "flags": [],
      "_width": [
        4,
        4
      ],
      "__type__": "PatternRE"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "62": {
    "name": "__ANON_1",
    "pattern": {
      "value": ", ",
      "flags": [],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "63": {
    "name": "START",
    "pattern": {
      "value": "START",
      "flags": [],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "64": {
    "name": "__ANON_2",
    "pattern": {
      "value": "t'",
      "flags": [],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "65": {
    "name": "QUOTE",
    "pattern": {
      "value": "'",
      "flags": [],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "66": {
    "name": "STOP",
    "pattern": {
      "value": "STOP",
      "flags": [],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "67": {
    "name": "__ANON_3",
    "pattern": {
      "value": "AS",
      "flags": [
        "i"
      ],
      "__type__": "PatternStr"
    },
    "priority": 0,
    "__type__": "TerminalDef"
  },
  "68": {
    "origin": {
      "name": "start",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "__start_star_0",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "69": {
    "origin": {
      "name": "start",
      "__type__": "NonTerminal"
    },
    "expansion": [],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "70": {
    "origin": {
      "name": "statement",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "assignment",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "71": {
    "origin": {
      "name": "statement",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "command_no_result",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "72": {
    "origin": {
      "name": "assignment",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "EQUAL",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "command_with_result",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "73": {
    "origin": {
      "name": "assignment",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "command_with_result",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "74": {
    "origin": {
      "name": "command_with_result",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "get",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "75": {
    "origin": {
      "name": "command_with_result",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "find",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "76": {
    "origin": {
      "name": "command_with_result",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "join",
        "__type__": "NonTerminal"
      }
    ],
    "order": 2,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "77": {
    "origin": {
      "name": "command_with_result",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "sort",
        "__type__": "NonTerminal"
      }
    ],
    "order": 3,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "78": {
    "origin": {
      "name": "command_with_result",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "group",
        "__type__": "NonTerminal"
      }
    ],
    "order": 4,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "79": {
    "origin": {
      "name": "command_with_result",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "load",
        "__type__": "NonTerminal"
      }
    ],
    "order": 5,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "80": {
    "origin": {
      "name": "command_with_result",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "new",
        "__type__": "NonTerminal"
      }
    ],
    "order": 6,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "81": {
    "origin": {
      "name": "command_with_result",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "merge",
        "__type__": "NonTerminal"
      }
    ],
    "order": 7,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "82": {
    "origin": {
      "name": "command_with_result",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "assign",
        "__type__": "NonTerminal"
      }
    ],
    "order": 8,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "83": {
    "origin": {
      "name": "command_no_result",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "disp",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "84": {
    "origin": {
      "name": "command_no_result",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "info",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "85": {
    "origin": {
      "name": "command_no_result",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "apply",
        "__type__": "NonTerminal"
      }
    ],
    "order": 2,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "86": {
    "origin": {
      "name": "command_no_result",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "save",
        "__type__": "NonTerminal"
      }
    ],
    "order": 3,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "87": {
    "origin": {
      "name": "assign",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "expression",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "88": {
    "origin": {
      "name": "merge",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "__merge_plus_1",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "89": {
    "origin": {
      "name": "disp",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "DISP",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "expression",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "90": {
    "origin": {
      "name": "info",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "INFO",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "91": {
    "origin": {
      "name": "get",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "GET",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ENTITY_TYPE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "FROM",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "DATASRC",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "WHERE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATTERNBODY",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "starttime",
        "__type__": "NonTerminal"
      },
      {
        "name": "endtime",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "92": {
    "origin": {
      "name": "get",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "GET",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ENTITY_TYPE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "FROM",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "DATASRC",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "WHERE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATTERNBODY",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "93": {
    "origin": {
      "name": "get",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "GET",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ENTITY_TYPE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "WHERE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATTERNBODY",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "starttime",
        "__type__": "NonTerminal"
      },
      {
        "name": "endtime",
        "__type__": "NonTerminal"
      }
    ],
    "order": 2,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "94": {
    "origin": {
      "name": "get",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "GET",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ENTITY_TYPE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "WHERE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATTERNBODY",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 3,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "95": {
    "origin": {
      "name": "find",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "FIND",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ENTITY_TYPE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "RELATION",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "REVERSED",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "starttime",
        "__type__": "NonTerminal"
      },
      {
        "name": "endtime",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "96": {
    "origin": {
      "name": "find",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "FIND",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ENTITY_TYPE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "RELATION",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "REVERSED",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "97": {
    "origin": {
      "name": "find",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "FIND",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ENTITY_TYPE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "RELATION",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "starttime",
        "__type__": "NonTerminal"
      },
      {
        "name": "endtime",
        "__type__": "NonTerminal"
      }
    ],
    "order": 2,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "98": {
    "origin": {
      "name": "find",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "FIND",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ENTITY_TYPE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "RELATION",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 3,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "99": {
    "origin": {
      "name": "apply",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "APPLY",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ANALYTICS",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ON",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "variables",
        "__type__": "NonTerminal"
      },
      {
        "name": "WITH",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "anaparams",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "100": {
    "origin": {
      "name": "apply",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "APPLY",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ANALYTICS",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ON",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "variables",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "101": {
    "origin": {
      "name": "join",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "JOIN",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "COMMA",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "BY",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "COMMA",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "102": {
    "origin": {
      "name": "join",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "JOIN",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "COMMA",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "103": {
    "origin": {
      "name": "sort",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "SORT",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "BY",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ASC",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "104": {
    "origin": {
      "name": "sort",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "SORT",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "BY",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "DESC",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "105": {
    "origin": {
      "name": "sort",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "SORT",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "BY",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 2,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "106": {
    "origin": {
      "name": "group",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "GROUP",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "BY",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "path_list",
        "__type__": "NonTerminal"
      },
      {
        "name": "WITH",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "agg_list",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "107": {
    "origin": {
      "name": "group",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "GROUP",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "BY",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "path_list",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "108": {
    "origin": {
      "name": "load",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "LOAD",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "DUMPPATH",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "AS",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ENTITY_TYPE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "109": {
    "origin": {
      "name": "load",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "LOAD",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "DUMPPATH",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "110": {
    "origin": {
      "name": "save",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "SAVE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "TO",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "DUMPPATH",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "111": {
    "origin": {
      "name": "new",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "NEW",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ENTITY_TYPE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARDATA",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "112": {
    "origin": {
      "name": "new",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "NEW",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARDATA",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "113": {
    "origin": {
      "name": "transform",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "TRANSFORM",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "LPAR",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "RPAR",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "114": {
    "origin": {
      "name": "transform",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "115": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "116": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "117": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 2,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "118": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 3,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "119": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 4,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "120": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 5,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "121": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 6,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "122": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 7,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "123": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 8,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "124": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 9,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "125": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 10,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "126": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 11,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "127": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 12,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "128": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 13,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "129": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 14,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "130": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "where_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 15,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "131": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 16,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "132": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 17,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "133": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 18,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "134": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 19,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "135": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 20,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "136": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 21,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "137": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 22,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "138": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "attr_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 23,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "139": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 24,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "140": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 25,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "141": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 26,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "142": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "sort_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 27,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "143": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 28,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "144": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "limit_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 29,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "145": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      },
      {
        "name": "offset_clause",
        "__type__": "NonTerminal"
      }
    ],
    "order": 30,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "146": {
    "origin": {
      "name": "expression",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "transform",
        "__type__": "NonTerminal"
      }
    ],
    "order": 31,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "147": {
    "origin": {
      "name": "where_clause",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "WHERE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "condition",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "148": {
    "origin": {
      "name": "attr_clause",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "ATTR",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATHS",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "149": {
    "origin": {
      "name": "sort_clause",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "SORT",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "BY",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ASC",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "150": {
    "origin": {
      "name": "sort_clause",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "SORT",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "BY",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "DESC",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "151": {
    "origin": {
      "name": "sort_clause",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "SORT",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "BY",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 2,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "152": {
    "origin": {
      "name": "limit_clause",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "LIMIT",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "INT",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "153": {
    "origin": {
      "name": "offset_clause",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "OFFSET",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "INT",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "154": {
    "origin": {
      "name": "condition",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "disjunction",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "155": {
    "origin": {
      "name": "disjunction",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "conjunction",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "156": {
    "origin": {
      "name": "disjunction",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "disjunction",
        "__type__": "NonTerminal"
      },
      {
        "name": "OR",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "conjunction",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": "disj",
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "157": {
    "origin": {
      "name": "conjunction",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "comparison",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "158": {
    "origin": {
      "name": "conjunction",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "conjunction",
        "__type__": "NonTerminal"
      },
      {
        "name": "AND",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "comparison",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": "conj",
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "159": {
    "origin": {
      "name": "comparison",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "column",
        "__type__": "NonTerminal"
      },
      {
        "name": "OP",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "value",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": "comp",
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "160": {
    "origin": {
      "name": "comparison",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "column",
        "__type__": "NonTerminal"
      },
      {
        "name": "NULL_OP",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "NULL",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": "null_comp",
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "161": {
    "origin": {
      "name": "comparison",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "LPAR",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "disjunction",
        "__type__": "NonTerminal"
      },
      {
        "name": "RPAR",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 2,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "162": {
    "origin": {
      "name": "column",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "163": {
    "origin": {
      "name": "value",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "SQSTRING",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": "squoted_str",
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "164": {
    "origin": {
      "name": "value",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "NUMBER",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": "num_literal",
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "165": {
    "origin": {
      "name": "value",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "__ANON_0",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 2,
    "alias": "nulls",
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "166": {
    "origin": {
      "name": "anaparams",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "localargs",
        "__type__": "NonTerminal"
      },
      {
        "name": "__anaparams_star_2",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "167": {
    "origin": {
      "name": "anaparams",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "localargs",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "168": {
    "origin": {
      "name": "anaparams",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "URI",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 2,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "169": {
    "origin": {
      "name": "localargs",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "CNAME",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "EQUAL",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "valuelist",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "170": {
    "origin": {
      "name": "localargs",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "CNAME",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "EQUAL",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "QSTRING",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "171": {
    "origin": {
      "name": "localargs",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "CNAME",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "EQUAL",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "NUMBER",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 2,
    "alias": "number",
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "172": {
    "origin": {
      "name": "valuelist",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "PATH",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "__valuelist_star_3",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "173": {
    "origin": {
      "name": "valuelist",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "PATH",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "174": {
    "origin": {
      "name": "starttime",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "START",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "__ANON_2",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ISOTIMESTAMP",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "QUOTE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "175": {
    "origin": {
      "name": "endtime",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "STOP",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "__ANON_2",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "ISOTIMESTAMP",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "QUOTE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "176": {
    "origin": {
      "name": "variables",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "__variables_star_4",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "177": {
    "origin": {
      "name": "variables",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "178": {
    "origin": {
      "name": "path_list",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "__path_list_star_5",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": "valuelist",
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "179": {
    "origin": {
      "name": "path_list",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": "valuelist",
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "180": {
    "origin": {
      "name": "agg_list",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "agg",
        "__type__": "NonTerminal"
      },
      {
        "name": "__agg_list_star_6",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "181": {
    "origin": {
      "name": "agg_list",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "agg",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "182": {
    "origin": {
      "name": "agg",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "funcname",
        "__type__": "NonTerminal"
      },
      {
        "name": "LPAR",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "RPAR",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "__ANON_3",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "alias",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "183": {
    "origin": {
      "name": "agg",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "funcname",
        "__type__": "NonTerminal"
      },
      {
        "name": "LPAR",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "RPAR",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "184": {
    "origin": {
      "name": "alias",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "CNAME",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "185": {
    "origin": {
      "name": "funcname",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "MIN",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "186": {
    "origin": {
      "name": "funcname",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "MAX",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "187": {
    "origin": {
      "name": "funcname",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "SUM",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 2,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "188": {
    "origin": {
      "name": "funcname",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "AVG",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 3,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "189": {
    "origin": {
      "name": "funcname",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "COUNT",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 4,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "190": {
    "origin": {
      "name": "funcname",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "NUNIQUE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 5,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": true,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "191": {
    "origin": {
      "name": "__start_star_0",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "statement",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "192": {
    "origin": {
      "name": "__start_star_0",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "__start_star_0",
        "__type__": "NonTerminal"
      },
      {
        "name": "statement",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "193": {
    "origin": {
      "name": "__merge_plus_1",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "PLUS",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "194": {
    "origin": {
      "name": "__merge_plus_1",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "__merge_plus_1",
        "__type__": "NonTerminal"
      },
      {
        "name": "PLUS",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "195": {
    "origin": {
      "name": "__anaparams_star_2",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "__ANON_1",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "localargs",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "196": {
    "origin": {
      "name": "__anaparams_star_2",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "__anaparams_star_2",
        "__type__": "NonTerminal"
      },
      {
        "name": "__ANON_1",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "localargs",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "197": {
    "origin": {
      "name": "__valuelist_star_3",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "COMMA",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "PATH",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "198": {
    "origin": {
      "name": "__valuelist_star_3",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "__valuelist_star_3",
        "__type__": "NonTerminal"
      },
      {
        "name": "COMMA",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "PATH",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "199": {
    "origin": {
      "name": "__variables_star_4",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "COMMA",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "200": {
    "origin": {
      "name": "__variables_star_4",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "__variables_star_4",
        "__type__": "NonTerminal"
      },
      {
        "name": "COMMA",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "VARIABLE",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "201": {
    "origin": {
      "name": "__path_list_star_5",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "COMMA",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "202": {
    "origin": {
      "name": "__path_list_star_5",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "__path_list_star_5",
        "__type__": "NonTerminal"
      },
      {
        "name": "COMMA",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "STIXPATH",
        "filter_out": false,
        "__type__": "Terminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "203": {
    "origin": {
      "name": "__agg_list_star_6",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "COMMA",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "agg",
        "__type__": "NonTerminal"
      }
    ],
    "order": 0,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  },
  "204": {
    "origin": {
      "name": "__agg_list_star_6",
      "__type__": "NonTerminal"
    },
    "expansion": [
      {
        "name": "__agg_list_star_6",
        "__type__": "NonTerminal"
      },
      {
        "name": "COMMA",
        "filter_out": false,
        "__type__": "Terminal"
      },
      {
        "name": "agg",
        "__type__": "NonTerminal"
      }
    ],
    "order": 1,
    "alias": null,
    "options": {
      "keep_all_tokens": true,
      "expand1": false,
      "priority": null,
      "template_source": null,
      "empty_indices": [],
      "__type__": "RuleOptions"
    },
    "__type__": "Rule"
  }
};
